<<CodeGen.m
<<Filters.m
<<CostMeasures.m

MatlabOptimizationGen::toosmall =
  "The number of pole pairs (``) is to small-- it needs to be at least ``.";

(*  S U P P O R T I N G     F U N C T I O N S  *)

(* filterorder --  for a Butterworth filter [Ludeman, p. 131] *)
filterorder[ wp_, ws_, dp_, ds_ ] :=
	Block [	{K1, K2},
		K1 = 20 Log[10, 1 - dp];
		K2 = 20 Log[10, ds];
		Log[10, (10^(-K1/10) - 1) / (10^(-K2/10) - 1)] /
		  (2 Log[10, wp/ws]) ]

(* getVariables *)
getvariables[x_] := Union[ Select[ Level[x, Infinity], variableQ ] ]

(* imagPartButtPole *)
imagPartButtPole[ j_, n_ ] := Sin[ Pi (3/2 -  (2 j - 1)/(2 n))]

(* myD ---  a kludge to make integrate work with D *)
myD[ x_, a_ ] :=
	Block [	{derivative, int, i, newx, rules},
		i = 0;
		rules = {};
		checkIn[ e_, w_ ] :=
			Block [	{fder, newint},
				i = i + 1;
				fder = D[e, a];
				newint = integrate[fder, w];
				AppendTo[rules, (int[i]')[a] -> newint];
				int[i][a] ];
		newx = x /.
			{ g_ integrate[ f_, w_ ] :> checkIn[f g, w],
			  integrate[f_, w_] :> checkIn[f, w] };
		derivative = D[ newx, a ];
		derivative /. rules ]

(* myDfilter *)
myDfilter[x_] := If [ SameQ[Head[x], List] && Apply[SameQ, x], First[x], x ]

(* realPartButtPole *)
realPartButtPole[ j_, n_ ] := Cos[ Pi (3/2 - (2 j - 1)/(2 n))]

(*  variableQ  *)
variableQ[x_] := SameQ[ Head[x], Symbol ]


(*  A B S T R A C T I O N S     F O R     C O D E     G E N E R A T I O N  *)


(*  writeAssignment  *)
writeAssignment[ target_, file_, lhs_, rhs_ ] :=
	writeLine[ target, file, ToString[lhs], " ",
		   assignString[target], " ", ToString[rhs],
		   endString[target] ]

(* endString *)
endString[ "Fortran" ] = ""
endString[ _ ] := ";"

(* assignString *)
assignString[ _ ] := "="

(* beginComment *)
beginComment[ "Matlab" ] = "%"
beginComment[ "C" ] = "/*"
beginComment[ "Fortran" ] = "     C"

(* endComment *)
endComment[ "C" ] = "*/"
endComment[ _ ] := ""


(*  C O D E     G E N E R A T I O N  *)

forbiddenVariables =
	{ eps, f, g, gf, GC, options, root, tpa, tpc, wc, wc1, wc2, x, x0 };

Apply[ Unprotect, forbiddenVariables ];
Apply[ Clear, forbiddenVariables ];
Apply[ Protect, forbiddenVariables ];


Unprotect[ int1, int2, int3, int4 ];
Clear[ int1, int2, int3, int4 ];
Protect[ int1, int2, int3, int4 ];


(* MatlabOptimizationGen *)
MatlabOptimizationGen[ { Wmp_, Wmt_, Wms_, Wph_, WQ_, WO_ },
		       a_Symbol, b_Symbol, n_, wp_, ws_,
		       wmax_, maxO_, dp_, ds_, useDer_:True ] :=
Module[	{augCostFun, bodyvar, ccount, constraints, costDerName, costFun,
	 costFunName, defaultValues, explanation, file, globallist, gofile,
	 gstr, i, initialGuess, j, len, m, mag, nstr, numcon, numparams,
	 order, paramlist, passSamples, passSamples0,
	 progfilename, q, qmax, reImButter,
	 spaces, startFlag, stepfilename, stepFunName, str, strlen,
	 theconstraint, tpeak, tpeakApprox, useDerFlag, wc1value, wc2value},

	(*  A.  List of parameters, their default values, and their meaning *)

	paramlist =
	    { Wmp, Wmt, Wms, Wph, WQ, WO, wp, ws, wmax, maxO, dp, ds };

	explanation = {
	  "weight on mag. response in passband",		 (* Wmp   *)
	  "weight on mag. response in transition band",		 (* Wmt   *)
	  "weight on mag. response in stopband",		 (* Wms   *)
	  "weight on deviation from linear phase",		 (* Wph   *)
	  "weight on quality factor cost",			 (* WQ    *)
	  "weight on percent overshoot cost",			 (* WO    *)
	  "end of passband frequency",				 (* wp    *)
	  "start of stopband frequency",			 (* ws    *)
	  "max. frequency for filter to exhibit linear phase",	 (* wmax  *)
	  "max. percent overshoot of the step response",	 (* maxO  *)
	  "allowable mag. error in the passband",		 (* dp    *)
	  "allowable mag. error in the stopband" };		 (* ds    *)

	(* default values are for a second-order Butterworth filter *)
	defaultValues = { 1, 1, 1, 0.1, 1, 1, 0.5, 10, wp, 20, 0.7, 0.01 };

	tpeak = Unique[ "tpeak" ];
	globallist = Append[ getvariables[ N[paramlist] ], tpeak ];
	costFun = weightedCosts[ { Wmp, Wmt, Wms, Wph, WQ, WO },
				 a, b, nn, wp, ws, wmax, tpeak ];

	nstr = ToString[n];

	useDerFlag = TrueQ[useDer];

	(* check the filter order to see if it is enough *)
	order = filterorder[wp, ws, dp, ds];
	If [ TrueQ[ (2 n) < Round[N[order]] ],
	     Message[ MatlabOptimizationGen::toosmall, n, Round[N[order]/2] ] ];

	(*  C.  Write the step response to a separate file.  *)

	stepFunName = "stepresp";
	stepfilename = StringJoin[ stepFunName, ".m" ];
	file = OpenWrite[ stepfilename ];
	m = Unique[ "m" ];
	WriteString[ file, "function f = ", stepFunName,
		     "(", x, ", ",  a, ", ", b, ", ", m, ")\n"  ];
	WriteString[ file, "%", ToUpperCase[ stepFunName ],
		     " computes the step response of an ",
		     "analog filter with ", n, " pole pairs.\n",
		     "%\n",
		     "%\tThis function takes four arguments:\n",
		     "%\t  ", x, " is time\n",
		     "%\t  ", a, " are the real values of the poles\n",
		     "%\t  ", b, " are imaginary values of the poles\n",
		     "%\t  ", m, " scales the step response\n" ];
	WriteString[ file, nn, " = length(", a, ");\n" ];
	bodyvar = MatlabCodeGen[ stepResponse[a, b, nn, x], file ];
	WriteString[ file, "f = ", m, ".*", ToString[bodyvar], ";\n" ];
	WriteString[ file, "end\n" ];

	Close[file];

	Print[ "Matlab function for the step response ",
	       "is in the file '", stepfilename, "'." ];

	(*  D.  Write Matlab cost function and constraints to "filcostN.m" *)

	costFunName = "filcost";
	file = OpenWrite[ StringJoin[ costFunName, ".m" ] ];

	WriteString[ file, "function [f,g]=", costFunName, "(x)\n" ];
	WriteString[ file,
		     "% ", ToUpperCase[costFunName],
		     "(x) returns the cost function for an analog filter\n",
		     "%\n%\tx contains the real parts of the ", nstr,
		     " pole pairs concatenated with\n",
		     "%\tthe imaginary parts of the ", nstr, " pole pairs.\n",
		     "%\n%\tCode Generated by Mathematica packages ",
		     "written by Brian L. Evans\n",
		     "%\tCopyright 1993 by the University of California\n",
		     "\n%% Extract real and imaginary components of the ",
		     "filters's poles ", a, " +/- j ", b, "\n" ];
	WriteString[ file, nn, " = length(x)/2;\n" ];
	WriteString[ file, a, " = x(1:", nn, ");\n" ];
	WriteString[ file, b, " = x(", MmaToMatlab[nn+1], ":",
		     MmaToMatlab[2*nn], ");\n" ];

	If [ ! SameQ[ globallist, {} ],
	     Print[ "Global variable(s) in Matlab functions:" ];
	     Print[ globallist ];
	     str = ToString[ InputForm[ globallist ] ];
	     str = StringReplace[ str, { "{" -> "", "}" -> "", "," -> "" } ];
	     gstr = StringJoin[ "global ", str, ";\n" ];
	     WriteString[ file, "\n%% Global parameters\n", gstr ] ];

	WriteString[ file, "\n%% Parameter settings\n" ];
	numparams = Length[ paramlist ];
	For [ i = 1, i <= numparams, i++,
	      WriteString[ file, "%%   ", explanation[[i]], ": ",
			   ToString[ InputForm[ paramlist[[i]] ] ], "\n" ] ];

	(*  C O M P U T E     T H E     C O N S T R A I N T S  *)

	(*  constraints need to come first in order to compute tpeak  *)

	WriteString[ file, "\n%% Code to compute the constraints\n" ];
	constraints = {};
	Clear[i];
	ccount = 0;			(* constraint counter *)

	(*  constraints on the quality factor of each section *)

	(*  1. From Firth: qmax is 10 for wp < 10 kHz and 25 for wp > 10 kHZ *)
	WriteString[ file, "\n%% Constraints on the quality factors\n" ];
	qmax = Unique[ "qmax" ];
	If [ N[wp < 2 Pi 10000],
	     WriteString[ file, qmax, " = 10;\n" ],
	     WriteString[ file, qmax, " = 25;\n" ],
	     WriteString[ file,
			  "if ", MmaToMatlab[wp], " < ", N[2 Pi 10000], "\n",
			  "   ", qmax, " = 10;\nelse\n",
			  "   ", qmax, " = 25;\nend\n" ] ];

	WriteString[ file, "ccount = 0;\n" ];
	WriteString[ file, "for ", i, " = [1:", nn, "];\n" ];
	WriteString[ file, "ccount = ccount + 1;\n" ];
	q = qualityOneSection[a, b, i];
	bodyvar = MatlabCodeGen[ q - qmax, file ];
	WriteString[ file, "g(", i, ") = ", bodyvar, ";\n" ];
	WriteString[ file, "end;\n" ];

	(*  2. Magnitude response in passband frequencies	*)
	(*     1 - dp <= magnitude <= 1 yields two constraints; *)
	(*     eps is Matlab's distance between real numbers;	*)
	(*     it allows us to convert x <= a to x - eps < a;	*)
	(*     we don't need to check DC because it's always 1	*)
	WriteString[file, "\n%% Constraints to check the passband response\n"];
	passSamples0 = 10;
	WriteString[file, passSamples, " = ", passSamples0, ";\n" ];
	WriteString[file, "for ", i, " = [", 1, ":", passSamples, "]", ";\n" ];

	mag = magnitude[a, b, nn, i*wp/passSamples] - 1 - Global`eps;
	AppendTo[ constraints, mag ];
	WriteString[file, "ccount = ccount + 1;\n" ];
	bodyvar = MatlabCodeGen[ mag, file ];
	WriteString[ file, "g(ccount) = ", bodyvar, ";\n" ];

	mag = 1 - dp - magnitude[a, b, nn, i*wp/passSamples] - Global`eps;
	AppendTo[ constraints, mag ];
	WriteString[file, "ccount = ccount + 1;\n" ];
	bodyvar = MatlabCodeGen[ mag, file ];
	WriteString[ file, "g(ccount) = ", bodyvar, ";\n" ]; 

	WriteString[ file, "end;\n" ];

	(*  3. Magnitude response at the stopband frequency wp  *)
	WriteString[ file, "\n%% Constraint to check the stopand response\n" ];
	mag = magnitude[a, b, nn, ws] - ds - Global`eps;
	AppendTo[ constraints, mag ];
	WriteString[file, "ccount = ccount + 1;\n" ];
	bodyvar = MatlabCodeGen[ mag, file ];
	WriteString[ file, "g(ccount) = ", bodyvar, ";\n" ];

	(*  4. Overshoot *)
	WriteString[ file, "\n%% Constraint to check the overshoot ",
		     "of the step response\n" ];
	WriteString[ file, "%%  Overshoot is computed by maximizing ",
		     "the function ", stepFunName, "\n" ];
	Clear[j];
	WriteString[file, "ccount = ccount + 1;\n" ];
	WriteString[ file, tpeak, " = fmin('", stepFunName, "', ", 0, ", ",
		     MmaToMatlab[ Max[ Table[ -Pi/b[j], {j, 1, n} ] ] ],
		     ", [], ", a, ", ", b, ", -1);\n" ];
	AppendTo[ constraints,
		  stepResponse[a, b, nn, tpeak] - 1 - eps - maxO/100 ];
	WriteString[ file, "g(ccount) = ", stepFunName,
		     "(", tpeak, ", ", a, ", ", b, ", 1) - 1 - eps - ",
		     MmaToMatlab[maxO/100], ";\n" ];

	(*  C O M P U T E     T H E     C O S T     F U N C T I O N  *)

	(*  It uses the value of tpeak calculated in the constraint code  *)

	WriteString[ file, "\n%% Code to compute the cost function\n" ];
	bodyvar = MatlabCodeGen[costFun, file];
	WriteString[ file, "f = ", ToString[bodyvar], ";\n" ];

	debugString[ expr_ ] :=
	  StringReplace[ MmaToMatlab[expr], 
			 { "int1" -> "integrate1",
			   "int2" -> "integrate2",
			   "int3" -> "integrate3",
			   "int4" -> "integrate4" } ];

	WriteString[ file, "\n%% Debugging code\n" ];
	WriteString[ file, "global numtimes weights;\n",
		     "weights = weights + [ ",
		     debugString[ Wms*int1/
				  (ws (10^($StopbandDecades) - 1)) ], " ",
		     debugString[ Wmp*int2/wp ], " ",
		     debugString[ Wmt*int3/(ws-wp) ], " ",
		     debugString[ Wph*int4/wmax ], " ] / f;\n",
		     "numtimes = numtimes + 1;\n" ];

	WriteString[ file, "\nend\n" ];

	Close[file];

	Print[ "Matlab code for the cost function is the file '",
	       costFunName, ".m'." ];

	gofile ]


(*
<<parameters.m
Clear[ Wmp, Wmt, Wms, Wph, WQ, WO ];
Clear[wmax];
Wmp = Wmt = Wms = Wph = WQ = WO = 0;
Wph = 1;
 *)

n = 2;
Clear[ Wmp, Wmt, Wms, Wph, WQ, WO, a, b, wp, ws, wmax, maxO, dp, ds ];
MatlabOptimizationGen[ { Wmp, Wmt, Wms, Wph, WQ, WO },
		       a, b, n, wp, ws, wmax, maxO, dp, ds ];
