function [f,g]=filcost3(x)
% FILCOST3(x) returns the cost function for an analog filter
%
%	x contains the real parts of the 3 pole pairs concatenated with
%	the imaginary parts of the 3 pole pairs.
%	further concatenated with the zeros.
%
%	Code Generated by Mathematica packages written by Brian L. Evans
%	Copyright 1993 by the Regents of the University of California

%% Extract real and imaginary components of the filters's poles a +/- j b

%% Extract real and imaginary components of the filters's zeros c +/- j d
a = x(1:3);
b = x(4:6);
c = x(7:9);
d = x(10:12);

%% Global parameters
global dp ds maxO wmax Wmp Wms Wmt WO wp Wph WQ ws tpeak1;

%% Parameter settings
%%   weight on mag. response in passband: Wmp
%%   weight on mag. response in transition band: Wmt
%%   weight on mag. response in stopband: Wms
%%   weight on deviation from linear phase: Wph
%%   weight on quality factor cost: WQ
%%   weight on percent overshoot cost: WO
%%   end of passband frequency: wp
%%   start of stopband frequency: ws
%%   max. frequency for filter to exhibit linear phase: wmax
%%   max. percent overshoot of the step response: maxO
%%   allowable mag. error in the passband: dp
%%   allowable mag. error in the stopband: ds

%% Code to compute the constraints

%% Constraints on the quality factors
if wp < 62831.9
   qmax1 = 20;
else
   qmax1 = 25;
end
g(1) = -qmax1 - sqrt(a(1).^2 + b(1).^2)./(2.*a(1));
g(2) = -qmax1 - sqrt(a(2).^2 + b(2).^2)./(2.*a(2));
g(3) = -qmax1 - sqrt(a(3).^2 + b(3).^2)./(2.*a(3));

%% Constraints to check the passband response
g(4) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(2).^2 - d(2).^2)))./100).*((c(3).^2 + d(3).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(3).^2 - d(3).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(3).^2 - b(3).^2)))./100)));
g(5) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(2).^2 - d(2).^2)))./100).*((c(3).^2 + d(3).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(3).^2 - d(3).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(3).^2 - b(3).^2)))./100)));
g(6) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(2).^2 - d(2).^2)))./25).*((c(3).^2 + d(3).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(3).^2 - d(3).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(3).^2 - b(3).^2)))./25)));
g(7) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(2).^2 - d(2).^2)))./25).*((c(3).^2 + d(3).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(3).^2 - d(3).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(3).^2 - b(3).^2)))./25)));
g(8) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(2).^2 - d(2).^2)))./100).*((c(3).^2 + d(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(3).^2 - d(3).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100)));
g(9) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(2).^2 - d(2).^2)))./100).*((c(3).^2 + d(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(3).^2 - d(3).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100)));
g(10) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(2).^2 - d(2).^2)))./25).*((c(3).^2 + d(3).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(3).^2 - d(3).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25)));
g(11) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(2).^2 - d(2).^2)))./25).*((c(3).^2 + d(3).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(3).^2 - d(3).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25)));
g(12) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(1).^2 - d(1).^2)))./4).*((c(2).^2 + d(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(2).^2 - d(2).^2)))./4).*((c(3).^2 + d(3).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(3).^2 - d(3).^2)))./4)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(1).^2 - b(1).^2)))./4).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(2).^2 - b(2).^2)))./4).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(3).^2 - b(3).^2)))./4)));
g(13) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(1).^2 - d(1).^2)))./4).*((c(2).^2 + d(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(2).^2 - d(2).^2)))./4).*((c(3).^2 + d(3).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(3).^2 - d(3).^2)))./4)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(1).^2 - b(1).^2)))./4).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(2).^2 - b(2).^2)))./4).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(3).^2 - b(3).^2)))./4)));
g(14) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(2).^2 - d(2).^2)))./25).*((c(3).^2 + d(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(3).^2 - d(3).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25)));
g(15) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(2).^2 - d(2).^2)))./25).*((c(3).^2 + d(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(3).^2 - d(3).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25)));
g(16) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(2).^2 - d(2).^2)))./100).*((c(3).^2 + d(3).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(3).^2 - d(3).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100)));
g(17) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(2).^2 - d(2).^2)))./100).*((c(3).^2 + d(3).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(3).^2 - d(3).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100)));
g(18) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(2).^2 - d(2).^2)))./25).*((c(3).^2 + d(3).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(3).^2 - d(3).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25)));
g(19) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(2).^2 - d(2).^2)))./25).*((c(3).^2 + d(3).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(3).^2 - d(3).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25)));
g(20) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(2).^2 - d(2).^2)))./100).*((c(3).^2 + d(3).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(3).^2 - d(3).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100)));
g(21) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(2).^2 - d(2).^2)))./100).*((c(3).^2 + d(3).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(3).^2 - d(3).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100)));
g(22) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(1).^2 - d(1).^2))).*((c(2).^2 + d(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(2).^2 - d(2).^2))).*((c(3).^2 + d(3).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(3).^2 - d(3).^2)))))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(2).^2 - b(2).^2))).*((a(3).^2 + b(3).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(3).^2 - b(3).^2)))));
g(23) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(1).^2 - d(1).^2))).*((c(2).^2 + d(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(2).^2 - d(2).^2))).*((c(3).^2 + d(3).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(3).^2 - d(3).^2)))))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(2).^2 - b(2).^2))).*((a(3).^2 + b(3).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(3).^2 - b(3).^2)))));

%% Constraint to check the stopand response
g(24) = -ds - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + ws.^2.*(ws.^2 + 2.*(c(1).^2 - d(1).^2))).*((c(2).^2 + d(2).^2).^2 + ws.^2.*(ws.^2 + 2.*(c(2).^2 - d(2).^2))).*((c(3).^2 + d(3).^2).^2 + ws.^2.*(ws.^2 + 2.*(c(3).^2 - d(3).^2)))))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(2).^2 - b(2).^2))).*((a(3).^2 + b(3).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(3).^2 - b(3).^2)))));

%% Constraint to check the overshoot of the step response
%%  Overshoot is computed by maximizing the function stepresp
tpeak1 = fmin('stepresp', 0, max([-(pi./b(1)), -(pi./b(2)), -(pi./b(3))]), [], a, b,c,d, -1);
g(25) = stepresp(tpeak1, a, b,c,d, 1) - 1 - eps - maxO./100;

%% Code to compute the cost function
w1 = [ws:(99.*ws)./100:100.*ws];
expr106 = (a(1).^2 + b(1).^2).^2;
expr107 = ((a(1).^2 + b(1).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(1).^2 - b(1).^2))).^(-1);
expr108 = (a(2).^2 + b(2).^2).^2;
expr109 = ((a(2).^2 + b(2).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(2).^2 - b(2).^2))).^(-1);
expr110 = (a(3).^2 + b(3).^2).^2;
expr111 = ((a(3).^2 + b(3).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(3).^2 - b(3).^2))).^(-1);
expr112 = (c(1).^2 + d(1).^2).^(-2);
expr113 = (c(1).^2 + d(1).^2).^2 + w1.^2.*(w1.^2 + 2.*(c(1).^2 - d(1).^2));
expr114 = (c(2).^2 + d(2).^2).^(-2);
expr115 = (c(2).^2 + d(2).^2).^2 + w1.^2.*(w1.^2 + 2.*(c(2).^2 - d(2).^2));
expr116 = (c(3).^2 + d(3).^2).^(-2);
expr117 = (c(3).^2 + d(3).^2).^2 + w1.^2.*(w1.^2 + 2.*(c(3).^2 - d(3).^2));
expr118 = expr106.*expr107.*expr108.*expr109.*expr110.*expr111.*expr112.*expr113.*expr114.*expr115.*expr116.*expr117;
integrate1 = trapz(w1, expr118);
w2 = [0:wp./100:wp];
expr119 = a(1).^2 + b(1).^2;
expr120 = a(2).^2 + b(2).^2;
expr121 = a(3).^2 + b(3).^2;
expr122 = (a(1).^2 + b(1).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(1).^2 - b(1).^2));
expr123 = (a(2).^2 + b(2).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(2).^2 - b(2).^2));
expr124 = (a(3).^2 + b(3).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(3).^2 - b(3).^2));
expr125 = -1./2;
expr126 = (c(1).^2 + d(1).^2).^(-1);
expr127 = (c(2).^2 + d(2).^2).^(-1);
expr128 = (c(3).^2 + d(3).^2).^(-1);
expr129 = (c(1).^2 + d(1).^2).^2 + w2.^2.*(w2.^2 + 2.*(c(1).^2 - d(1).^2));
expr130 = (c(2).^2 + d(2).^2).^2 + w2.^2.*(w2.^2 + 2.*(c(2).^2 - d(2).^2));
expr131 = (c(3).^2 + d(3).^2).^2 + w2.^2.*(w2.^2 + 2.*(c(3).^2 - d(3).^2));
expr132 = 1./2;
expr133 = (-1 + expr119.*expr120.*expr121.*(expr122.*expr123.*expr124).^expr125.*expr126.*expr127.*expr128.*(expr129.*expr130.*expr131).^expr132).^2;
integrate2 = trapz(w2, expr133);
w3 = [wp:(-wp + ws)./100:ws];
expr134 = -(w3./(wp - ws));
expr135 = ws./(wp - ws);
expr136 = a(1).^2 + b(1).^2;
expr137 = a(2).^2 + b(2).^2;
expr138 = a(3).^2 + b(3).^2;
expr139 = (a(1).^2 + b(1).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(1).^2 - b(1).^2));
expr140 = (a(2).^2 + b(2).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(2).^2 - b(2).^2));
expr141 = (a(3).^2 + b(3).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(3).^2 - b(3).^2));
expr142 = -1./2;
expr143 = (c(1).^2 + d(1).^2).^(-1);
expr144 = (c(2).^2 + d(2).^2).^(-1);
expr145 = (c(3).^2 + d(3).^2).^(-1);
expr146 = (c(1).^2 + d(1).^2).^2 + w3.^2.*(w3.^2 + 2.*(c(1).^2 - d(1).^2));
expr147 = (c(2).^2 + d(2).^2).^2 + w3.^2.*(w3.^2 + 2.*(c(2).^2 - d(2).^2));
expr148 = (c(3).^2 + d(3).^2).^2 + w3.^2.*(w3.^2 + 2.*(c(3).^2 - d(3).^2));
expr149 = 1./2;
expr150 = (expr134 + expr135 + expr136.*expr137.*expr138.*(expr139.*expr140.*expr141).^expr142.*expr143.*expr144.*expr145.*(expr146.*expr147.*expr148).^expr149).^2;
integrate3 = trapz(w3, expr150);
w4 = [0:wmax./100:wmax];
expr151 = angle(1 + (i.*(w4 - b(1)))./a(1));
expr152 = angle(1 + (i.*(w4 + b(1)))./a(1));
expr153 = angle(1 + (i.*(w4 - b(2)))./a(2));
expr154 = angle(1 + (i.*(w4 + b(2)))./a(2));
expr155 = angle(1 + (i.*(w4 - b(3)))./a(3));
expr156 = angle(1 + (i.*(w4 + b(3)))./a(3));
expr157 = -angle(1 + (i.*(w4 - d(1)))./c(1));
expr158 = -angle(1 + (i.*(w4 + d(1)))./c(1));
expr159 = -angle(1 + (i.*(w4 - d(2)))./c(2));
expr160 = -angle(1 + (i.*(w4 + d(2)))./c(2));
expr161 = -angle(1 + (i.*(w4 - d(3)))./c(3));
expr162 = -angle(1 + (i.*(w4 + d(3)))./c(3));
expr163 = wmax.^(-3);
expr164 = 1./2;
expr165 = -2.*wmax.*a(1);
expr166 = angle(1 + (i.*(wmax - b(1)))./a(1)) + angle(1 + (i.*(wmax + b(1)))./a(1));
expr167 = -wmax.^2 - a(1).^2 + b(1).^2;
expr168 = -(a(1).*b(1).*log(1 + (wmax - b(1)).^2./a(1).^2));
expr169 = a(1).*b(1).*log(1 + (wmax + b(1)).^2./a(1).^2);
expr170 = -2.*wmax.*a(2);
expr171 = angle(1 + (i.*(wmax - b(2)))./a(2)) + angle(1 + (i.*(wmax + b(2)))./a(2));
expr172 = -wmax.^2 - a(2).^2 + b(2).^2;
expr173 = -(a(2).*b(2).*log(1 + (wmax - b(2)).^2./a(2).^2));
expr174 = a(2).*b(2).*log(1 + (wmax + b(2)).^2./a(2).^2);
expr175 = -2.*wmax.*a(3);
expr176 = angle(1 + (i.*(wmax - b(3)))./a(3)) + angle(1 + (i.*(wmax + b(3)))./a(3));
expr177 = -wmax.^2 - a(3).^2 + b(3).^2;
expr178 = -(a(3).*b(3).*log(1 + (wmax - b(3)).^2./a(3).^2));
expr179 = a(3).*b(3).*log(1 + (wmax + b(3)).^2./a(3).^2);
expr180 = 2.*wmax.*c(1);
expr181 = angle(1 + (i.*(wmax - d(1)))./c(1)) + angle(1 + (i.*(wmax + d(1)))./c(1));
expr182 = -wmax.^2 - c(1).^2 + d(1).^2;
expr183 = c(1).*d(1).*log(1 + (wmax - d(1)).^2./c(1).^2);
expr184 = -(c(1).*d(1).*log(1 + (wmax + d(1)).^2./c(1).^2));
expr185 = 2.*wmax.*c(2);
expr186 = angle(1 + (i.*(wmax - d(2)))./c(2)) + angle(1 + (i.*(wmax + d(2)))./c(2));
expr187 = -wmax.^2 - c(2).^2 + d(2).^2;
expr188 = c(2).*d(2).*log(1 + (wmax - d(2)).^2./c(2).^2);
expr189 = -(c(2).*d(2).*log(1 + (wmax + d(2)).^2./c(2).^2));
expr190 = 2.*wmax.*c(3);
expr191 = angle(1 + (i.*(wmax - d(3)))./c(3)) + angle(1 + (i.*(wmax + d(3)))./c(3));
expr192 = -wmax.^2 - c(3).^2 + d(3).^2;
expr193 = c(3).*d(3).*log(1 + (wmax - d(3)).^2./c(3).^2);
expr194 = -(c(3).*d(3).*log(1 + (wmax + d(3)).^2./c(3).^2));
expr195 = expr164.*(expr165 - expr166.*expr167 + expr168 + expr169);
expr196 = expr164.*(expr170 - expr171.*expr172 + expr173 + expr174);
expr197 = expr164.*(expr175 - expr176.*expr177 + expr178 + expr179);
expr198 = expr164.*(expr180 + expr181.*expr182 + expr183 + expr184);
expr199 = expr164.*(expr185 + expr186.*expr187 + expr188 + expr189);
expr200 = expr164.*(expr190 + expr191.*expr192 + expr193 + expr194);
expr201 = (expr151 + expr152 + expr153 + expr154 + expr155 + expr156 + expr157 + expr158 + expr159 + expr160 + expr161 + expr162 - 3.*expr163.*(expr195 + expr196 + expr197 + expr198 + expr199 + expr200).*w4).^2;
integrate4 = trapz(w4, expr201);
expr202 = (integrate2.*Wmp)./wp;
expr203 = (integrate4.*Wph)./wmax;
expr204 = (integrate1.*Wms)./(99.*ws);
expr205 = (integrate3.*Wmt)./(-wp + ws);
expr206 = 1./2;
expr207 = a(1).^(-1);
expr208 = a(2).^(-1);
expr209 = a(3).^(-1);
expr210 = sqrt(a(1).^2 + b(1).^2);
expr211 = sqrt(a(2).^2 + b(2).^2);
expr212 = sqrt(a(3).^2 + b(3).^2);
expr213 = 1./3;
expr214 = b(1).^(-1);
expr215 = a(2).^2 + b(2).^2;
expr216 = a(3).^2 + b(3).^2;
expr217 = (a(1) - a(2)).^2 + (b(1) - b(2)).^2;
expr218 = (a(1) - a(2)).^2 + (b(1) + b(2)).^2;
expr219 = (a(1) - a(3)).^2 + (b(1) - b(3)).^2;
expr220 = (a(1) - a(3)).^2 + (b(1) + b(3)).^2;
expr221 = -1./2;
expr222 = (c(1).^2 + d(1).^2).^(-1);
expr223 = (c(2).^2 + d(2).^2).^(-1);
expr224 = (c(3).^2 + d(3).^2).^(-1);
expr225 = (a(1) - c(1)).^2 + (b(1) - d(1)).^2;
expr226 = (a(1) - c(1)).^2 + (b(1) + d(1)).^2;
expr227 = (a(1) - c(2)).^2 + (b(1) - d(2)).^2;
expr228 = (a(1) - c(2)).^2 + (b(1) + d(2)).^2;
expr229 = (a(1) - c(3)).^2 + (b(1) - d(3)).^2;
expr230 = (a(1) - c(3)).^2 + (b(1) + d(3)).^2;
expr231 = b(1);
expr232 = angle(1 + (i.*(b(1) - b(2)))./(a(1) - a(2)));
expr233 = angle(1 + (i.*(b(1) + b(2)))./(a(1) - a(2)));
expr234 = angle(1 + (i.*(b(1) - b(3)))./(a(1) - a(3)));
expr235 = angle(1 + (i.*(b(1) + b(3)))./(a(1) - a(3)));
expr236 = -angle(1 + (i.*(b(1) - d(1)))./(a(1) - c(1)));
expr237 = -angle(1 + (i.*(b(1) + d(1)))./(a(1) - c(1)));
expr238 = -angle(1 + (i.*(b(1) - d(2)))./(a(1) - c(2)));
expr239 = -angle(1 + (i.*(b(1) + d(2)))./(a(1) - c(2)));
expr240 = -angle(1 + (i.*(b(1) - d(3)))./(a(1) - c(3)));
expr241 = -angle(1 + (i.*(b(1) + d(3)))./(a(1) - c(3)));
expr242 = a(1);
expr243 = exp(tpeak1.*a(1));
expr244 = cos(tpeak1.*b(1));
expr245 = a(1).^2 + b(1).^2;
expr246 = sin(tpeak1.*b(1));
expr247 = b(2).^(-1);
expr248 = (-a(1) + a(2)).^2 + (-b(1) + b(2)).^2;
expr249 = (-a(1) + a(2)).^2 + (b(1) + b(2)).^2;
expr250 = (a(2) - a(3)).^2 + (b(2) - b(3)).^2;
expr251 = (a(2) - a(3)).^2 + (b(2) + b(3)).^2;
expr252 = (a(2) - c(1)).^2 + (b(2) - d(1)).^2;
expr253 = (a(2) - c(1)).^2 + (b(2) + d(1)).^2;
expr254 = (a(2) - c(2)).^2 + (b(2) - d(2)).^2;
expr255 = (a(2) - c(2)).^2 + (b(2) + d(2)).^2;
expr256 = (a(2) - c(3)).^2 + (b(2) - d(3)).^2;
expr257 = (a(2) - c(3)).^2 + (b(2) + d(3)).^2;
expr258 = b(2);
expr259 = angle(1 + (i.*(-b(1) + b(2)))./(-a(1) + a(2)));
expr260 = angle(1 + (i.*(b(1) + b(2)))./(-a(1) + a(2)));
expr261 = angle(1 + (i.*(b(2) - b(3)))./(a(2) - a(3)));
expr262 = angle(1 + (i.*(b(2) + b(3)))./(a(2) - a(3)));
expr263 = -angle(1 + (i.*(b(2) - d(1)))./(a(2) - c(1)));
expr264 = -angle(1 + (i.*(b(2) + d(1)))./(a(2) - c(1)));
expr265 = -angle(1 + (i.*(b(2) - d(2)))./(a(2) - c(2)));
expr266 = -angle(1 + (i.*(b(2) + d(2)))./(a(2) - c(2)));
expr267 = -angle(1 + (i.*(b(2) - d(3)))./(a(2) - c(3)));
expr268 = -angle(1 + (i.*(b(2) + d(3)))./(a(2) - c(3)));
expr269 = a(2);
expr270 = exp(tpeak1.*a(2));
expr271 = cos(tpeak1.*b(2));
expr272 = sin(tpeak1.*b(2));
expr273 = b(3).^(-1);
expr274 = (-a(1) + a(3)).^2 + (-b(1) + b(3)).^2;
expr275 = (-a(1) + a(3)).^2 + (b(1) + b(3)).^2;
expr276 = (-a(2) + a(3)).^2 + (-b(2) + b(3)).^2;
expr277 = (-a(2) + a(3)).^2 + (b(2) + b(3)).^2;
expr278 = (a(3) - c(1)).^2 + (b(3) - d(1)).^2;
expr279 = (a(3) - c(1)).^2 + (b(3) + d(1)).^2;
expr280 = (a(3) - c(2)).^2 + (b(3) - d(2)).^2;
expr281 = (a(3) - c(2)).^2 + (b(3) + d(2)).^2;
expr282 = (a(3) - c(3)).^2 + (b(3) - d(3)).^2;
expr283 = (a(3) - c(3)).^2 + (b(3) + d(3)).^2;
expr284 = b(3);
expr285 = angle(1 + (i.*(-b(1) + b(3)))./(-a(1) + a(3)));
expr286 = angle(1 + (i.*(b(1) + b(3)))./(-a(1) + a(3)));
expr287 = angle(1 + (i.*(-b(2) + b(3)))./(-a(2) + a(3)));
expr288 = angle(1 + (i.*(b(2) + b(3)))./(-a(2) + a(3)));
expr289 = -angle(1 + (i.*(b(3) - d(1)))./(a(3) - c(1)));
expr290 = -angle(1 + (i.*(b(3) + d(1)))./(a(3) - c(1)));
expr291 = -angle(1 + (i.*(b(3) - d(2)))./(a(3) - c(2)));
expr292 = -angle(1 + (i.*(b(3) + d(2)))./(a(3) - c(2)));
expr293 = -angle(1 + (i.*(b(3) - d(3)))./(a(3) - c(3)));
expr294 = -angle(1 + (i.*(b(3) + d(3)))./(a(3) - c(3)));
expr295 = a(3);
expr296 = exp(tpeak1.*a(3));
expr297 = cos(tpeak1.*b(3));
expr298 = sin(tpeak1.*b(3));
expr299 = (-0.5 + expr206.*(-(expr207.*expr208.*expr209.*expr210.*expr211.*expr212)).^expr213).*WQ;
expr300 = (expr217.*expr218.*expr219.*expr220).^expr221;
expr301 = (expr225.*expr226.*expr227.*expr228.*expr229.*expr230).^expr206;
expr302 = expr231.*cos(expr232 + expr233 + expr234 + expr235 + expr236 + expr237 + expr238 + expr239 + expr240 + expr241) + expr242.*sin(expr232 + expr233 + expr234 + expr235 + expr236 + expr237 + expr238 + expr239 + expr240 + expr241);
expr303 = sin(expr232 + expr233 + expr234 + expr235 + expr236 + expr237 + expr238 + expr239 + expr240 + expr241);
expr304 = (expr231.*cos(expr232 + expr233 + expr234 + expr235 + expr236 + expr237 + expr238 + expr239 + expr240 + expr241) + expr242.*sin(expr232 + expr233 + expr234 + expr235 + expr236 + expr237 + expr238 + expr239 + expr240 + expr241)).^(-1);
expr305 = (expr248.*expr249.*expr250.*expr251).^expr221;
expr306 = (expr252.*expr253.*expr254.*expr255.*expr256.*expr257).^expr206;
expr307 = expr258.*cos(expr259 + expr260 + expr261 + expr262 + expr263 + expr264 + expr265 + expr266 + expr267 + expr268) + expr269.*sin(expr259 + expr260 + expr261 + expr262 + expr263 + expr264 + expr265 + expr266 + expr267 + expr268);
expr308 = sin(expr259 + expr260 + expr261 + expr262 + expr263 + expr264 + expr265 + expr266 + expr267 + expr268);
expr309 = (expr258.*cos(expr259 + expr260 + expr261 + expr262 + expr263 + expr264 + expr265 + expr266 + expr267 + expr268) + expr269.*sin(expr259 + expr260 + expr261 + expr262 + expr263 + expr264 + expr265 + expr266 + expr267 + expr268)).^(-1);
expr310 = (expr274.*expr275.*expr276.*expr277).^expr221;
expr311 = (expr278.*expr279.*expr280.*expr281.*expr282.*expr283).^expr206;
expr312 = expr284.*cos(expr285 + expr286 + expr287 + expr288 + expr289 + expr290 + expr291 + expr292 + expr293 + expr294) + expr295.*sin(expr285 + expr286 + expr287 + expr288 + expr289 + expr290 + expr291 + expr292 + expr293 + expr294);
expr313 = sin(expr285 + expr286 + expr287 + expr288 + expr289 + expr290 + expr291 + expr292 + expr293 + expr294);
expr314 = (expr284.*cos(expr285 + expr286 + expr287 + expr288 + expr289 + expr290 + expr291 + expr292 + expr293 + expr294) + expr295.*sin(expr285 + expr286 + expr287 + expr288 + expr289 + expr290 + expr291 + expr292 + expr293 + expr294)).^(-1);
expr315 = expr214.*expr215.*expr216.*expr222.*expr223.*expr224.*expr300.*expr301.*expr302.*(1 - expr243.*(expr244 - expr214.*expr246.*(expr242 - expr245.*expr303.*expr304)));
expr316 = expr216.*expr222.*expr223.*expr224.*expr245.*expr247.*expr305.*expr306.*expr307.*(1 - expr270.*(expr271 - expr247.*expr272.*(expr269 - expr215.*expr308.*expr309)));
expr317 = expr215.*expr222.*expr223.*expr224.*expr245.*expr273.*expr310.*expr311.*expr312.*(1 - expr296.*(expr297 - expr273.*expr298.*(expr295 - expr216.*expr313.*expr314)));
expr318 = expr202 + expr203 + expr204 + expr205 + expr299 + 100.*(-1 + expr315 + expr316 + expr317).^2.*WO;
f = expr318;

%% Debugging code
global numtimes weights;
weights = weights + [ (integrate1.*Wms)./(99.*ws) (integrate2.*Wmp)./wp (integrate3.*Wmt)./(-wp + ws) (integrate4.*Wph)./wmax ] / f;
numtimes = numtimes + 1;

end
