function [f,g]=filcost4(x)
% FILCOST4(x) returns the cost function for an analog filter
%
%	x contains the real parts of the 4 pole pairs concatenated with
%	the imaginary parts of the 4 pole pairs.
%	further concatenated with the zeros.
%
%	Code Generated by Mathematica packages written by Brian L. Evans
%	Copyright 1993 by the Regents of the University of California

%% Extract real and imaginary components of the filters's poles a +/- j b

%% Extract real and imaginary components of the filters's zeros c +/- j d
a = x(1:4);
b = x(5:8);
c = x(9:12);
d = x(13:16);

%% Global parameters
global dp ds maxO wmax Wmp Wms Wmt WO wp Wph WQ ws tpeak1;

%% Parameter settings
%%   weight on mag. response in passband: Wmp
%%   weight on mag. response in transition band: Wmt
%%   weight on mag. response in stopband: Wms
%%   weight on deviation from linear phase: Wph
%%   weight on quality factor cost: WQ
%%   weight on percent overshoot cost: WO
%%   end of passband frequency: wp
%%   start of stopband frequency: ws
%%   max. frequency for filter to exhibit linear phase: wmax
%%   max. percent overshoot of the step response: maxO
%%   allowable mag. error in the passband: dp
%%   allowable mag. error in the stopband: ds

%% Code to compute the constraints

%% Constraints on the quality factors
if wp < 62831.9
   qmax1 = 10;
else
   qmax1 = 25;
end
g(1) = -qmax1 - sqrt(a(1).^2 + b(1).^2)./(2.*a(1));
g(2) = -qmax1 - sqrt(a(2).^2 + b(2).^2)./(2.*a(2));
g(3) = -qmax1 - sqrt(a(3).^2 + b(3).^2)./(2.*a(3));
g(4) = -qmax1 - sqrt(a(4).^2 + b(4).^2)./(2.*a(4));

%% Constraints to check the passband response
g(5) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(2).^2 - d(2).^2)))./100).*((c(3).^2 + d(3).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(3).^2 - d(3).^2)))./100).*((c(4).^2 + d(4).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(4).^2 - d(4).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(3).^2 - b(3).^2)))./100).*((a(4).^2 + b(4).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(4).^2 - b(4).^2)))./100)));
g(6) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(2).^2 - d(2).^2)))./100).*((c(3).^2 + d(3).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(3).^2 - d(3).^2)))./100).*((c(4).^2 + d(4).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(c(4).^2 - d(4).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(3).^2 - b(3).^2)))./100).*((a(4).^2 + b(4).^2).^2 + (wp.^2.*(wp.^2./100 + 2.*(a(4).^2 - b(4).^2)))./100)));
g(7) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(2).^2 - d(2).^2)))./25).*((c(3).^2 + d(3).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(3).^2 - d(3).^2)))./25).*((c(4).^2 + d(4).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(4).^2 - d(4).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(3).^2 - b(3).^2)))./25).*((a(4).^2 + b(4).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(4).^2 - b(4).^2)))./25)));
g(8) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(2).^2 - d(2).^2)))./25).*((c(3).^2 + d(3).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(3).^2 - d(3).^2)))./25).*((c(4).^2 + d(4).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(c(4).^2 - d(4).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(3).^2 - b(3).^2)))./25).*((a(4).^2 + b(4).^2).^2 + (wp.^2.*(wp.^2./25 + 2.*(a(4).^2 - b(4).^2)))./25)));
g(9) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(2).^2 - d(2).^2)))./100).*((c(3).^2 + d(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(3).^2 - d(3).^2)))./100).*((c(4).^2 + d(4).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(4).^2 - d(4).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100).*((a(4).^2 + b(4).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(4).^2 - b(4).^2)))./100)));
g(10) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(2).^2 - d(2).^2)))./100).*((c(3).^2 + d(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(3).^2 - d(3).^2)))./100).*((c(4).^2 + d(4).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(c(4).^2 - d(4).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100).*((a(4).^2 + b(4).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./100 + 2.*(a(4).^2 - b(4).^2)))./100)));
g(11) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(2).^2 - d(2).^2)))./25).*((c(3).^2 + d(3).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(3).^2 - d(3).^2)))./25).*((c(4).^2 + d(4).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(4).^2 - d(4).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25).*((a(4).^2 + b(4).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(4).^2 - b(4).^2)))./25)));
g(12) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(2).^2 - d(2).^2)))./25).*((c(3).^2 + d(3).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(3).^2 - d(3).^2)))./25).*((c(4).^2 + d(4).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(c(4).^2 - d(4).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25).*((a(4).^2 + b(4).^2).^2 + (4.*wp.^2.*((4.*wp.^2)./25 + 2.*(a(4).^2 - b(4).^2)))./25)));
g(13) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(1).^2 - d(1).^2)))./4).*((c(2).^2 + d(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(2).^2 - d(2).^2)))./4).*((c(3).^2 + d(3).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(3).^2 - d(3).^2)))./4).*((c(4).^2 + d(4).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(4).^2 - d(4).^2)))./4)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(1).^2 - b(1).^2)))./4).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(2).^2 - b(2).^2)))./4).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(3).^2 - b(3).^2)))./4).*((a(4).^2 + b(4).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(4).^2 - b(4).^2)))./4)));
g(14) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(1).^2 - d(1).^2)))./4).*((c(2).^2 + d(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(2).^2 - d(2).^2)))./4).*((c(3).^2 + d(3).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(3).^2 - d(3).^2)))./4).*((c(4).^2 + d(4).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(c(4).^2 - d(4).^2)))./4)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(1).^2 - b(1).^2)))./4).*((a(2).^2 + b(2).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(2).^2 - b(2).^2)))./4).*((a(3).^2 + b(3).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(3).^2 - b(3).^2)))./4).*((a(4).^2 + b(4).^2).^2 + (wp.^2.*(wp.^2./4 + 2.*(a(4).^2 - b(4).^2)))./4)));
g(15) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(2).^2 - d(2).^2)))./25).*((c(3).^2 + d(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(3).^2 - d(3).^2)))./25).*((c(4).^2 + d(4).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(4).^2 - d(4).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25).*((a(4).^2 + b(4).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(4).^2 - b(4).^2)))./25)));
g(16) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(2).^2 - d(2).^2)))./25).*((c(3).^2 + d(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(3).^2 - d(3).^2)))./25).*((c(4).^2 + d(4).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(c(4).^2 - d(4).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25).*((a(4).^2 + b(4).^2).^2 + (9.*wp.^2.*((9.*wp.^2)./25 + 2.*(a(4).^2 - b(4).^2)))./25)));
g(17) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(2).^2 - d(2).^2)))./100).*((c(3).^2 + d(3).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(3).^2 - d(3).^2)))./100).*((c(4).^2 + d(4).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(4).^2 - d(4).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100).*((a(4).^2 + b(4).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(4).^2 - b(4).^2)))./100)));
g(18) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(2).^2 - d(2).^2)))./100).*((c(3).^2 + d(3).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(3).^2 - d(3).^2)))./100).*((c(4).^2 + d(4).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(c(4).^2 - d(4).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100).*((a(4).^2 + b(4).^2).^2 + (49.*wp.^2.*((49.*wp.^2)./100 + 2.*(a(4).^2 - b(4).^2)))./100)));
g(19) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(2).^2 - d(2).^2)))./25).*((c(3).^2 + d(3).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(3).^2 - d(3).^2)))./25).*((c(4).^2 + d(4).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(4).^2 - d(4).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25).*((a(4).^2 + b(4).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(4).^2 - b(4).^2)))./25)));
g(20) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(1).^2 - d(1).^2)))./25).*((c(2).^2 + d(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(2).^2 - d(2).^2)))./25).*((c(3).^2 + d(3).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(3).^2 - d(3).^2)))./25).*((c(4).^2 + d(4).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(c(4).^2 - d(4).^2)))./25)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(1).^2 - b(1).^2)))./25).*((a(2).^2 + b(2).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(2).^2 - b(2).^2)))./25).*((a(3).^2 + b(3).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(3).^2 - b(3).^2)))./25).*((a(4).^2 + b(4).^2).^2 + (16.*wp.^2.*((16.*wp.^2)./25 + 2.*(a(4).^2 - b(4).^2)))./25)));
g(21) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(2).^2 - d(2).^2)))./100).*((c(3).^2 + d(3).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(3).^2 - d(3).^2)))./100).*((c(4).^2 + d(4).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(4).^2 - d(4).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100).*((a(4).^2 + b(4).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(4).^2 - b(4).^2)))./100)));
g(22) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(1).^2 - d(1).^2)))./100).*((c(2).^2 + d(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(2).^2 - d(2).^2)))./100).*((c(3).^2 + d(3).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(3).^2 - d(3).^2)))./100).*((c(4).^2 + d(4).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(c(4).^2 - d(4).^2)))./100)))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(1).^2 - b(1).^2)))./100).*((a(2).^2 + b(2).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(2).^2 - b(2).^2)))./100).*((a(3).^2 + b(3).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(3).^2 - b(3).^2)))./100).*((a(4).^2 + b(4).^2).^2 + (81.*wp.^2.*((81.*wp.^2)./100 + 2.*(a(4).^2 - b(4).^2)))./100)));
g(23) = -1 - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(1).^2 - d(1).^2))).*((c(2).^2 + d(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(2).^2 - d(2).^2))).*((c(3).^2 + d(3).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(3).^2 - d(3).^2))).*((c(4).^2 + d(4).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(4).^2 - d(4).^2)))))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(2).^2 - b(2).^2))).*((a(3).^2 + b(3).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(3).^2 - b(3).^2))).*((a(4).^2 + b(4).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(4).^2 - b(4).^2)))));
g(24) = 1 - dp - eps - ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(1).^2 - d(1).^2))).*((c(2).^2 + d(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(2).^2 - d(2).^2))).*((c(3).^2 + d(3).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(3).^2 - d(3).^2))).*((c(4).^2 + d(4).^2).^2 + wp.^2.*(wp.^2 + 2.*(c(4).^2 - d(4).^2)))))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(2).^2 - b(2).^2))).*((a(3).^2 + b(3).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(3).^2 - b(3).^2))).*((a(4).^2 + b(4).^2).^2 + wp.^2.*(wp.^2 + 2.*(a(4).^2 - b(4).^2)))));

%% Constraint to check the stopand response
g(25) = -ds - eps + ((a(1).^2 + b(1).^2).*(a(2).^2 + b(2).^2).*(a(3).^2 + b(3).^2).*(a(4).^2 + b(4).^2).*sqrt(((c(1).^2 + d(1).^2).^2 + ws.^2.*(ws.^2 + 2.*(c(1).^2 - d(1).^2))).*((c(2).^2 + d(2).^2).^2 + ws.^2.*(ws.^2 + 2.*(c(2).^2 - d(2).^2))).*((c(3).^2 + d(3).^2).^2 + ws.^2.*(ws.^2 + 2.*(c(3).^2 - d(3).^2))).*((c(4).^2 + d(4).^2).^2 + ws.^2.*(ws.^2 + 2.*(c(4).^2 - d(4).^2)))))./((c(1).^2 + d(1).^2).*(c(2).^2 + d(2).^2).*(c(3).^2 + d(3).^2).*(c(4).^2 + d(4).^2).*sqrt(((a(1).^2 + b(1).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(1).^2 - b(1).^2))).*((a(2).^2 + b(2).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(2).^2 - b(2).^2))).*((a(3).^2 + b(3).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(3).^2 - b(3).^2))).*((a(4).^2 + b(4).^2).^2 + ws.^2.*(ws.^2 + 2.*(a(4).^2 - b(4).^2)))));

%% Constraint to check the overshoot of the step response
%%  Overshoot is computed by maximizing the function stepresp
tpeak1 = fmin('stepresp', 0, max([-(pi./b(1)), -(pi./b(2)), -(pi./b(3)), -(pi./b(4))]), [], a, b,c,d, -1);
g(26) = stepresp(tpeak1, a, b,c,d, 1) - 1 - eps - maxO./100;

%% Code to compute the cost function
w1 = [ws:(99.*ws)./100:100.*ws];
expr172 = (a(1).^2 + b(1).^2).^2;
expr173 = ((a(1).^2 + b(1).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(1).^2 - b(1).^2))).^(-1);
expr174 = (a(2).^2 + b(2).^2).^2;
expr175 = ((a(2).^2 + b(2).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(2).^2 - b(2).^2))).^(-1);
expr176 = (a(3).^2 + b(3).^2).^2;
expr177 = ((a(3).^2 + b(3).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(3).^2 - b(3).^2))).^(-1);
expr178 = (a(4).^2 + b(4).^2).^2;
expr179 = ((a(4).^2 + b(4).^2).^2 + w1.^2.*(w1.^2 + 2.*(a(4).^2 - b(4).^2))).^(-1);
expr180 = (c(1).^2 + d(1).^2).^(-2);
expr181 = (c(1).^2 + d(1).^2).^2 + w1.^2.*(w1.^2 + 2.*(c(1).^2 - d(1).^2));
expr182 = (c(2).^2 + d(2).^2).^(-2);
expr183 = (c(2).^2 + d(2).^2).^2 + w1.^2.*(w1.^2 + 2.*(c(2).^2 - d(2).^2));
expr184 = (c(3).^2 + d(3).^2).^(-2);
expr185 = (c(3).^2 + d(3).^2).^2 + w1.^2.*(w1.^2 + 2.*(c(3).^2 - d(3).^2));
expr186 = (c(4).^2 + d(4).^2).^(-2);
expr187 = (c(4).^2 + d(4).^2).^2 + w1.^2.*(w1.^2 + 2.*(c(4).^2 - d(4).^2));
expr188 = expr172.*expr173.*expr174.*expr175.*expr176.*expr177.*expr178.*expr179.*expr180.*expr181.*expr182.*expr183.*expr184.*expr185.*expr186.*expr187;
integrate1 = trapz(w1, expr188);
w2 = [0:wp./100:wp];
expr189 = a(1).^2 + b(1).^2;
expr190 = a(2).^2 + b(2).^2;
expr191 = a(3).^2 + b(3).^2;
expr192 = a(4).^2 + b(4).^2;
expr193 = (a(1).^2 + b(1).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(1).^2 - b(1).^2));
expr194 = (a(2).^2 + b(2).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(2).^2 - b(2).^2));
expr195 = (a(3).^2 + b(3).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(3).^2 - b(3).^2));
expr196 = (a(4).^2 + b(4).^2).^2 + w2.^2.*(w2.^2 + 2.*(a(4).^2 - b(4).^2));
expr197 = -1./2;
expr198 = (c(1).^2 + d(1).^2).^(-1);
expr199 = (c(2).^2 + d(2).^2).^(-1);
expr200 = (c(3).^2 + d(3).^2).^(-1);
expr201 = (c(4).^2 + d(4).^2).^(-1);
expr202 = (c(1).^2 + d(1).^2).^2 + w2.^2.*(w2.^2 + 2.*(c(1).^2 - d(1).^2));
expr203 = (c(2).^2 + d(2).^2).^2 + w2.^2.*(w2.^2 + 2.*(c(2).^2 - d(2).^2));
expr204 = (c(3).^2 + d(3).^2).^2 + w2.^2.*(w2.^2 + 2.*(c(3).^2 - d(3).^2));
expr205 = (c(4).^2 + d(4).^2).^2 + w2.^2.*(w2.^2 + 2.*(c(4).^2 - d(4).^2));
expr206 = 1./2;
expr207 = (-1 + expr189.*expr190.*expr191.*expr192.*(expr193.*expr194.*expr195.*expr196).^expr197.*expr198.*expr199.*expr200.*expr201.*(expr202.*expr203.*expr204.*expr205).^expr206).^2;
integrate2 = trapz(w2, expr207);
w3 = [wp:(-wp + ws)./100:ws];
expr208 = -(w3./(wp - ws));
expr209 = ws./(wp - ws);
expr210 = a(1).^2 + b(1).^2;
expr211 = a(2).^2 + b(2).^2;
expr212 = a(3).^2 + b(3).^2;
expr213 = a(4).^2 + b(4).^2;
expr214 = (a(1).^2 + b(1).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(1).^2 - b(1).^2));
expr215 = (a(2).^2 + b(2).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(2).^2 - b(2).^2));
expr216 = (a(3).^2 + b(3).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(3).^2 - b(3).^2));
expr217 = (a(4).^2 + b(4).^2).^2 + w3.^2.*(w3.^2 + 2.*(a(4).^2 - b(4).^2));
expr218 = -1./2;
expr219 = (c(1).^2 + d(1).^2).^(-1);
expr220 = (c(2).^2 + d(2).^2).^(-1);
expr221 = (c(3).^2 + d(3).^2).^(-1);
expr222 = (c(4).^2 + d(4).^2).^(-1);
expr223 = (c(1).^2 + d(1).^2).^2 + w3.^2.*(w3.^2 + 2.*(c(1).^2 - d(1).^2));
expr224 = (c(2).^2 + d(2).^2).^2 + w3.^2.*(w3.^2 + 2.*(c(2).^2 - d(2).^2));
expr225 = (c(3).^2 + d(3).^2).^2 + w3.^2.*(w3.^2 + 2.*(c(3).^2 - d(3).^2));
expr226 = (c(4).^2 + d(4).^2).^2 + w3.^2.*(w3.^2 + 2.*(c(4).^2 - d(4).^2));
expr227 = 1./2;
expr228 = (expr208 + expr209 + expr210.*expr211.*expr212.*expr213.*(expr214.*expr215.*expr216.*expr217).^expr218.*expr219.*expr220.*expr221.*expr222.*(expr223.*expr224.*expr225.*expr226).^expr227).^2;
integrate3 = trapz(w3, expr228);
w4 = [0:wmax./100:wmax];
expr229 = angle(1 + (i.*(w4 - b(1)))./a(1));
expr230 = angle(1 + (i.*(w4 + b(1)))./a(1));
expr231 = angle(1 + (i.*(w4 - b(2)))./a(2));
expr232 = angle(1 + (i.*(w4 + b(2)))./a(2));
expr233 = angle(1 + (i.*(w4 - b(3)))./a(3));
expr234 = angle(1 + (i.*(w4 + b(3)))./a(3));
expr235 = angle(1 + (i.*(w4 - b(4)))./a(4));
expr236 = angle(1 + (i.*(w4 + b(4)))./a(4));
expr237 = -angle(1 + (i.*(w4 - d(1)))./c(1));
expr238 = -angle(1 + (i.*(w4 + d(1)))./c(1));
expr239 = -angle(1 + (i.*(w4 - d(2)))./c(2));
expr240 = -angle(1 + (i.*(w4 + d(2)))./c(2));
expr241 = -angle(1 + (i.*(w4 - d(3)))./c(3));
expr242 = -angle(1 + (i.*(w4 + d(3)))./c(3));
expr243 = -angle(1 + (i.*(w4 - d(4)))./c(4));
expr244 = -angle(1 + (i.*(w4 + d(4)))./c(4));
expr245 = wmax.^(-3);
expr246 = 1./2;
expr247 = -2.*wmax.*a(1);
expr248 = angle(1 + (i.*(wmax - b(1)))./a(1)) + angle(1 + (i.*(wmax + b(1)))./a(1));
expr249 = -wmax.^2 - a(1).^2 + b(1).^2;
expr250 = -(a(1).*b(1).*log(1 + (wmax - b(1)).^2./a(1).^2));
expr251 = a(1).*b(1).*log(1 + (wmax + b(1)).^2./a(1).^2);
expr252 = -2.*wmax.*a(2);
expr253 = angle(1 + (i.*(wmax - b(2)))./a(2)) + angle(1 + (i.*(wmax + b(2)))./a(2));
expr254 = -wmax.^2 - a(2).^2 + b(2).^2;
expr255 = -(a(2).*b(2).*log(1 + (wmax - b(2)).^2./a(2).^2));
expr256 = a(2).*b(2).*log(1 + (wmax + b(2)).^2./a(2).^2);
expr257 = -2.*wmax.*a(3);
expr258 = angle(1 + (i.*(wmax - b(3)))./a(3)) + angle(1 + (i.*(wmax + b(3)))./a(3));
expr259 = -wmax.^2 - a(3).^2 + b(3).^2;
expr260 = -(a(3).*b(3).*log(1 + (wmax - b(3)).^2./a(3).^2));
expr261 = a(3).*b(3).*log(1 + (wmax + b(3)).^2./a(3).^2);
expr262 = -2.*wmax.*a(4);
expr263 = angle(1 + (i.*(wmax - b(4)))./a(4)) + angle(1 + (i.*(wmax + b(4)))./a(4));
expr264 = -wmax.^2 - a(4).^2 + b(4).^2;
expr265 = -(a(4).*b(4).*log(1 + (wmax - b(4)).^2./a(4).^2));
expr266 = a(4).*b(4).*log(1 + (wmax + b(4)).^2./a(4).^2);
expr267 = 2.*wmax.*c(1);
expr268 = angle(1 + (i.*(wmax - d(1)))./c(1)) + angle(1 + (i.*(wmax + d(1)))./c(1));
expr269 = -wmax.^2 - c(1).^2 + d(1).^2;
expr270 = c(1).*d(1).*log(1 + (wmax - d(1)).^2./c(1).^2);
expr271 = -(c(1).*d(1).*log(1 + (wmax + d(1)).^2./c(1).^2));
expr272 = 2.*wmax.*c(2);
expr273 = angle(1 + (i.*(wmax - d(2)))./c(2)) + angle(1 + (i.*(wmax + d(2)))./c(2));
expr274 = -wmax.^2 - c(2).^2 + d(2).^2;
expr275 = c(2).*d(2).*log(1 + (wmax - d(2)).^2./c(2).^2);
expr276 = -(c(2).*d(2).*log(1 + (wmax + d(2)).^2./c(2).^2));
expr277 = 2.*wmax.*c(3);
expr278 = angle(1 + (i.*(wmax - d(3)))./c(3)) + angle(1 + (i.*(wmax + d(3)))./c(3));
expr279 = -wmax.^2 - c(3).^2 + d(3).^2;
expr280 = c(3).*d(3).*log(1 + (wmax - d(3)).^2./c(3).^2);
expr281 = -(c(3).*d(3).*log(1 + (wmax + d(3)).^2./c(3).^2));
expr282 = 2.*wmax.*c(4);
expr283 = angle(1 + (i.*(wmax - d(4)))./c(4)) + angle(1 + (i.*(wmax + d(4)))./c(4));
expr284 = -wmax.^2 - c(4).^2 + d(4).^2;
expr285 = c(4).*d(4).*log(1 + (wmax - d(4)).^2./c(4).^2);
expr286 = -(c(4).*d(4).*log(1 + (wmax + d(4)).^2./c(4).^2));
expr287 = expr246.*(expr247 - expr248.*expr249 + expr250 + expr251);
expr288 = expr246.*(expr252 - expr253.*expr254 + expr255 + expr256);
expr289 = expr246.*(expr257 - expr258.*expr259 + expr260 + expr261);
expr290 = expr246.*(expr262 - expr263.*expr264 + expr265 + expr266);
expr291 = expr246.*(expr267 + expr268.*expr269 + expr270 + expr271);
expr292 = expr246.*(expr272 + expr273.*expr274 + expr275 + expr276);
expr293 = expr246.*(expr277 + expr278.*expr279 + expr280 + expr281);
expr294 = expr246.*(expr282 + expr283.*expr284 + expr285 + expr286);
expr295 = (expr229 + expr230 + expr231 + expr232 + expr233 + expr234 + expr235 + expr236 + expr237 + expr238 + expr239 + expr240 + expr241 + expr242 + expr243 + expr244 - 3.*expr245.*(expr287 + expr288 + expr289 + expr290 + expr291 + expr292 + expr293 + expr294).*w4).^2;
integrate4 = trapz(w4, expr295);
expr296 = (integrate2.*Wmp)./wp;
expr297 = (integrate4.*Wph)./wmax;
expr298 = (integrate1.*Wms)./(99.*ws);
expr299 = (integrate3.*Wmt)./(-wp + ws);
expr300 = 1./2;
expr301 = a(1).^(-1);
expr302 = a(2).^(-1);
expr303 = a(3).^(-1);
expr304 = a(4).^(-1);
expr305 = sqrt(a(1).^2 + b(1).^2);
expr306 = sqrt(a(2).^2 + b(2).^2);
expr307 = sqrt(a(3).^2 + b(3).^2);
expr308 = sqrt(a(4).^2 + b(4).^2);
expr309 = 1./4;
expr310 = b(1).^(-1);
expr311 = a(2).^2 + b(2).^2;
expr312 = a(3).^2 + b(3).^2;
expr313 = a(4).^2 + b(4).^2;
expr314 = (a(1) - a(2)).^2 + (b(1) - b(2)).^2;
expr315 = (a(1) - a(2)).^2 + (b(1) + b(2)).^2;
expr316 = (a(1) - a(3)).^2 + (b(1) - b(3)).^2;
expr317 = (a(1) - a(3)).^2 + (b(1) + b(3)).^2;
expr318 = (a(1) - a(4)).^2 + (b(1) - b(4)).^2;
expr319 = (a(1) - a(4)).^2 + (b(1) + b(4)).^2;
expr320 = -1./2;
expr321 = (c(1).^2 + d(1).^2).^(-1);
expr322 = (c(2).^2 + d(2).^2).^(-1);
expr323 = (c(3).^2 + d(3).^2).^(-1);
expr324 = (c(4).^2 + d(4).^2).^(-1);
expr325 = (a(1) - c(1)).^2 + (b(1) - d(1)).^2;
expr326 = (a(1) - c(1)).^2 + (b(1) + d(1)).^2;
expr327 = (a(1) - c(2)).^2 + (b(1) - d(2)).^2;
expr328 = (a(1) - c(2)).^2 + (b(1) + d(2)).^2;
expr329 = (a(1) - c(3)).^2 + (b(1) - d(3)).^2;
expr330 = (a(1) - c(3)).^2 + (b(1) + d(3)).^2;
expr331 = (a(1) - c(4)).^2 + (b(1) - d(4)).^2;
expr332 = (a(1) - c(4)).^2 + (b(1) + d(4)).^2;
expr333 = b(1);
expr334 = angle(1 + (i.*(b(1) - b(2)))./(a(1) - a(2)));
expr335 = angle(1 + (i.*(b(1) + b(2)))./(a(1) - a(2)));
expr336 = angle(1 + (i.*(b(1) - b(3)))./(a(1) - a(3)));
expr337 = angle(1 + (i.*(b(1) + b(3)))./(a(1) - a(3)));
expr338 = angle(1 + (i.*(b(1) - b(4)))./(a(1) - a(4)));
expr339 = angle(1 + (i.*(b(1) + b(4)))./(a(1) - a(4)));
expr340 = -angle(1 + (i.*(b(1) - d(1)))./(a(1) - c(1)));
expr341 = -angle(1 + (i.*(b(1) + d(1)))./(a(1) - c(1)));
expr342 = -angle(1 + (i.*(b(1) - d(2)))./(a(1) - c(2)));
expr343 = -angle(1 + (i.*(b(1) + d(2)))./(a(1) - c(2)));
expr344 = -angle(1 + (i.*(b(1) - d(3)))./(a(1) - c(3)));
expr345 = -angle(1 + (i.*(b(1) + d(3)))./(a(1) - c(3)));
expr346 = -angle(1 + (i.*(b(1) - d(4)))./(a(1) - c(4)));
expr347 = -angle(1 + (i.*(b(1) + d(4)))./(a(1) - c(4)));
expr348 = a(1);
expr349 = exp(tpeak1.*a(1));
expr350 = cos(tpeak1.*b(1));
expr351 = a(1).^2 + b(1).^2;
expr352 = sin(tpeak1.*b(1));
expr353 = b(2).^(-1);
expr354 = (-a(1) + a(2)).^2 + (-b(1) + b(2)).^2;
expr355 = (-a(1) + a(2)).^2 + (b(1) + b(2)).^2;
expr356 = (a(2) - a(3)).^2 + (b(2) - b(3)).^2;
expr357 = (a(2) - a(3)).^2 + (b(2) + b(3)).^2;
expr358 = (a(2) - a(4)).^2 + (b(2) - b(4)).^2;
expr359 = (a(2) - a(4)).^2 + (b(2) + b(4)).^2;
expr360 = (a(2) - c(1)).^2 + (b(2) - d(1)).^2;
expr361 = (a(2) - c(1)).^2 + (b(2) + d(1)).^2;
expr362 = (a(2) - c(2)).^2 + (b(2) - d(2)).^2;
expr363 = (a(2) - c(2)).^2 + (b(2) + d(2)).^2;
expr364 = (a(2) - c(3)).^2 + (b(2) - d(3)).^2;
expr365 = (a(2) - c(3)).^2 + (b(2) + d(3)).^2;
expr366 = (a(2) - c(4)).^2 + (b(2) - d(4)).^2;
expr367 = (a(2) - c(4)).^2 + (b(2) + d(4)).^2;
expr368 = b(2);
expr369 = angle(1 + (i.*(-b(1) + b(2)))./(-a(1) + a(2)));
expr370 = angle(1 + (i.*(b(1) + b(2)))./(-a(1) + a(2)));
expr371 = angle(1 + (i.*(b(2) - b(3)))./(a(2) - a(3)));
expr372 = angle(1 + (i.*(b(2) + b(3)))./(a(2) - a(3)));
expr373 = angle(1 + (i.*(b(2) - b(4)))./(a(2) - a(4)));
expr374 = angle(1 + (i.*(b(2) + b(4)))./(a(2) - a(4)));
expr375 = -angle(1 + (i.*(b(2) - d(1)))./(a(2) - c(1)));
expr376 = -angle(1 + (i.*(b(2) + d(1)))./(a(2) - c(1)));
expr377 = -angle(1 + (i.*(b(2) - d(2)))./(a(2) - c(2)));
expr378 = -angle(1 + (i.*(b(2) + d(2)))./(a(2) - c(2)));
expr379 = -angle(1 + (i.*(b(2) - d(3)))./(a(2) - c(3)));
expr380 = -angle(1 + (i.*(b(2) + d(3)))./(a(2) - c(3)));
expr381 = -angle(1 + (i.*(b(2) - d(4)))./(a(2) - c(4)));
expr382 = -angle(1 + (i.*(b(2) + d(4)))./(a(2) - c(4)));
expr383 = a(2);
expr384 = exp(tpeak1.*a(2));
expr385 = cos(tpeak1.*b(2));
expr386 = sin(tpeak1.*b(2));
expr387 = b(3).^(-1);
expr388 = (-a(1) + a(3)).^2 + (-b(1) + b(3)).^2;
expr389 = (-a(1) + a(3)).^2 + (b(1) + b(3)).^2;
expr390 = (-a(2) + a(3)).^2 + (-b(2) + b(3)).^2;
expr391 = (-a(2) + a(3)).^2 + (b(2) + b(3)).^2;
expr392 = (a(3) - a(4)).^2 + (b(3) - b(4)).^2;
expr393 = (a(3) - a(4)).^2 + (b(3) + b(4)).^2;
expr394 = (a(3) - c(1)).^2 + (b(3) - d(1)).^2;
expr395 = (a(3) - c(1)).^2 + (b(3) + d(1)).^2;
expr396 = (a(3) - c(2)).^2 + (b(3) - d(2)).^2;
expr397 = (a(3) - c(2)).^2 + (b(3) + d(2)).^2;
expr398 = (a(3) - c(3)).^2 + (b(3) - d(3)).^2;
expr399 = (a(3) - c(3)).^2 + (b(3) + d(3)).^2;
expr400 = (a(3) - c(4)).^2 + (b(3) - d(4)).^2;
expr401 = (a(3) - c(4)).^2 + (b(3) + d(4)).^2;
expr402 = b(3);
expr403 = angle(1 + (i.*(-b(1) + b(3)))./(-a(1) + a(3)));
expr404 = angle(1 + (i.*(b(1) + b(3)))./(-a(1) + a(3)));
expr405 = angle(1 + (i.*(-b(2) + b(3)))./(-a(2) + a(3)));
expr406 = angle(1 + (i.*(b(2) + b(3)))./(-a(2) + a(3)));
expr407 = angle(1 + (i.*(b(3) - b(4)))./(a(3) - a(4)));
expr408 = angle(1 + (i.*(b(3) + b(4)))./(a(3) - a(4)));
expr409 = -angle(1 + (i.*(b(3) - d(1)))./(a(3) - c(1)));
expr410 = -angle(1 + (i.*(b(3) + d(1)))./(a(3) - c(1)));
expr411 = -angle(1 + (i.*(b(3) - d(2)))./(a(3) - c(2)));
expr412 = -angle(1 + (i.*(b(3) + d(2)))./(a(3) - c(2)));
expr413 = -angle(1 + (i.*(b(3) - d(3)))./(a(3) - c(3)));
expr414 = -angle(1 + (i.*(b(3) + d(3)))./(a(3) - c(3)));
expr415 = -angle(1 + (i.*(b(3) - d(4)))./(a(3) - c(4)));
expr416 = -angle(1 + (i.*(b(3) + d(4)))./(a(3) - c(4)));
expr417 = a(3);
expr418 = exp(tpeak1.*a(3));
expr419 = cos(tpeak1.*b(3));
expr420 = sin(tpeak1.*b(3));
expr421 = b(4).^(-1);
expr422 = (-a(1) + a(4)).^2 + (-b(1) + b(4)).^2;
expr423 = (-a(1) + a(4)).^2 + (b(1) + b(4)).^2;
expr424 = (-a(2) + a(4)).^2 + (-b(2) + b(4)).^2;
expr425 = (-a(2) + a(4)).^2 + (b(2) + b(4)).^2;
expr426 = (-a(3) + a(4)).^2 + (-b(3) + b(4)).^2;
expr427 = (-a(3) + a(4)).^2 + (b(3) + b(4)).^2;
expr428 = (a(4) - c(1)).^2 + (b(4) - d(1)).^2;
expr429 = (a(4) - c(1)).^2 + (b(4) + d(1)).^2;
expr430 = (a(4) - c(2)).^2 + (b(4) - d(2)).^2;
expr431 = (a(4) - c(2)).^2 + (b(4) + d(2)).^2;
expr432 = (a(4) - c(3)).^2 + (b(4) - d(3)).^2;
expr433 = (a(4) - c(3)).^2 + (b(4) + d(3)).^2;
expr434 = (a(4) - c(4)).^2 + (b(4) - d(4)).^2;
expr435 = (a(4) - c(4)).^2 + (b(4) + d(4)).^2;
expr436 = b(4);
expr437 = angle(1 + (i.*(-b(1) + b(4)))./(-a(1) + a(4)));
expr438 = angle(1 + (i.*(b(1) + b(4)))./(-a(1) + a(4)));
expr439 = angle(1 + (i.*(-b(2) + b(4)))./(-a(2) + a(4)));
expr440 = angle(1 + (i.*(b(2) + b(4)))./(-a(2) + a(4)));
expr441 = angle(1 + (i.*(-b(3) + b(4)))./(-a(3) + a(4)));
expr442 = angle(1 + (i.*(b(3) + b(4)))./(-a(3) + a(4)));
expr443 = -angle(1 + (i.*(b(4) - d(1)))./(a(4) - c(1)));
expr444 = -angle(1 + (i.*(b(4) + d(1)))./(a(4) - c(1)));
expr445 = -angle(1 + (i.*(b(4) - d(2)))./(a(4) - c(2)));
expr446 = -angle(1 + (i.*(b(4) + d(2)))./(a(4) - c(2)));
expr447 = -angle(1 + (i.*(b(4) - d(3)))./(a(4) - c(3)));
expr448 = -angle(1 + (i.*(b(4) + d(3)))./(a(4) - c(3)));
expr449 = -angle(1 + (i.*(b(4) - d(4)))./(a(4) - c(4)));
expr450 = -angle(1 + (i.*(b(4) + d(4)))./(a(4) - c(4)));
expr451 = a(4);
expr452 = exp(tpeak1.*a(4));
expr453 = cos(tpeak1.*b(4));
expr454 = sin(tpeak1.*b(4));
expr455 = (-0.5 + expr300.*(expr301.*expr302.*expr303.*expr304.*expr305.*expr306.*expr307.*expr308).^expr309).*WQ;
expr456 = (expr314.*expr315.*expr316.*expr317.*expr318.*expr319).^expr320;
expr457 = (expr325.*expr326.*expr327.*expr328.*expr329.*expr330.*expr331.*expr332).^expr300;
expr458 = expr333.*cos(expr334 + expr335 + expr336 + expr337 + expr338 + expr339 + expr340 + expr341 + expr342 + expr343 + expr344 + expr345 + expr346 + expr347) + expr348.*sin(expr334 + expr335 + expr336 + expr337 + expr338 + expr339 + expr340 + expr341 + expr342 + expr343 + expr344 + expr345 + expr346 + expr347);
expr459 = sin(expr334 + expr335 + expr336 + expr337 + expr338 + expr339 + expr340 + expr341 + expr342 + expr343 + expr344 + expr345 + expr346 + expr347);
expr460 = (expr333.*cos(expr334 + expr335 + expr336 + expr337 + expr338 + expr339 + expr340 + expr341 + expr342 + expr343 + expr344 + expr345 + expr346 + expr347) + expr348.*sin(expr334 + expr335 + expr336 + expr337 + expr338 + expr339 + expr340 + expr341 + expr342 + expr343 + expr344 + expr345 + expr346 + expr347)).^(-1);
expr461 = (expr354.*expr355.*expr356.*expr357.*expr358.*expr359).^expr320;
expr462 = (expr360.*expr361.*expr362.*expr363.*expr364.*expr365.*expr366.*expr367).^expr300;
expr463 = expr368.*cos(expr369 + expr370 + expr371 + expr372 + expr373 + expr374 + expr375 + expr376 + expr377 + expr378 + expr379 + expr380 + expr381 + expr382) + expr383.*sin(expr369 + expr370 + expr371 + expr372 + expr373 + expr374 + expr375 + expr376 + expr377 + expr378 + expr379 + expr380 + expr381 + expr382);
expr464 = sin(expr369 + expr370 + expr371 + expr372 + expr373 + expr374 + expr375 + expr376 + expr377 + expr378 + expr379 + expr380 + expr381 + expr382);
expr465 = (expr368.*cos(expr369 + expr370 + expr371 + expr372 + expr373 + expr374 + expr375 + expr376 + expr377 + expr378 + expr379 + expr380 + expr381 + expr382) + expr383.*sin(expr369 + expr370 + expr371 + expr372 + expr373 + expr374 + expr375 + expr376 + expr377 + expr378 + expr379 + expr380 + expr381 + expr382)).^(-1);
expr466 = (expr388.*expr389.*expr390.*expr391.*expr392.*expr393).^expr320;
expr467 = (expr394.*expr395.*expr396.*expr397.*expr398.*expr399.*expr400.*expr401).^expr300;
expr468 = expr402.*cos(expr403 + expr404 + expr405 + expr406 + expr407 + expr408 + expr409 + expr410 + expr411 + expr412 + expr413 + expr414 + expr415 + expr416) + expr417.*sin(expr403 + expr404 + expr405 + expr406 + expr407 + expr408 + expr409 + expr410 + expr411 + expr412 + expr413 + expr414 + expr415 + expr416);
expr469 = sin(expr403 + expr404 + expr405 + expr406 + expr407 + expr408 + expr409 + expr410 + expr411 + expr412 + expr413 + expr414 + expr415 + expr416);
expr470 = (expr402.*cos(expr403 + expr404 + expr405 + expr406 + expr407 + expr408 + expr409 + expr410 + expr411 + expr412 + expr413 + expr414 + expr415 + expr416) + expr417.*sin(expr403 + expr404 + expr405 + expr406 + expr407 + expr408 + expr409 + expr410 + expr411 + expr412 + expr413 + expr414 + expr415 + expr416)).^(-1);
expr471 = (expr422.*expr423.*expr424.*expr425.*expr426.*expr427).^expr320;
expr472 = (expr428.*expr429.*expr430.*expr431.*expr432.*expr433.*expr434.*expr435).^expr300;
expr473 = expr436.*cos(expr437 + expr438 + expr439 + expr440 + expr441 + expr442 + expr443 + expr444 + expr445 + expr446 + expr447 + expr448 + expr449 + expr450) + expr451.*sin(expr437 + expr438 + expr439 + expr440 + expr441 + expr442 + expr443 + expr444 + expr445 + expr446 + expr447 + expr448 + expr449 + expr450);
expr474 = sin(expr437 + expr438 + expr439 + expr440 + expr441 + expr442 + expr443 + expr444 + expr445 + expr446 + expr447 + expr448 + expr449 + expr450);
expr475 = (expr436.*cos(expr437 + expr438 + expr439 + expr440 + expr441 + expr442 + expr443 + expr444 + expr445 + expr446 + expr447 + expr448 + expr449 + expr450) + expr451.*sin(expr437 + expr438 + expr439 + expr440 + expr441 + expr442 + expr443 + expr444 + expr445 + expr446 + expr447 + expr448 + expr449 + expr450)).^(-1);
expr476 = expr310.*expr311.*expr312.*expr313.*expr321.*expr322.*expr323.*expr324.*expr456.*expr457.*expr458.*(1 - expr349.*(expr350 - expr310.*expr352.*(expr348 - expr351.*expr459.*expr460)));
expr477 = expr312.*expr313.*expr321.*expr322.*expr323.*expr324.*expr351.*expr353.*expr461.*expr462.*expr463.*(1 - expr384.*(expr385 - expr353.*expr386.*(expr383 - expr311.*expr464.*expr465)));
expr478 = expr311.*expr313.*expr321.*expr322.*expr323.*expr324.*expr351.*expr387.*expr466.*expr467.*expr468.*(1 - expr418.*(expr419 - expr387.*expr420.*(expr417 - expr312.*expr469.*expr470)));
expr479 = expr311.*expr312.*expr321.*expr322.*expr323.*expr324.*expr351.*expr421.*expr471.*expr472.*expr473.*(1 - expr452.*(expr453 - expr421.*expr454.*(expr451 - expr313.*expr474.*expr475)));
expr480 = expr296 + expr297 + expr298 + expr299 + expr455 + 100.*(-1 + expr476 + expr477 + expr478 + expr479).^2.*WO;
f = expr480;

%% Debugging code
global numtimes weights;
weights = weights + [ (integrate1.*Wms)./(99.*ws) (integrate2.*Wmp)./wp (integrate3.*Wmt)./(-wp + ws) (integrate4.*Wph)./wmax ] / f;
numtimes = numtimes + 1;

end
