(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    137021,       4888]*)
(*NotebookOutlinePosition[    137826,       4916]*)
(*  CellTagsIndexPosition[    137782,       4912]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Optimization of Analog Filters with Poles and Zeroes", "Title"],

Cell["\<\
Niranjan Damera-Venkata and
Brian L. Evans\
\>", "Subtitle"],

Cell["\<\
Embedded Signal Processing Laboratory
Department of Electrical and Computer Engineering
The University of Texas at Austin
Austin, Texas 78712-1084\
\>", "Subsubtitle"],

Cell["http://anchovy.ece.utexas.edu", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell["Add the filter optimization packages to the path.", "Text"],

Cell[BoxData[
    \(\(AppendTo[$Path, \ "\<../Packages\>"]; \)\)], "Input",
  InitializationCell->True],

Cell["Initialize the filter optimization packages.", "Text"],

Cell[BoxData[
    \(\(Needs[\ "\<FilterOptimization`Master`\>"\ ]; \)\)], "Input",
  InitializationCell->True],

Cell["\<\
Clear several global variables.  You can ignore the two spell error \
warnings.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Clear[\ Wmp, \ Wmt, \ Wms, \ Wph, \ WQ, \ WO, \ a, \ b, \ c, \ d, \ 
      wp, \ ws, \ wmax, \ maxO, \ dp, \ ds\ ]; \)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(General::"spell1" \( : \ \) 
      "Possible spelling error: new symbol name \"\!\(wmax\)\" is similar to \
existing symbol \"\!\(max\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \( : \ \) 
      "Possible spelling error: new symbol name \"\!\(maxO\)\" is similar to \
existing symbol \"\!\(max\)\"."\)], "Message"]
}, Open  ]],

Cell[BoxData[
    \(\(Begin["\<FilterOptimization`Generator`Private`\>"]; \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Example", "Section"],

Cell["\<\
The subscript 1 denotes the original analog Butterworth filter \
whose behavior is plotted in dashed lines.  The subscript2 denotes the \
all-pole filter simultaneously optimized for step response and linear phase \
over the passed, whose behavior is plotted in solid lines.  This example \
comexs from the following paper:\
\>", "Text"],

Cell[TextData[{
  "N. Damera-Venkata, B. L. Evans, M. D. Lutovac, and D. V. Tosic, \"Joint \
Optimization of Multiple Behavioral and Implementation Properties of Analog \
Filter Designs\", ",
  StyleBox["Proc. IEEE Int. Sym. on  Circuits and Systems",
    FontSlant->"Italic"],
  ", Monterey, CA, May 31 - Jun. 3, 1998, vol. 6, pp. 286-289. \
http://www.ece.utexas.edu/~bevans/papers/1998/filter_optimization/"
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Defining the order of the filter and the pole and zero \
locations\
\>", "Subsection"],

Cell["\<\
The variable n represents the number of pole pairs, and m denotes \
the number of zero pairs in the analog filter.\
\>", "Text"],

Cell[BoxData[
    \(n\  = \ 2; \nm\  = \ 2; \)], "Input",
  InitializationCell->True],

Cell["\<\
The pole pairs are r[1] +/- I i[1] and r[2] +/- I i[2].  The zero \
pairs are c[1] +/- I d[1] and c[2] +/- d[2].\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(polesZeroes1
       = {r[1] -> \(-5.3553\), i[1] -> \ \(-16.9547\), r[2] -> \(-.1636\), 
        i[2] -> \(-19.9899\), c[1] -> \(-0.0000001\), d[1] -> \(-20.2479\), 
        c[2] -> \(-0.0000001\), d[2] -> \(-28.0184\)}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{\(r[1]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["5.35529999999999972`",
              StyleBoxAutoDelete->True,
              PrintPrecision->5]}]}], ",", 
        RowBox[{\(i[1]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["16.9546999999999981`",
              StyleBoxAutoDelete->True,
              PrintPrecision->6]}]}], ",", 
        RowBox[{\(r[2]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["0.163599999999999994`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}]}], ",", 
        RowBox[{\(i[2]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["19.9898999999999986`",
              StyleBoxAutoDelete->True,
              PrintPrecision->6]}]}], ",", 
        RowBox[{\(c[1]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["1.`*^-7",
              StyleBoxAutoDelete->True,
              PrintPrecision->1]}]}], ",", 
        RowBox[{\(d[1]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["20.2479000000000031`",
              StyleBoxAutoDelete->True,
              PrintPrecision->6]}]}], ",", 
        RowBox[{\(c[2]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["1.`*^-7",
              StyleBoxAutoDelete->True,
              PrintPrecision->1]}]}], ",", 
        RowBox[{\(d[2]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["28.0183999999999997`",
              StyleBoxAutoDelete->True,
              PrintPrecision->6]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(polesZeroes2\ 
       = {r[1] -> \(-11.4343\), i[1] -> \(-10.5092\), r[2] -> \(-1.0926\), 
        i[2] -> \(-21.8241\), c[1] -> \(-3.4232\), d[1] -> \(-28.6856\), 
        c[2] -> \(-1.2725\), d[2] -> \(-35.5476\)}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{\(r[1]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["11.4342999999999994`",
              StyleBoxAutoDelete->True,
              PrintPrecision->6]}]}], ",", 
        RowBox[{\(i[1]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["10.5092000000000007`",
              StyleBoxAutoDelete->True,
              PrintPrecision->6]}]}], ",", 
        RowBox[{\(r[2]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["1.09260000000000001`",
              StyleBoxAutoDelete->True,
              PrintPrecision->5]}]}], ",", 
        RowBox[{\(i[2]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["21.8240999999999996`",
              StyleBoxAutoDelete->True,
              PrintPrecision->6]}]}], ",", 
        RowBox[{\(c[1]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["3.42320000000000002`",
              StyleBoxAutoDelete->True,
              PrintPrecision->5]}]}], ",", 
        RowBox[{\(d[1]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["28.6856000000000008`",
              StyleBoxAutoDelete->True,
              PrintPrecision->6]}]}], ",", 
        RowBox[{\(c[2]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["1.27249999999999996`",
              StyleBoxAutoDelete->True,
              PrintPrecision->5]}]}], ",", 
        RowBox[{\(d[2]\), "\[Rule]", 
          RowBox[{"-", 
            StyleBox["35.5476000000000036`",
              StyleBoxAutoDelete->True,
              PrintPrecision->6]}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnitude response", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(magnitudeResponsePZ1\  = \ 
      Plot[\((20\ Log[10, magnitude[r\ , i\ , c\ , d\ , n\ , m\ , \ w]]\  /. 
            \ polesZeroes1)\), {w, 0, 100}, 
        PlotStyle -> {Dashing[{.02, .02}]}]; \)\)], "Input",
  InitializationCell->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0145009 0.583461 0.00969904 [
[.16882 .57096 -6 -9 ]
[.16882 .57096 6 0 ]
[.31383 .57096 -6 -9 ]
[.31383 .57096 6 0 ]
[.45884 .57096 -6 -9 ]
[.45884 .57096 6 0 ]
[.60385 .57096 -6 -9 ]
[.60385 .57096 6 0 ]
[.74886 .57096 -6 -9 ]
[.74886 .57096 6 0 ]
[.89387 .57096 -6 -9 ]
[.89387 .57096 6 0 ]
[.01131 .00152 -18 -4.5 ]
[.01131 .00152 0 4.5 ]
[.01131 .09851 -18 -4.5 ]
[.01131 .09851 0 4.5 ]
[.01131 .1955 -18 -4.5 ]
[.01131 .1955 0 4.5 ]
[.01131 .29249 -18 -4.5 ]
[.01131 .29249 0 4.5 ]
[.01131 .38948 -18 -4.5 ]
[.01131 .38948 0 4.5 ]
[.01131 .48647 -18 -4.5 ]
[.01131 .48647 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16882 .58346 m
.16882 .58971 L
s
[(10)] .16882 .57096 0 1 Mshowa
.31383 .58346 m
.31383 .58971 L
s
[(20)] .31383 .57096 0 1 Mshowa
.45884 .58346 m
.45884 .58971 L
s
[(30)] .45884 .57096 0 1 Mshowa
.60385 .58346 m
.60385 .58971 L
s
[(40)] .60385 .57096 0 1 Mshowa
.74886 .58346 m
.74886 .58971 L
s
[(50)] .74886 .57096 0 1 Mshowa
.89387 .58346 m
.89387 .58971 L
s
[(60)] .89387 .57096 0 1 Mshowa
.125 Mabswid
.05281 .58346 m
.05281 .58721 L
s
.08181 .58346 m
.08181 .58721 L
s
.11082 .58346 m
.11082 .58721 L
s
.13982 .58346 m
.13982 .58721 L
s
.19782 .58346 m
.19782 .58721 L
s
.22682 .58346 m
.22682 .58721 L
s
.25582 .58346 m
.25582 .58721 L
s
.28483 .58346 m
.28483 .58721 L
s
.34283 .58346 m
.34283 .58721 L
s
.37183 .58346 m
.37183 .58721 L
s
.40083 .58346 m
.40083 .58721 L
s
.42984 .58346 m
.42984 .58721 L
s
.48784 .58346 m
.48784 .58721 L
s
.51684 .58346 m
.51684 .58721 L
s
.54584 .58346 m
.54584 .58721 L
s
.57485 .58346 m
.57485 .58721 L
s
.63285 .58346 m
.63285 .58721 L
s
.66185 .58346 m
.66185 .58721 L
s
.69085 .58346 m
.69085 .58721 L
s
.71986 .58346 m
.71986 .58721 L
s
.77786 .58346 m
.77786 .58721 L
s
.80686 .58346 m
.80686 .58721 L
s
.83586 .58346 m
.83586 .58721 L
s
.86486 .58346 m
.86486 .58721 L
s
.92287 .58346 m
.92287 .58721 L
s
.95187 .58346 m
.95187 .58721 L
s
.98087 .58346 m
.98087 .58721 L
s
.25 Mabswid
0 .58346 m
1 .58346 L
s
.02381 .00152 m
.03006 .00152 L
s
[(-60)] .01131 .00152 1 0 Mshowa
.02381 .09851 m
.03006 .09851 L
s
[(-50)] .01131 .09851 1 0 Mshowa
.02381 .1955 m
.03006 .1955 L
s
[(-40)] .01131 .1955 1 0 Mshowa
.02381 .29249 m
.03006 .29249 L
s
[(-30)] .01131 .29249 1 0 Mshowa
.02381 .38948 m
.03006 .38948 L
s
[(-20)] .01131 .38948 1 0 Mshowa
.02381 .48647 m
.03006 .48647 L
s
[(-10)] .01131 .48647 1 0 Mshowa
.125 Mabswid
.02381 .02092 m
.02756 .02092 L
s
.02381 .04031 m
.02756 .04031 L
s
.02381 .05971 m
.02756 .05971 L
s
.02381 .07911 m
.02756 .07911 L
s
.02381 .11791 m
.02756 .11791 L
s
.02381 .13731 m
.02756 .13731 L
s
.02381 .1567 m
.02756 .1567 L
s
.02381 .1761 m
.02756 .1761 L
s
.02381 .2149 m
.02756 .2149 L
s
.02381 .2343 m
.02756 .2343 L
s
.02381 .25369 m
.02756 .25369 L
s
.02381 .27309 m
.02756 .27309 L
s
.02381 .31189 m
.02756 .31189 L
s
.02381 .33129 m
.02756 .33129 L
s
.02381 .35068 m
.02756 .35068 L
s
.02381 .37008 m
.02756 .37008 L
s
.02381 .40888 m
.02756 .40888 L
s
.02381 .42828 m
.02756 .42828 L
s
.02381 .44767 m
.02756 .44767 L
s
.02381 .46707 m
.02756 .46707 L
s
.02381 .50587 m
.02756 .50587 L
s
.02381 .52527 m
.02756 .52527 L
s
.02381 .54467 m
.02756 .54467 L
s
.02381 .56406 m
.02756 .56406 L
s
.02381 .60286 m
.02756 .60286 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .02 .02 ] 0 setdash
.02381 .58346 m
.0256 .58346 L
.02723 .58347 L
.02911 .58348 L
.03089 .58349 L
.03405 .58352 L
.03748 .58356 L
.04125 .58363 L
.04526 .58372 L
.05245 .58392 L
.05986 .58418 L
.06681 .58449 L
.08264 .58539 L
.09878 .58662 L
.11354 .58802 L
.14679 .59212 L
.17814 .59698 L
.19341 .59944 L
.20725 .60145 L
.21421 .60227 L
.21788 .60263 L
.22174 .60294 L
.22513 .60314 L
.22706 .60322 L
.22886 .60328 L
.23051 .60331 L
.23201 .60332 L
.23375 .60331 L
.2354 .60327 L
.23712 .60321 L
.23902 .60311 L
.241 .60297 L
.24286 .60281 L
.24619 .60241 L
.24977 .60186 L
.25374 .60106 L
.25793 .60001 L
.2654 .59758 L
.27994 .5911 L
.28792 .58708 L
.29184 .5853 L
.29357 .58464 L
.29546 .58403 L
.29723 .58363 L
.29888 .58347 L
.30062 .58358 L
.30249 .58417 L
.30347 .58474 L
.30454 .58562 L
.30647 .58819 L
Mistroke
.30836 .59236 L
.31011 .59808 L
.31186 .60327 L
.3135 .59119 L
.31497 .53912 L
.31656 .42172 L
.3183 .39342 L
.32014 .46238 L
.32171 .48221 L
.32343 .49312 L
.32542 .49966 L
.32726 .50275 L
.32823 .50368 L
.32929 .50431 L
.33039 .50463 L
.33143 .50467 L
.33334 .50425 L
.33508 .50343 L
.33699 .50216 L
.33901 .50051 L
.34579 .49328 L
.35319 .48343 L
.38506 .42468 L
.39307 .40446 L
.40174 .37799 L
.40572 .36343 L
.40993 .34556 L
.41357 .32718 L
.41748 .30275 L
.41942 .2878 L
.42127 .27103 L
.42472 .22771 L
.42641 .19517 L
.428 .14697 L
.42966 .01472 L
.43149 .11088 L
.43334 .18113 L
.43532 .22065 L
.43717 .24542 L
.43887 .26284 L
.44278 .2923 L
.44689 .31433 L
.45401 .34124 L
.46161 .36155 L
.46879 .37611 L
.47531 .38682 L
.49131 .40661 L
.50642 .42005 L
.5212 .43015 L
.53686 .43866 L
Mistroke
.56494 .45017 L
.59471 .45899 L
.62258 .46524 L
.68165 .47458 L
.71385 .47823 L
.74444 .48107 L
.80263 .48529 L
.86454 .48858 L
.92415 .49099 L
.9875 .49298 L
Mfstroke
.9875 .49298 m
1 .49329 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`>?U]kOUiBgUFbJo_bI<_bJoC000oooG0;nH]P000000E@00ZP00o`1E001EE@1EZP1Eo`2Z
002ZE@2ZZP2Zo`3o003oE@3oZP3ooeD005D0EED0ZUD0oeEE05EEEEEEZUEEoeFZ05FZEEFZZUFZoeGo
05GoEEGoZUGoojX00:X0EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZZZoj[o0:[oEJ[oZZ[oool0
0?l0EOl0Z_l0oomE0?mEEOmEZ_mEoonZ0?nZEOnZZ_nZoooo0?ooEOooZ_ooo`0001lO7clo?emOGgmo
OinOWkno_moOgoooonKVi]WIfDa<C;OU`]cU;Nc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a
/JRXZ:2PX=Rof8:2PXj>SWalO7EeMH9cPYVIV@00?mFgi@00O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03loOclo_clo
ocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0
oglo07lo?gloOglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl0
0;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo
?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono
_onooooo?oooOooo_n[ZjWAdM:NWYjj^[WMgMiUVc9UVoiVI09VI<iVIIYVIc9VIoiW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I_l08@000?l08@000?l08@000?l08@000?l0
8@0000P00P440081o`0A00001`001040004200040@000@@00`7o00T0000700040@000@8000@10001
10000`40003o00T000000`010@020@800`4300040@000@@000<10000o`0900001`000`4000030004
0@000@@000<10000o`0900001`000`40000300040@000@@000<10000J`000`40002J000020030@<0
0P4500030@0006/000<10000VP0001D00P5/00030@0009X0000E00030@0006/000<10000VP0001D0
00<10000J`000`40002J00005@000`40001[00030@0009X0000E00030@0006/000<10000VP0001D0
0P5/00030@0009X0000E00030@0006/000<10000VP0001D000<10000K0000`40002I00005@000`40
001[0081V`0001D000<10000J`020I/0000E0081K0020I/0000E00030@0006/000<10000VP0001D0
00<10000J`000`40002J00005@000`40001[00030@0009X0000E00030@0006/000<10000VP0001D0
00<10000K0000`40002I00005@020Fd000<10000V@0001D000<10000K0000`40002I00005@000`40
001/00030@0009T0000700<110020@D000<10000J`020I/0000:00040@000@8000<100000P000`40
001[0081V`0000X000@100010P000`40000200<1J`000`40002J000000<00@400P4200<10`001040
004400030@0006/000<10000VP0000L000<100000`001040004400030@0006/000<10000VP0000L0
00<100000`001040004400030@0006/000<10000VP0000L0104300811@000`40001[00030@0009X0
000E0081K@000`40002I00005@000`40001/00030@0009T0000E00030@0006`000<10000V@0001D0
00<10000K0000`40002I00005@000`40001[0081V`0001D00P5/0081V`0001D000<10000J`000`40
002J00005@000`40001[00030@0009X0000E00030@0006/000<10000VP0001D000<10000J`000`40
002J00005@000`40001[00030@0009X0000E0081K@000`40002I00005@000`40001/00030@0009T0
000E00030@0006`000<10000V@0001D000<10000K0000`40002I00005@000`40001[0081V`0001D0
0P5/0081V`0001D000<10000J`000`40002J00005@000`40001Z00030@0009/0000E00030@0006X0
00<10000V`0000T000<100000P020@D000<10000JP000`40002K00002@001@400001008000<10000
0P030Ol02@0000H01@4200040@000@@000<10000K@000`40002H000000<00@400P401@01000100<0
00@1000110000`40001]00030@0009P0000700030@0100<000@1000110000`40001]00030@0009P0
000800810`001040004400030@0006d000<10000V00000T000<100000P020@D00P5[00040@000IX0
000E00030@0006X000@10001VP0001D000<10000JP000`40002K00005@000`40001Z00030@0009/0
000E00030@0006X000<10000V`0001D000<10000JP000`40002K00005@020Fh000<10000V00001D0
00<10000K@000`40002H00005@000`40001]00030@0009P0000E00030@0006d000<10000V00001D0
00<10000K@000`40002H00005@020FX000<100000P000`40002G00005@000`40001Y00030@000080
00<10000U`0001D000<10000J@000`40002L00005@000`40001Y00030@0009`0000E00030@0006T0
00<10000W00001D00P5Z00030@0009`0000E00030@0006h000<10000U`0001D000<10000KP000`40
002G00005@000`40001^00030@0009L00008008110020@D000<10000K`000`40002F00001`001040
004200040@000@@000<10000K`000`40002F00002P001040004200030@0000800`5X00030@0000@0
00<10000UP000003004100810`020@<000@1000110000`40001X00030@0000@000<10000UP0000X0
00@100010P000`40000200030@0006P000<10000W@0000L000@100010P001040004400030@0006P0
00<10000W@0000P00P4400811@000`40001X00030@0009d0000E0081J@000`40002M00005@000`40
001`00030@0009D0000E00030@00070000<10000U@0001D000<10000L@000`40002D00005@000`40
001a00030@0009@0000E0081J0000`40000800030@0009<0000E00030@0006L000<1000020000`40
002C00005@000`40001W00030@0009h0000E00030@0006H000<10000W`0001D000<10000IP000`40
002O00005@020FL000<10000W`0001D000<10000IP000`40000:00030@000980000E00030@0007@0
00<10000T@0001D000<10000M0000`40002A00005@000`40001d00030@000940000E00030@0007D0
00<10000T00001D00P5U00030@0000h000<10000T00001D000<10000I0000`40002Q00005@000`40
001T00030@000:40000E00030@0006@000<10000X@0000L0104300811@000`40001S00030@000:80
000700030@0000<000@1000110030F<000<100004P000`40002=000020000`40000200040@000@@0
00<10000N@000`40002<000000<00@400P4400050@0000400P000`40000200030@0007X000<10000
R`0000X000@100010P000`40000200030@0007/000<10000RP0000L000@100010P00104000440003
0@0004d000<10000;0000`400029000020020@@00P450081CP000`40000A00030@000:@0000E0003
0@0004d000<100004@000`40002T00005@000`40001=00030@00010000<10000Y@0001D000<10000
C@000`40000@00030@0001d000<10000Q@0001D000<10000C0020A4000<100007`020HD0000E0003
0@0005l000<100008@000`40002200005@020HD000<10000P@0001D000<10000o`0900005@000`40
00280081OP0001D000<10000RP020G`0000E00030@0004`00P4>00030@0002d00P5j00005@020Dd0
0P4>00030@000:T0000E00030@0004`00P4=00030@0003@00P5d00005@000`40001<00030@0100`0
00<10000=P020G80000E00030@0004`000<100402`000`40000i0081L00001D000<10000C0000`40
0@0;00030@0003l00`5Y00005@020J000`5V00005@000`40002W00<1GP0001D000<10000ZP030@D0
0`5C00005@000`40002e00<110030DT0000700@10`020@D000<10000E`000`40001U00@110040Cd0
000900050@0000400P000`40000200<1C0000`400@0800030@0007400`4400L1;`0000T000D10000
0@0200030@00008000<10000C0000`400@0700030@0008@01P4500H16P0000030041008110001@40
0001008000<100000P000`40001<00030@0100H000<10000V`060@D02P4000T000D100000@020003
0@00008000<10000C0001040004400030@000;40000700<10`001040004400030@0004`000@10001
^00000T000<100000P020@D000<10000C0001040006h00005@020Ol02P0001D000<10000o`090000
5@000`40003o00T0000E00030@000?l02@0001D000<10000C0000`40002i00005@020Dd000<10000
^@0001D000<10000C0000`40002i00005@000`40001<00030@000;T0000E00030@0004`000<10000
^@0001D000<10000C0000`40002i00005@020Dd000<10000^@0001D000<10000o`0900005@000`40
000O00@10`020Al0104300817`020@@00P4Q00030@0000800P4N00<110020B000P4400816P0001D0
00<100008@001@400001008000<1000070000`40000300040@000Ad000@100010P001040004P0005
0@0000400P000`40000N00040@000@8000<1000070001040004200040@000AT0000E00030@000240
00D100000@0200030@0001d000<100000P001040004P00040@000@8000<100006`050@8000@10001
80001040004200030@0001`000@100010P001040004I00005@020B8000D100000@0200030@0001h0
00<100000P4200030@0001`00P4300040@000Ad000@100010`001040004M00<10`001040004N00<1
0`001040004I00005@000`40000Q00050@0000400P000`40000O00040@010@8000<100007P001040
004200030@0001`000<100400`001040004M00030@0000<000@100017P000`40000300040@000AT0
000E00030@0001l00`4300040@000Ah000D1000100020@8000<100006`001040004200040@000Al0
0P4300040@000Ad000<100000`001040004N00030@0000<000@100016@0001D000<100008@000`40
0002008180020@8000@100417`020@@00P4Q00030@0000800P4N00@10`020B000`4300816P0001D0
00<10000C0000`40002i00005@000`40001<00030@000;T0000>0?l14`4001D000<100001@000`40
000500030@0000H11P000`40000500030@0000D000<100001@000`40000500030@0000D00P440003
0@0100L000<100001@000`40000400030@0000D000<100001@000`40000500030@0000D000<10000
1@000`40000500030@0000D000<100001@000`40000400030@0000D000<100001@000`4000050003
0@0000D000<100001@000`40000500030@0000D000<100001@000`40000500030@0000@000<10000
1@000`40000400005@000`40000K00H1:@000`40002k00005@000`40000V00@15P000`4000080003
0@000;X0000E00030@0002X00P4@00@12`000`40002j00005@020C401`4400030@0000d000<10000
^P0001D000<10000o`0900005@000`40003o00T0000E00030@000?l02@0001D000<10000o`090000
o`0Q0000o`0Q0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.42468, -62.5958, 0.253465,
   0.378951}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(magnitudeResponsePZ2\  = \ 
      Plot[\((20\ Log[10, magnitude[r\ , i\ , c\ , d\ , n\ , m\ , \ w]\ ] /. 
            \ polesZeroes2)\), {w, 0, 100}]; \)\)], "Input",
  InitializationCell->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.574332 0.0120308 [
[.21429 .56183 -6 -9 ]
[.21429 .56183 6 0 ]
[.40476 .56183 -6 -9 ]
[.40476 .56183 6 0 ]
[.59524 .56183 -6 -9 ]
[.59524 .56183 6 0 ]
[.78571 .56183 -6 -9 ]
[.78571 .56183 6 0 ]
[.97619 .56183 -9 -9 ]
[.97619 .56183 9 0 ]
[.01131 .0931 -18 -4.5 ]
[.01131 .0931 0 4.5 ]
[.01131 .21341 -18 -4.5 ]
[.01131 .21341 0 4.5 ]
[.01131 .33372 -18 -4.5 ]
[.01131 .33372 0 4.5 ]
[.01131 .45402 -18 -4.5 ]
[.01131 .45402 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .57433 m
.21429 .58058 L
s
[(20)] .21429 .56183 0 1 Mshowa
.40476 .57433 m
.40476 .58058 L
s
[(40)] .40476 .56183 0 1 Mshowa
.59524 .57433 m
.59524 .58058 L
s
[(60)] .59524 .56183 0 1 Mshowa
.78571 .57433 m
.78571 .58058 L
s
[(80)] .78571 .56183 0 1 Mshowa
.97619 .57433 m
.97619 .58058 L
s
[(100)] .97619 .56183 0 1 Mshowa
.125 Mabswid
.07143 .57433 m
.07143 .57808 L
s
.11905 .57433 m
.11905 .57808 L
s
.16667 .57433 m
.16667 .57808 L
s
.2619 .57433 m
.2619 .57808 L
s
.30952 .57433 m
.30952 .57808 L
s
.35714 .57433 m
.35714 .57808 L
s
.45238 .57433 m
.45238 .57808 L
s
.5 .57433 m
.5 .57808 L
s
.54762 .57433 m
.54762 .57808 L
s
.64286 .57433 m
.64286 .57808 L
s
.69048 .57433 m
.69048 .57808 L
s
.7381 .57433 m
.7381 .57808 L
s
.83333 .57433 m
.83333 .57808 L
s
.88095 .57433 m
.88095 .57808 L
s
.92857 .57433 m
.92857 .57808 L
s
.25 Mabswid
0 .57433 m
1 .57433 L
s
.02381 .0931 m
.03006 .0931 L
s
[(-40)] .01131 .0931 1 0 Mshowa
.02381 .21341 m
.03006 .21341 L
s
[(-30)] .01131 .21341 1 0 Mshowa
.02381 .33372 m
.03006 .33372 L
s
[(-20)] .01131 .33372 1 0 Mshowa
.02381 .45402 m
.03006 .45402 L
s
[(-10)] .01131 .45402 1 0 Mshowa
.125 Mabswid
.02381 .11716 m
.02756 .11716 L
s
.02381 .14122 m
.02756 .14122 L
s
.02381 .16528 m
.02756 .16528 L
s
.02381 .18935 m
.02756 .18935 L
s
.02381 .23747 m
.02756 .23747 L
s
.02381 .26153 m
.02756 .26153 L
s
.02381 .28559 m
.02756 .28559 L
s
.02381 .30965 m
.02756 .30965 L
s
.02381 .35778 m
.02756 .35778 L
s
.02381 .38184 m
.02756 .38184 L
s
.02381 .4059 m
.02756 .4059 L
s
.02381 .42996 m
.02756 .42996 L
s
.02381 .47809 m
.02756 .47809 L
s
.02381 .50215 m
.02756 .50215 L
s
.02381 .52621 m
.02756 .52621 L
s
.02381 .55027 m
.02756 .55027 L
s
.02381 .06904 m
.02756 .06904 L
s
.02381 .04498 m
.02756 .04498 L
s
.02381 .02091 m
.02756 .02091 L
s
.02381 .59839 m
.02756 .59839 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57433 m
.02499 .57433 L
.02605 .57433 L
.02729 .57433 L
.02846 .57433 L
.03053 .57432 L
.03279 .57431 L
.03527 .5743 L
.0379 .57428 L
.04262 .57423 L
.04496 .5742 L
.04749 .57416 L
.05205 .57407 L
.05748 .57393 L
.06244 .57376 L
.0678 .57351 L
.07277 .57322 L
.07823 .57282 L
.08405 .57228 L
.09482 .57093 L
.10458 .56926 L
.12383 .56463 L
.14465 .55803 L
.15496 .55465 L
.16458 .55187 L
.16943 .55075 L
.17192 .55029 L
.17463 .54988 L
.17616 .5497 L
.17684 .54964 L
.17759 .54958 L
.17824 .54953 L
.17895 .54949 L
.17969 .54946 L
.18039 .54944 L
.18103 .54944 L
.18173 .54944 L
.18246 .54946 L
.18314 .54949 L
.18435 .54957 L
.18565 .5497 L
.18688 .54988 L
.18824 .55012 L
.19098 .55081 L
.19352 .55172 L
.19589 .55283 L
.19869 .5545 L
.20124 .55643 L
.20423 .55923 L
.207 .56245 L
Mistroke
.21194 .56992 L
.21733 .58092 L
.22245 .59341 L
.22469 .59853 L
.22588 .60076 L
.22715 .6025 L
.22843 .60332 L
.22963 .60299 L
.23033 .60222 L
.23099 .60107 L
.23224 .59776 L
.23291 .59537 L
.23361 .59239 L
.23488 .58595 L
.23774 .56739 L
.24771 .49026 L
.26633 .36509 L
.28584 .2592 L
.30413 .1886 L
.34287 .07989 L
.34791 .05988 L
.35328 .03738 L
.35589 .02738 L
.35717 .02315 L
.35835 .01984 L
.35942 .01745 L
.36056 .01566 L
.3617 .01472 L
.36295 .01473 L
.36427 .01592 L
.36547 .01799 L
.36613 .01951 L
.36685 .02142 L
.36817 .0255 L
.37304 .04472 L
.38406 .08936 L
.39345 .11944 L
.40381 .14537 L
.41476 .16692 L
.42481 .183 L
.44414 .20716 L
.46498 .22662 L
.48388 .24036 L
.50458 .25247 L
.5451 .27019 L
.58412 .28241 L
.62558 .29211 L
.66553 .2993 L
.70397 .30479 L
.74485 .30953 L
Mistroke
.78422 .31327 L
.82208 .31628 L
.86239 .319 L
.90118 .32123 L
.94242 .32326 L
.97619 .32471 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`>?U]kOUiBgUFbJo_bI<_bJoC000oooG0;nH]P000000E@00ZP00o`1E001EE@1EZP1Eo`2Z
002ZE@2ZZP2Zo`3o003oE@3oZP3ooeD005D0EED0ZUD0oeEE05EEEEEEZUEEoeFZ05FZEEFZZUFZoeGo
05GoEEGoZUGoojX00:X0EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZZZoj[o0:[oEJ[oZZ[oool0
0?l0EOl0Z_l0oomE0?mEEOmEZ_mEoonZ0?nZEOnZZ_nZoooo0?ooEOooZ_ooo`0001lO7clo?emOGgmo
OinOWkno_moOgoooonKVi]WIfDa<C;OU`]cU;Nc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a
/JRXZ:2PX=Rof8:2PXj>SWalO7EeMH9cPYVIV@00?mFgi@00O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03loOclo_clo
ocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0
oglo07lo?gloOglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl0
0;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo
?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono
_onooooo?oooOooo_n[ZjWAdM:NWYjj^[WMgMiUVc9UVoiVI09VI<iVIIYVIc9VIoiW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I_l08@000?l08@000?l08@000?l08@000?l0
8@0001D000<10000o`0900005@000`40003o00T0000E00030@000?l02@0001D000<10000o`090000
5@000`40001G00<1[P0001D00P5H00030@010:h0000E00030@0005L000<10040[P0001D000<10000
EP001@4000010:d0000E00030@0005H000D100000@2]00005@000`40001F00050@000040[@0001D0
00<10000EP000`40000200030@000:X0000E00030@0005H000<100000P000`40002Z00005@020EH0
00<100000`000`40002Z00005@000`40001E00030@0000<000<10000ZP0001D000<10000E@000`40
000400030@000:T0000E00030@0005@000<100001@000`40002Y00005@000`40001D00030@0000D0
00<10000Z@0001D000<10000E0000`40000500030@000:T0000E0081E@000`40000600030@000:P0
000E00030@0005<000<100001`000`40002X00005@000`40001C00030@0000L000<10000Z00001D0
00<10000D`000`40000700030@000:P0000E00030@0005<000<1000020000`40002W00005@000`40
001B00030@0000T000<10000Y`0000T000<100000P020@D000<10000DP000`40000900030@000:L0
000900050@0000400P000`40000200<1DP000`40000900030@000:L0000600D10P00104000440003
0@00054000<100002`000`40002V000000<00@400P401@01000100<000@1000110000`40001A0003
0@0000/000<10000YP0000L000<100400`001040004400030@00050000<1000030000`40002V0000
20020@<000@1000110000`40001@00030@0000`000<10000YP0000T000<100000P020@D000<10000
D0000`40000=00030@000:D0000E0081D0000`40000>00030@000:D0000E00030@0004l000<10000
3P000`40002U00005@000`40001?00030@0000h000<10000Y@0001D000<10000CP000`40000@0003
0@000:@0000E00030@0004h000<1000040000`40002T00005@000`40001>00030@00014000<10000
X`0001D000<10000C@000`40000B00030@000:<0000E0081CP000`40000C00030@000:80000E0003
0@0004`000<1000050000`40002R00005@000`40001<00030@0001D000<10000X@0001D000<10000
C0000`40000E00030@000:40000E00030@0004/000<100005`000`40002P00005@000`40001;0003
0@0001L000<10000X00001D00P5<00030@0001P000<10000W`0001D000<10000BP000`40000I0003
0@0009l0000E00030@0004X000<100006P000`40002N00005@000`40001900030@0001`000<10000
W@0001D000<10000B@000`40000L00030@0009d0000E00030@0004T000<100007@000`40002L0000
5@000`40001800030@0001l000<10000V`0001D00P5900030@0001l000<10000V`0001D000<10000
B0000`40000P00030@0009X0000E00030@0004L000<100008P000`40002I00005@000`4000170003
0@0002<000<10000V00001D000<10000A`000`40000S00030@0009P00008008110020@D000<10000
A`000`40000T00030@0009L0000700040@000@8000@1000110030DH000<100009P000`40002F0000
2P001040004200030@00008000<10000AP000`40000W0081UP000003004100810`020@<000@10001
10000`40001600030@0002T000<10000T`0000X000@100010P000`40000200030@0004H000<10000
:P000`40002B00001`001040004200040@000@@000<10000A@000`40000/00030@00094000080081
10020@D000<10000A@000`40000]00030@000900000E00030@0004D000<10000;P020I00000E0081
AP000`40000`00030@0008d0000E00030@0004@000<10000<P000`40002<00005@000`4000140003
0@0003<00P6<00005@000`40001400030@0003D00P6:00005@000`40001400030@0003L00P680000
5@000`40001300030@0003X00P6600005@020D@000<10000?0020H@0000E00030@0004<000<10000
?P020H80000E00030@0004<000<10000@0020H00000E00030@00048000<10000@`030Gd0000E0003
0@00048000<10000AP040GT0000E00030@00048000<10000BP040GD0000E00030@00048000<10000
CP040G40000E0081@`000`40001B00H1J`0001D000<10000@P000`40001H00D1IP0001D000<10000
@@000`40001N00H1H00001D000<10000@@000`40001T00D1F`0001D000<10000@@000`40001Y00D1
EP0001D000<10000@@000`40001^00P1CP0001D00P5200030@0007H02`5300005@000`4000110003
0@0008402`4h00005@000`40001000030@0008d02P4^00005@000`40001000030@0009L05@4I0000
5@000`40001000030@000:`0404900001`040@<00P4500030@00040000<10000a@0000L000<10000
0`001040004400030@00040000<10000a@0000P000<100000P001040004400<1?`000`4000360000
00<00@400P4400050@0000400P000`40000200030@0003l000<10000aP0000X000@100010P000`40
000200030@0003l000<10000aP0000L000@100010P001040004400030@0003l000<10000aP0000P0
0P4400811@000`40000o00030@000<H0000E00030@0003l000<10000aP0001D00P4o00030@000<L0
000E00030@0003h000<10000a`0001D000<10000?P000`40003700005@000`40000n00030@000<L0
000E00030@0003h000<10000a`0001D000<10000?P000`40003700005@000`40000m00030@000<P0
000E0081?P000`40003800005@000`40000m00030@000<P0000E00030@0003d000<10000b00001D0
00<10000?@000`40003800005@000`40000m00030@000<P0000E00030@0003d000<10000b00001D0
0P4m00030@000<T0000E00030@0003`000<10000b@0001D000<10000?0000`40003900005@000`40
000l00030@000<T0000E00030@0003`000<10000b@0001D000<10000?0000`40003900005@000`40
000l00030@000<T0000E0081?0000`40003:00005@000`40000k00030@000<X0000E00030@0003/0
00<10000bP0001D000<10000>`000`40003:00005@000`40000k00030@000<X0000700@10`020@D0
00<10000>`000`40003:00002@001@400001008000<100000P030CX000<10000b`0000T000D10000
0@0200030@00008000<10000>P000`40003;000000<00@400P4400050@0000400P000`4000020003
0@0003X000<10000b`0000T000D100000@0200030@00008000<10000>P000`40003;00001`030@<0
00@1000110000`40000j00030@000</0000900030@0000800P4500030@0003X000<10000b`0001D0
00<10000>P000`40003;00005@020CX000<10000c00001D000<10000>@000`40003<00005@000`40
000i00030@000<`0000E00030@0003T000<10000c00001D000<10000>@000`40003<00005@000`40
000i00030@000<`0000E0081>P000`40003<00005@000`40000i00030@000<`0000E00030@0003T0
00<10000c00001D000<10000>0000`40003=00005@000`40000h00030@000<d0000E00030@0003P0
00<10000c@0001D000<10000>0000`40003=00005@020CT000<10000c@0001D000<10000>0000`40
003=00005@000`40000h00030@000<d0000E00030@0003P000<10000c@0001D000<10000:`040@<0
0P4400030@0002H000<100000P020B/00P440081:`020@@00P4X00@10`020@@00P4300005@000`40
000[00030@0000<000@100010`000`40000V00050@0000400P000`40000W00040@000@8000@10001
:@001040004200040@000BT000D100000@0200040@000@800@410040000E00818`0;0@@000@10001
0P000`40000T00D10P001040004Y00040@000@8000@10001:@001040004200040@000BT000D10000
0@0200040@000@800@410040000E00030@0001l00`4900<10`001040004200030@0002@000@10001
0`001040004Y00<10`001040004Z00810`001040004Y00050@0000400P001040004200410@010000
5@000`40000L00<13P020@8000@100010P000`40000U00030@0100<000@10001:@000`4000030004
0@000BT000@100010P001040004Y00050@0000400P001040004200410@0100005@000`40000J0081
3`001040004200040@000@8000<100009P020@<000@10001:@000`40000300040@000BT000@10001
0P001040004W00<10`001040004200040@000@80000E00030@0001H0104B008100@00@000P430003
0@0002L000<100000P020B/00`430081:`020@@00P4Z00030@0000800P4400810`0001D000<10000
4P040AX000<1000010000`40003>00005@000`40000201017P000`40000400030@000<h0000>0?l1
404300005@000`40000:00030@0000X000<100002@000`40000:008110000`40000400030@0000X0
00<100002P000`40000:00030@0000T000<100002P000`40000:00030@0000X000<100002P000`40
000:00030@0000T000<100002P000`40000:00030@0000X000<100002P000`40000:00030@0000L0
000E00030@00034000<100000P000`40003?00005@000`40000b00050@000040d@0001D000<10000
<P001040007B00005@000`40000b00040@000M80000E0081=0000`400@3B00005@000`40000c00<1
dP0001D000<10000o`0900005@000`40003o00T0000E00030@000?l02@0001D000<10000o`090000
o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-8.32696, -49.3429, 0.389667,
   0.308468}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(magnitudeResponsesPZ\  = \ 
      Show[magnitudeResponsePZ1, \ magnitudeResponsePZ2, \ 
        AxesLabel -> {"\<\[Omega]\>", "\<\>"}, 
        PlotLabel -> "\<Magnitude Response (dB)\>"]; \)\)], "Input",
  InitializationCell->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.580089 0.00964153 [
[.21429 .56759 -6 -9 ]
[.21429 .56759 6 0 ]
[.40476 .56759 -6 -9 ]
[.40476 .56759 6 0 ]
[.59524 .56759 -6 -9 ]
[.59524 .56759 6 0 ]
[.78571 .56759 -6 -9 ]
[.78571 .56759 6 0 ]
[.97619 .56759 -9 -9 ]
[.97619 .56759 9 0 ]
[1.025 .58009 0 -7.5 ]
[1.025 .58009 10 7.5 ]
[.01131 .0016 -18 -4.5 ]
[.01131 .0016 0 4.5 ]
[.01131 .09801 -18 -4.5 ]
[.01131 .09801 0 4.5 ]
[.01131 .19443 -18 -4.5 ]
[.01131 .19443 0 4.5 ]
[.01131 .29084 -18 -4.5 ]
[.01131 .29084 0 4.5 ]
[.01131 .38726 -18 -4.5 ]
[.01131 .38726 0 4.5 ]
[.01131 .48367 -18 -4.5 ]
[.01131 .48367 0 4.5 ]
[.5 .63053 -71 0 ]
[.5 .63053 71 15 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .58009 m
.21429 .58634 L
s
[(20)] .21429 .56759 0 1 Mshowa
.40476 .58009 m
.40476 .58634 L
s
[(40)] .40476 .56759 0 1 Mshowa
.59524 .58009 m
.59524 .58634 L
s
[(60)] .59524 .56759 0 1 Mshowa
.78571 .58009 m
.78571 .58634 L
s
[(80)] .78571 .56759 0 1 Mshowa
.97619 .58009 m
.97619 .58634 L
s
[(100)] .97619 .56759 0 1 Mshowa
.125 Mabswid
.07143 .58009 m
.07143 .58384 L
s
.11905 .58009 m
.11905 .58384 L
s
.16667 .58009 m
.16667 .58384 L
s
.2619 .58009 m
.2619 .58384 L
s
.30952 .58009 m
.30952 .58384 L
s
.35714 .58009 m
.35714 .58384 L
s
.45238 .58009 m
.45238 .58384 L
s
.5 .58009 m
.5 .58384 L
s
.54762 .58009 m
.54762 .58384 L
s
.64286 .58009 m
.64286 .58384 L
s
.69048 .58009 m
.69048 .58384 L
s
.7381 .58009 m
.7381 .58384 L
s
.83333 .58009 m
.83333 .58384 L
s
.88095 .58009 m
.88095 .58384 L
s
.92857 .58009 m
.92857 .58384 L
s
.25 Mabswid
0 .58009 m
1 .58009 L
s
gsave
1.025 .58009 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(w) show
69.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.02381 .0016 m
.03006 .0016 L
s
[(-60)] .01131 .0016 1 0 Mshowa
.02381 .09801 m
.03006 .09801 L
s
[(-50)] .01131 .09801 1 0 Mshowa
.02381 .19443 m
.03006 .19443 L
s
[(-40)] .01131 .19443 1 0 Mshowa
.02381 .29084 m
.03006 .29084 L
s
[(-30)] .01131 .29084 1 0 Mshowa
.02381 .38726 m
.03006 .38726 L
s
[(-20)] .01131 .38726 1 0 Mshowa
.02381 .48367 m
.03006 .48367 L
s
[(-10)] .01131 .48367 1 0 Mshowa
.125 Mabswid
.02381 .02088 m
.02756 .02088 L
s
.02381 .04016 m
.02756 .04016 L
s
.02381 .05945 m
.02756 .05945 L
s
.02381 .07873 m
.02756 .07873 L
s
.02381 .1173 m
.02756 .1173 L
s
.02381 .13658 m
.02756 .13658 L
s
.02381 .15586 m
.02756 .15586 L
s
.02381 .17514 m
.02756 .17514 L
s
.02381 .21371 m
.02756 .21371 L
s
.02381 .23299 m
.02756 .23299 L
s
.02381 .25228 m
.02756 .25228 L
s
.02381 .27156 m
.02756 .27156 L
s
.02381 .31013 m
.02756 .31013 L
s
.02381 .32941 m
.02756 .32941 L
s
.02381 .34869 m
.02756 .34869 L
s
.02381 .36798 m
.02756 .36798 L
s
.02381 .40654 m
.02756 .40654 L
s
.02381 .42582 m
.02756 .42582 L
s
.02381 .44511 m
.02756 .44511 L
s
.02381 .46439 m
.02756 .46439 L
s
.02381 .50296 m
.02756 .50296 L
s
.02381 .52224 m
.02756 .52224 L
s
.02381 .54152 m
.02756 .54152 L
s
.02381 .56081 m
.02756 .56081 L
s
.02381 .59937 m
.02756 .59937 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Magnitude) show
123.000000 15.000000 moveto
(Response) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
177.000000 15.000000 moveto
(H) show
183.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dB) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
195.000000 15.000000 moveto
(L) show
201.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .02 .02 ] 0 setdash
.02381 .58009 m
.02499 .58009 L
.02605 .5801 L
.02729 .5801 L
.02846 .58012 L
.03053 .58015 L
.03279 .58019 L
.03527 .58026 L
.0379 .58034 L
.04262 .58054 L
.04749 .58081 L
.05205 .58111 L
.06244 .58201 L
.07305 .58323 L
.08274 .58462 L
.10458 .58869 L
.12517 .59353 L
.1352 .59597 L
.14429 .59797 L
.14886 .59879 L
.15127 .59914 L
.15381 .59945 L
.15603 .59965 L
.1573 .59973 L
.15848 .59979 L
.15956 .59982 L
.16055 .59983 L
.16169 .59982 L
.16277 .59978 L
.1639 .59972 L
.16515 .59962 L
.16645 .59949 L
.16768 .59932 L
.16986 .59893 L
.17221 .59837 L
.17482 .59758 L
.17757 .59654 L
.18248 .59413 L
.19203 .58768 L
.19727 .58369 L
.19985 .58192 L
.20098 .58126 L
.20222 .58065 L
.20338 .58026 L
.20447 .58009 L
.20561 .58021 L
.20684 .58079 L
.20748 .58136 L
.20818 .58224 L
.20946 .58479 L
Mistroke
.2107 .58893 L
.21185 .59462 L
.21299 .59978 L
.21407 .58778 L
.21504 .53601 L
.21608 .41931 L
.21722 .39117 L
.21843 .45972 L
.21946 .47944 L
.22059 .49028 L
.2219 .49678 L
.22311 .49986 L
.22374 .50078 L
.22444 .50141 L
.22517 .50173 L
.22585 .50177 L
.2271 .50135 L
.22824 .50053 L
.2295 .49927 L
.23082 .49763 L
.23527 .49044 L
.24014 .48065 L
.26107 .42224 L
.26633 .40215 L
.27203 .37584 L
.27464 .36137 L
.27741 .3436 L
.27979 .32532 L
.28236 .30104 L
.28364 .28618 L
.28485 .26951 L
.28712 .22645 L
.28823 .1941 L
.28927 .14619 L
.29036 .01472 L
.29157 .11031 L
.29277 .18014 L
.29408 .21943 L
.29529 .24405 L
.29641 .26137 L
.29897 .29065 L
.30168 .31255 L
.30635 .33931 L
.31134 .35949 L
.31606 .37397 L
.32034 .38461 L
.33085 .40428 L
.34078 .41764 L
.35048 .42769 L
.36077 .43615 L
Mistroke
.37921 .44758 L
.39876 .45635 L
.41707 .46257 L
.45586 .47185 L
.47701 .47548 L
.4971 .47831 L
.53531 .48249 L
.57598 .48577 L
.61513 .48817 L
.65673 .49015 L
.69682 .49166 L
.73539 .49284 L
.77641 .49388 L
.81592 .49472 L
.85391 .4954 L
.89436 .49602 L
.93328 .49653 L
.97467 .497 L
.97619 .49702 L
Mfstroke
[ ] 0 setdash
.02381 .58009 m
.02499 .58009 L
.02605 .58009 L
.02729 .58009 L
.02846 .58008 L
.03053 .58008 L
.03279 .58007 L
.03527 .58006 L
.0379 .58005 L
.04262 .58001 L
.04496 .57998 L
.04749 .57995 L
.05205 .57988 L
.05748 .57977 L
.06244 .57963 L
.0678 .57943 L
.07277 .5792 L
.07823 .57887 L
.08405 .57844 L
.09482 .57736 L
.10458 .57603 L
.12383 .57231 L
.14465 .56703 L
.15496 .56432 L
.16458 .56209 L
.16943 .56119 L
.17192 .56082 L
.17463 .56049 L
.17616 .56035 L
.17684 .5603 L
.17759 .56025 L
.17824 .56021 L
.17895 .56018 L
.17969 .56016 L
.18039 .56014 L
.18103 .56014 L
.18173 .56014 L
.18246 .56016 L
.18314 .56018 L
.18435 .56025 L
.18565 .56035 L
.18688 .56049 L
.18824 .56069 L
.19098 .56124 L
.19352 .56197 L
.19589 .56285 L
.19869 .56419 L
.20124 .56574 L
.20423 .56799 L
.207 .57056 L
Mistroke
.21194 .57655 L
.21733 .58537 L
.22245 .59538 L
.22469 .59948 L
.22588 .60127 L
.22715 .60266 L
.22843 .60332 L
.22963 .60306 L
.23033 .60244 L
.23099 .60152 L
.23224 .59887 L
.23291 .59695 L
.23361 .59456 L
.23488 .5894 L
.23774 .57453 L
.24771 .51271 L
.26633 .4124 L
.28584 .32754 L
.30413 .27096 L
.34287 .18384 L
.34791 .16781 L
.35328 .14977 L
.35589 .14176 L
.35717 .13837 L
.35835 .13572 L
.35942 .1338 L
.36056 .13236 L
.3617 .13161 L
.36295 .13162 L
.36427 .13257 L
.36547 .13424 L
.36613 .13545 L
.36685 .13698 L
.36817 .14025 L
.37304 .15565 L
.38406 .19143 L
.39345 .21554 L
.40381 .23631 L
.41476 .25359 L
.42481 .26647 L
.44414 .28584 L
.46498 .30143 L
.48388 .31245 L
.50458 .32214 L
.5451 .33635 L
.58412 .34614 L
.62558 .35392 L
.66553 .35967 L
.70397 .36408 L
.74485 .36787 L
Mistroke
.78422 .37087 L
.82208 .37329 L
.86239 .37546 L
.90118 .37725 L
.94242 .37888 L
.97619 .38004 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`>?U]kOUiBgUFbJo_bI<_bJoC000oooG0;nH]P000000E@00ZP00o`1E001EE@1EZP1Eo`2Z
002ZE@2ZZP2Zo`3o003oE@3oZP3ooeD005D0EED0ZUD0oeEE05EEEEEEZUEEoeFZ05FZEEFZZUFZoeGo
05GoEEGoZUGoojX00:X0EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZZZoj[o0:[oEJ[oZZ[oool0
0?l0EOl0Z_l0oomE0?mEEOmEZ_mEoonZ0?nZEOnZZ_nZoooo0?ooEOooZ_ooo`0001lO7clo?emOGgmo
OinOWkno_moOgoooonKVi]WIfDa<C;OU`]cU;Nc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a
/JRXZ:2PX=Rof8:2PXj>SWalO7EeMH9cPYVIV@00?mFgi@00O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03loOclo_clo
ocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0
oglo07lo?gloOglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl0
0;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo
?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono
_onooooo?oooOooo_n[ZjWAdM:NWYjj^[WMgMiUVc9UVoiVI09VI<iVIIYVIc9VIoiW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I_l08@000?l08@000?l08@0000X00P440081
o`0?00002@001040004200040@000@@00`7o00L0000900040@000@8000@1000110000`40003o00L0
000300@10P030@<000@1000110000`40003o00L0000900030@0000<000@1000110000`40003o00L0
000900030@0000<000@1000110000`40001000030@000<<0000:00<10`020@D00P5100030@000<<0
000G00030@00040000<10000``0001L000<10000@0000`40003300005`000`40001000030@000<<0
000G00030@00040000<10000``0001L00P5100030@000<<0000G00030@00040000<10000``0001L0
00<10000@0000`40003300005`000`40001000030@000<<0000G00030@00040000<10000``0001L0
0P5100030@000<<0000G00030@00040000<10000``0001L000<10000@0000`40003300005`000`40
001000030@000<<0000G0081@@000`40003300005`000`40001000030@000<<0000G00030@000400
00<10000``0001L000<10000@0000`40003300002@030@@00P4500030@00040000<10000``0000`0
00@100010P000`40000200<1@0000`400033000030001040004200030@00008000<10000@0000`40
003300000`040@800`4300040@000@@000<10000@0000`40003300002@000`40000300040@000@@0
00<10000@0000`40003300002@000`40000300040@000@@000<10000@0000`40003300002@040@<0
0P450081@@000`40003300005`000`40001000030@000<<0000G00030@00040000<10000``0001L0
00<10000@0000`40003300005`000`40001000030@0000h00`6b00005`020D4000<100003P000`40
0@2b00005`000`40001000030@0000d000@10001/P0001L000<10000@0000`40000=00050@000040
/@0001L000<10000@0000`40000=00050@000040/@0001L000<10000@0000`40000=00030@000080
00<10000[P0001L00P5100030@0000`000<100000`000`40002^00005`000`40001000030@0000`0
00<100000`000`40002^00005`000`40001100030@0000X000<1000010000`40002^00005`000`40
001100030@0000X000<100001@000`40002]00005`000`40001100030@0000X000<100001@000`40
002]00005`020D4000<100002`000`40000500030@000:d0000G00030@00040000<100002P000`40
000600030@000:d0000G00030@00040000<100002P000`40000700030@000:`0000;00030@000080
0P4500030@0003l000<100002`000`40000700030@000:`0000;00050@0000400P000`40000200<1
?`000`400@0:00030@0000P000<10000[00000P01@4200040@000@@000<10000?`000`400@0:0003
0@0000T000<10000Z`0000<010401@01000100<000@1000110000`40001100030@0000L000<10000
2P000`40002[00002@000`400@0300040@000@@000<10000@@000`40000700030@0000/000<10000
ZP0000X00P4300040@000@@000<10000@@000`40000600030@0000`000<10000ZP0000/000<10000
0P020@D00P5200030@0000H000<100003@000`40002Y00005`000`40000o00030@0000L000<10000
3P000`40002Y00005`000`40000o00030@0000L000<100003P000`40002Y00005`000`40000o0003
0@0000H000<1000040000`40002X00005`000`40000o00030@0000H000<1000040000`40002X0000
5`020D0000<100401@000`40000B00030@000:L0000G00030@0003l000<100401@000`40000B0003
0@000:L0000G00030@00044000<100000P000`40000D00030@000:H0000G00030@00044000<10000
0P000`40000E00030@000:D0000G00030@00044000D100000@0H00030@000:D0000G0081@P001@40
000101T000<10000Y00001L000<10000?`000`40000200030@0001T000<10000X`0001L000<10000
?`000`40000200030@0001X000<10000XP0001L000<10000?`001@40000101h000<10000X@0001L0
00<10000?`001@40000101l000<10000X00001L00P5000030@00008180000`40002O00005`000`40
000n00050@0000408@000`40002O00005`000`40001200030@00020000<10000WP0000X00P440081
1@000`40001200030@00024000<10000W@0000T000@100010P001040004400<1@P000`40000R0081
W@0000`000@100010P000`40000200030@0004400P4V00030@0009X0000300@10`020@<000@10001
10000`40000n00040@000BP00P6J000030001040004200030@00008000<10000?P001040004Z0003
0@0009L0000900040@000@8000@1000110000`40000n00040@000B/00P6G00002P020@@00P450081
?`000`400@0^00030@0009@0000G00030@0003h000<100400P000`40000Z0081U00001L000<10000
?P000`400@0200030@0002`00`6A00005`000`40001000040@000C400`6>00005`000`40000o0003
0@00008000<10000<@020H`0000G0081@0000`40000200030@0003<00`6900005`000`40000o0003
0@00008000<10000=P020HL0000G00030@0003d000<10040?`040H<0000G00030@0003d00P5400D1
OP0001L000<10000?@020DT01@5i00005`020Ch00P4600030@0004D01@5d00005`000`40000l0003
0@0100H000<10000BP050Fl0000G00030@0003`00P4700030@0004l01@5Z00005`000`40000m0003
0@0000D000<10000E0080F80000G00030@0003d000<100001P000`40001K00X1F00001L00P4n0003
0@0000H000<10000I@0C0DD0000G00030@0003`000<10000PP0:0C/0000G00030@0003/00P6>01@1
9`0000T0104300811@000`40000k0081XP0>0AT0000900030@0000<000@1000110000`40000k0081
b@0000X000<100000P001040004400<1>P020@`000<10000^`0000<0104400050@0000400P000`40
000200030@0002h000<100002@020@d000<10000^P0000`000@100010P000`40000200030@0002h0
00<100002@020@d000<10000^P0000T000@100010P001040004400030@0002h000<100002P000`40
000<00030@000;T0000:008110020@D00P4_00030@0000T000<100003@000`40002i00005`000`40
000j00030@000<T0000G00030@0003X000<10000b@0001L000<10000;P000`4000080081b`0001L0
00<10000;P000`40000800814P000`40002f00005`020Bh00P4:00030@00018000<10000]@0001L0
00<10000;@020@T00P4E00030@000;@0000G00030@0002d00P4900815P000`40002c00005`000`40
000]008120000`400@0G00030@000;80000G00030@0002d000<100002@000`40000H00030@000:l0
000G0081;P000`40000800030@0001X000<10000[P0001L000<10000>0000`40000K0081[P0001L0
00<10000=P000`400@0O00030@000:/0000G00030@0002h000<100001@000`400@3=00005`000`40
000^00030@0000@000@1000190050J@0000G0081;P020@H000<10040:P000`40002Q00005`000`40
000]00811@001040004_0081W@0001L000<10000;@020@D000@10001<@040IT0000900@10`020@D0
00<10000;@020@P000<10000=`040I40000;00050@0000400P000`40000200030@0002d000<10000
1`000`40000k00030@0000801@6700002`001@400001008000<100000P030Bd000<100001P000`40
001600030@0000801P5l00000`040@@000D100000@0200030@00008000<10000=P000`40001E00H1
10060FP0000;00050@0000400P000`40000200030@00038000D100000@1[00H110060@@01P4400<1
@`0000T00`4300040@000@@000<10000;`000`400@0400030@0008X00`4400H110060@D01P4400@1
6@0000/000<100000P020@D000<10000;`030@@000<10000c@0001L00P4^00030@0000D000<10000
cP0001L000<10000;@000`40000500030@000<h0000G00030@0002d000<100001@000`40003>0000
5`000`40000]00030@0000D000<10000cP0001L00P4^00030@0000D000<10000cP0001L000<10000
;@000`40000500030@000<h0000G00030@0003@000<10000c`0001L000<10000=0000`40003?0000
5`000`40000d00030@000<l0000G0081=@000`40003?00005`000`40000X00@100<00@000P430003
0@0002<000<100000P020BL00P440081:0020@@00P4T00@10`020@@00P4C00005`000`40000X0003
0@0000800P4200040@000BD000D100000@0200030@0002<000@100010P001040004V00040@000@80
00@100019@001@400001008000@100010P000`40000@00005`000`40000Y00040@0000810P001040
004R00D10P001040004U00040@000@8000@100019P001040004200040@000BD000D100000@020004
0@000@8000<10000400001L000<10000:P000`4000020@8000@100018P001040004300040@000BD0
0`4300040@000BL00P4300040@000BD000D100000@0200040@000@8000<10000400001L00P4P00X1
0P0010400@4200030@0102@000<100400`001040004U00030@0000<000@100019P00104000420004
0@000BD000D100000@0200040@000@8000<10000400001L000<100007@020@T010400`010@020003
0@0102D00P4300040@000BD000<100000`001040004V00040@000@8000@100018`030@<000@10001
0P001040004B00005`000`40000I00@130030@<00P4200030@0002@000<100000P020BL00`430081
:0020@@00P4V00030@0000800P44008120040@L0000G00030@0001@01@4C00030@0000@000<10000
a0001P4000400@H0000G00030@0000`0204H00030@0000@000<10000a0001P4000400@H0000A0?`1
1`000`40000200030@0000@0000G00030@0000P01P4700030@0000T000<1000010020@<00P430003
0@0000@000<100002@000`40000900030@0000T000<100002@000`40000800030@0000T000<10000
2@000`40000900030@0000T000<100002@000`40000900030@0000T000<100002@000`4000090003
0@0000T000<1000030001@40000100H0000G00030@0001800`4B00030@0000<00P4300030@000=40
000G00030@0001D00`4>00030@0000@000<100400P000`40003A00005`000`40000L00030@0000d0
0P401@0100010=<0000G00817P050@/000<100000P7D00005`000`40000`0081e00001L000<10000
o`0700005`000`40003o00L0000G00030@000?l01`000?l08@000?l08@000?l08@000?l08@000?l0
8@0005H00`4n00<19@000`40000<00030@0004l0001I00030@0003`000<100008`000`40000>0003
0@0004h00019008100<00@400`020@04004000<100D00@4100020@03004100<10`020@<00P401001
00020@04004000<11`030@8000<100000`4200<10`030@@00P4200<100@00@400`4400<12P000`40
0002008100<00@400`4400030@0004h0001900050@0000400P001040004200040@000@8000@10001
10000`40000200060@000@010P001040004200040@000@/000@100010P000`40000600040@000@80
00@100010P001040004200030@0000<000@100013@001@400001008000@100010P001@4000010500
001900050@0100400`030@8000@100010P001040004400030@00008000<100000P00104000420004
0@000@800`4900<10`030@@00P4300040@000@8000@100010P001040004300810`030@/000D10000
0@0200040@000@8000D100000@1@0000B@001@400@0100D000@100010P001040004200030@000080
00<100000P000`40000200040@000@8000@100010P001040004800040@000@8000@100010P000`40
000300040@000@8000@100010P001040004200030@0000<000@100012P001@400001008000<10000
0`4400030@0004h00019008100<00@400`020@@00P4010010@020@@00P4300@100@00@400P4300<1
0`020@T000@100010`020@@00`400`0100020@@00P4200040@010@@00`4300812`000`40000200<1
0P001040004300030@0004h0001900050@0000406`000`40000;00030@0000/0104f00030@0000<0
00<100400`4300030@0004l0001T00030@00008000<100002P020D`00P5J0000o`0Q0000o`0Q0000
o`0Q0000o`0Q0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-9.96368, -61.8645, 0.419457,
   0.414336}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Step response", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stepResponsePZ1\  = \ 
      Plot[\((stepResponse[r\ , i\ , c\ , d\ , n\ , m\ , \ t]\  /. \ 
            polesZeroes1)\), {t, 0, 1}, PlotRange -> All, 
        PlotStyle -> {Dashing[{.02, .02}]}]; \)\)], "Input",
  InitializationCell->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.21623 0.65828 [
[.21429 .42955 -9 -9 ]
[.21429 .42955 9 0 ]
[.40476 .42955 -9 -9 ]
[.40476 .42955 9 0 ]
[.59524 .42955 -9 -9 ]
[.59524 .42955 9 0 ]
[.78571 .42955 -9 -9 ]
[.78571 .42955 9 0 ]
[.97619 .42955 -3 -9 ]
[.97619 .42955 3 0 ]
[.01131 .04708 -18 -4.5 ]
[.01131 .04708 0 4.5 ]
[.01131 .17874 -18 -4.5 ]
[.01131 .17874 0 4.5 ]
[.01131 .31039 -18 -4.5 ]
[.01131 .31039 0 4.5 ]
[.01131 .57371 -18 -4.5 ]
[.01131 .57371 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .44205 m
.21429 .4483 L
s
[(0.2)] .21429 .42955 0 1 Mshowa
.40476 .44205 m
.40476 .4483 L
s
[(0.4)] .40476 .42955 0 1 Mshowa
.59524 .44205 m
.59524 .4483 L
s
[(0.6)] .59524 .42955 0 1 Mshowa
.78571 .44205 m
.78571 .4483 L
s
[(0.8)] .78571 .42955 0 1 Mshowa
.97619 .44205 m
.97619 .4483 L
s
[(1)] .97619 .42955 0 1 Mshowa
.125 Mabswid
.07143 .44205 m
.07143 .4458 L
s
.11905 .44205 m
.11905 .4458 L
s
.16667 .44205 m
.16667 .4458 L
s
.2619 .44205 m
.2619 .4458 L
s
.30952 .44205 m
.30952 .4458 L
s
.35714 .44205 m
.35714 .4458 L
s
.45238 .44205 m
.45238 .4458 L
s
.5 .44205 m
.5 .4458 L
s
.54762 .44205 m
.54762 .4458 L
s
.64286 .44205 m
.64286 .4458 L
s
.69048 .44205 m
.69048 .4458 L
s
.7381 .44205 m
.7381 .4458 L
s
.83333 .44205 m
.83333 .4458 L
s
.88095 .44205 m
.88095 .4458 L
s
.92857 .44205 m
.92857 .4458 L
s
.25 Mabswid
0 .44205 m
1 .44205 L
s
.02381 .04708 m
.03006 .04708 L
s
[(0.4)] .01131 .04708 1 0 Mshowa
.02381 .17874 m
.03006 .17874 L
s
[(0.6)] .01131 .17874 1 0 Mshowa
.02381 .31039 m
.03006 .31039 L
s
[(0.8)] .01131 .31039 1 0 Mshowa
.02381 .57371 m
.03006 .57371 L
s
[(1.2)] .01131 .57371 1 0 Mshowa
.125 Mabswid
.02381 .08 m
.02756 .08 L
s
.02381 .11291 m
.02756 .11291 L
s
.02381 .14582 m
.02756 .14582 L
s
.02381 .21165 m
.02756 .21165 L
s
.02381 .24457 m
.02756 .24457 L
s
.02381 .27748 m
.02756 .27748 L
s
.02381 .34331 m
.02756 .34331 L
s
.02381 .37622 m
.02756 .37622 L
s
.02381 .40914 m
.02756 .40914 L
s
.02381 .47496 m
.02756 .47496 L
s
.02381 .50788 m
.02756 .50788 L
s
.02381 .54079 m
.02756 .54079 L
s
.02381 .01417 m
.02756 .01417 L
s
.02381 .60662 m
.02756 .60662 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
[ .02 .02 ] 0 setdash
.02381 .04217 m
.02846 .03008 L
.03279 .02203 L
.03527 .01876 L
.03754 .01664 L
.03879 .01581 L
.0395 .01544 L
.04015 .01517 L
.04135 .01484 L
.04262 .01472 L
.04384 .01482 L
.04496 .01511 L
.04626 .01566 L
.04749 .0164 L
.04967 .01822 L
.05205 .02094 L
.05466 .02475 L
.05744 .02974 L
.06244 .04099 L
.07382 .07623 L
.08454 .1194 L
.10458 .21671 L
.14313 .41349 L
.16307 .4966 L
.17324 .53053 L
.18413 .55979 L
.18941 .57123 L
.19441 .58041 L
.19927 .58782 L
.20377 .59334 L
.20803 .59742 L
.21255 .60056 L
.2149 .60171 L
.21709 .60251 L
.21835 .60284 L
.21951 .60307 L
.22077 .60324 L
.22141 .60329 L
.22211 .60332 L
.22342 .60331 L
.22464 .60321 L
.22528 .60313 L
.22598 .60302 L
.22739 .60272 L
.22863 .60237 L
.22997 .60191 L
.23238 .60086 L
.23726 .5979 L
.24172 .59428 L
.25246 .58236 L
Mistroke
.26267 .56754 L
.30091 .49537 L
.32227 .45402 L
.34161 .42174 L
.35131 .40831 L
.3618 .39622 L
.3717 .38726 L
.38079 .38118 L
.38551 .37884 L
.3881 .37779 L
.39055 .37694 L
.39284 .37628 L
.39532 .37571 L
.39757 .37531 L
.39866 .37516 L
.39965 .37505 L
.40084 .37495 L
.40212 .37487 L
.40324 .37483 L
.40443 .37482 L
.40573 .37485 L
.40694 .37491 L
.40764 .37495 L
.40827 .37501 L
.40969 .37515 L
.41232 .37554 L
.41517 .37611 L
.42033 .37755 L
.42524 .37938 L
.42982 .38146 L
.44025 .38739 L
.4613 .40323 L
.50018 .43761 L
.51997 .45327 L
.53041 .4602 L
.54151 .4663 L
.55133 .47048 L
.55692 .47232 L
.56218 .47369 L
.56452 .47419 L
.56698 .47464 L
.56911 .47496 L
.57139 .47525 L
.57267 .47538 L
.57384 .47548 L
.57503 .47557 L
.57613 .47563 L
.57741 .47569 L
.57808 .47571 L
.5788 .47573 L
Mistroke
.58 .47574 L
.58132 .47574 L
.58261 .47571 L
.58381 .47567 L
.58512 .47561 L
.58652 .47552 L
.58912 .47529 L
.59147 .47502 L
.59624 .47428 L
.60074 .47337 L
.61078 .47063 L
.62163 .46671 L
.66265 .4469 L
.68309 .43691 L
.69307 .43264 L
.70216 .42925 L
.71095 .42652 L
.7205 .42422 L
.72574 .42327 L
.73059 .4226 L
.73298 .42234 L
.73523 .42215 L
.73757 .42198 L
.73881 .42192 L
.74015 .42186 L
.74141 .42182 L
.74255 .42179 L
.74387 .42178 L
.74511 .42178 L
.74627 .42178 L
.74733 .4218 L
.7485 .42183 L
.74973 .42188 L
.75231 .42201 L
.75472 .42218 L
.75736 .42242 L
.76021 .42274 L
.76587 .42355 L
.77124 .42452 L
.78131 .42681 L
.81957 .43912 L
.84095 .44638 L
.86029 .45176 L
.87001 .45379 L
.87511 .45463 L
.8805 .45536 L
.88522 .45584 L
.8879 .45605 L
.8904 .4562 L
.89158 .45626 L
Mistroke
.8927 .45631 L
.89372 .45635 L
.89479 .45638 L
.89596 .4564 L
.89705 .45642 L
.89821 .45643 L
.89949 .45643 L
.90078 .45642 L
.90198 .4564 L
.90329 .45636 L
.90469 .45632 L
.90728 .4562 L
.90962 .45606 L
.9144 .45566 L
.91889 .45517 L
.92892 .45369 L
.93977 .45155 L
.97619 .44206 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`>?U]kOUiBgUFbJo_bI<_bJoC000oooG0;nH]P000000E@00ZP00o`1E001EE@1EZP1Eo`2Z
002ZE@2ZZP2Zo`3o003oE@3oZP3ooeD005D0EED0ZUD0oeEE05EEEEEEZUEEoeFZ05FZEEFZZUFZoeGo
05GoEEGoZUGoojX00:X0EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZZZoj[o0:[oEJ[oZZ[oool0
0?l0EOl0Z_l0oomE0?mEEOmEZ_mEoonZ0?nZEOnZZ_nZoooo0?ooEOooZ_ooo`0001lO7clo?emOGgmo
OinOWkno_moOgoooonKVi]WIfDa<C;OU`]cU;Nc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a
/JRXZ:2PX=Rof8:2PXj>SWalO7EeMH9cPYVIV@00?mFgi@00O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03loOclo_clo
ocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0
oglo07lo?gloOglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl0
0;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo
?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono
_onooooo?oooOooo_n[ZjWAdM:NWYjj^[WMgMiUVc9UVoiVI09VI<iVIIYVIc9VIoiW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I_l08@000?l08@000?l08@000?l08@0001D0
00<10000o`0900005@000`40003o00T0000E00030@000?l02@0001D000<10000o`0900005@020@80
0`7o00D0000E00040@000Ol0200001D000<10040o`0900005@000`400@3o00T0000E00030@000?l0
2@0001D000<100001P000`40003o00005@000`40000700030@000?h00002008110000`4000040003
0@0000<000<100001`000`40003n000000D00@000@0:00030@0000<000<100001`000`40003n0000
00D00@000@0700D110030@P000<10000o@000005004000401`001040004500030@0000P000<10000
o@0000050040004020000`400@0500030@000?l02@000005004000402@020@D000<10000o`090000
0P020@/000<100000`000`40003o00T0000E00030@000?l02@0001D000<100002P000`40003k0000
5@000`40000;00030@000?X0000E00030@0000/000<10000nP0001D00P4<00030@000?X0000E0003
0@0000/000<10000nP0001D000<100002`000`40003j00005@000`40003o00T0000E00030@000?l0
2@0001D000<10000o`0900005@000`40003o00T0000E00030@0000d000<10000n00001D000<10000
3@000`40003h00005@020@h000<10000n00001D000<100003@000`40003h00005@000`40000=0003
0@000?P0000E00030@0000h000<10000m`0001D000<100003P000`40003g00005@000`40003o00T0
000E00030@000?l02@0001D000<10000o`0900005@000`40003o00T0000E008140000`40003f0000
5@000`40000?00030@000?H0000E00030@0000l000<10000mP0001D000<1000040000`40003e0000
5@000`40000@00030@000?D0000E00030@00010000<10000m@0001D000<10000o`0900000P020@@0
00<100000`020@D000<10000o`09000000D00@000@0800040@000@@000<10000o`09000000D00@00
0@0800040@000@@00`7o00T000001@01000100P00`4500030@000?l02@0000050040004020000`40
000500030@00014000<10000m00000050040004020000`40000500030@00014000<10000m0000080
0P4:00<110000`40000A00030@000?@0000E00030@00018000<10000l`0001D000<100004P000`40
003c00005@000`40000B00030@000?<0000E00030@000?l02@0001D00P7o00X0000E00030@000?l0
2@0001D000<10000o`0900005@000`40000C00030@000?80000E00030@0001<000<10000lP0001D0
00<100004`000`40003b00005@000`40000D00030@000?40000E00030@0001@000<10000l@0001D0
0P4E00030@000?40000E00030@0001@000<10000l@0001D000<10000o`0900005@000`40003o00T0
000E00030@000?l02@0001D000<10000o`0900005@000`40000E00030@000?00000E00030@0001D0
00<10000l00001D000<100005@000`40003`00005@020AL000<10000k`0001D000<100005P000`40
003_00005@000`40000F00030@000>l0000E00030@000?l02@0001D000<10000o`0900005@000`40
003o00T0000E00030@000?l02@0001D000<10000o`0900000P020@@000<100000`020@D000<10000
5`000`40003^000000D00@000@0800040@000@@00`4G00030@000>h000001@01000100P000@10001
10000`40000H00030@000>d000001@01000100T00P4500030@0001P000<10000k@00000500400040
20001040004400030@0001T000<10000k00000050040004020001040004400030@0001T000<10000
k00000800P4:00811@000`40003o00T0000E00030@000?l02@0001D000<10000o`0900005@000`40
003o00T0000E00816`000`40003[00005@000`40000J00030@000>/0000E00030@0001X000<10000
j`0001D000<100006`000`40003Z00005@000`40000K00030@000>X0000E00030@0001/000<10000
jP0001D000<100006`000`40003Z00005@000`40003o00T0000E00030@000?l02@0001D00P5V00@1
W`0001D000<10000G`020@P00P6M00005@000`40000L00030@0003h00P6Y00005@000`40000L0003
0@0003d000<10000Z@0001D000<1000070000`40000l00030@00014000<10000UP0001D000<10000
7@000`40001@0081UP0001D000<100007@000`40001B00030@0009<0000E00030@0001d000<10000
D`000`40002B00005@000`40001G00030@000:h0000E0081E`000`40002_00005@000`40000Z0081
10000`40000200@170000`400006008110000`40000400030@0002<00P4400030@0000<00P4V0081
10000`4000030081:`040@H0000E00030@0002T000@1000120000`40000M00030@0000D000@10001
2P000`40000900030@0001H000@1000120001040004T00040@000@P000@10001;0000`4000050000
5@000`40000Y00040@000@T000<100006`000`40000600040@000@L01@4;00815P00104000480004
0@000B@000@1000120001040004/00030@0000D0000E00030@0001h000<1000020001040004:0003
0@0002<000@100011`001040004>00030@0001<000@1000120030AX0104500H12@020Bd000<10000
1@0001D000<100007P000`40000800040@000@/000<100008P001040004800030@0100l000<10000
4P001040004800030@0001P00P4;00040@000@P000@10001;0000`40000500005@000`40000N0003
0@0000P000@1000120001040004T00040@000@T00P4T00040@000@P000<100009@001040004400D1
0P000`40000X00<11`0001D000<100007`000`40000800812P020BH00P4;00030@0002<00P4:00<1
4@020A800P4900<1;@000`40000500005@000`40000O00030@0002l000<10000F`020EL0000>0?l1
4`4001D000<100002P000`40000:00030@0000X000<100002P000`40000:00030@0000X000<10000
0P000`40000500030@0000X000<100002P000`40000900030@00008120000`40000:00030@0000X0
00<100002P000`40000:00030@0000X000<100002P030@X000<100002P000`40000600<100<00@00
1P0001D000<10000<@000`40000K00030@0001<000<100006`000`40000B00030@00034000<10000
3@000`40000J00<110000`40000500005@000`40001>00030@0003<000<1000080020CP0104=00<1
4`0001D000<10000Y@020Ch00`4600@15P0001D000<1000080000`4000200081H`0001D000<10000
80000`40001U0081OP0001D000<100008@000`40001V00814P000`40001W00005@000`40000Q0003
0@0002P000<10000?@020@h00P5Z00005@020B8000<100009`000`400015008110030F`0000E0003
0@00028000<100009P000`40002j00005@000`40000R00030@0002D000<10000^`0001D000<10000
BP000`40002k00005@000`40001900030@000;`0000E00030@000?l02@0001D000<10000o`090000
5@000`40000S00030@000>80000E00030@0002<000<10000hP0001D00P4U00030@00020000<10000
_P0001D000<1000090000`40000O00030@000;l0000E00030@0002D000<100007P000`40002o0000
5@000`40000U00030@0001d000<10000`00001D000<10000A@000`40003000005@000`4000140003
0@000<40000E00030@000?l02@0001D000<10000o`0900005@000`40000V00030@000=l0000E0081
9`000`40000I00030@000<<0000E00030@0002L000<100005`000`40003400005@000`40000W0003
0@0001L000<10000a00001D000<10000:0000`40000E00030@000<D0000E00030@0002P000<10000
5@000`40003500005@000`40000o00030@000<H0000E00030@000?l02@0001D000<10000o`090000
00<00@400P4300030@000080104400030@000?l02@0000<000<100001`000`40000500<1:P000`40
003K00000`000`40000800030@0000@000<10000:`000`40000>00030@000<T0000300030@0000T0
00<100000`000`40000[00030@0000d000<10000bP0000<000<100002P000`40000200030@0002`0
00<1000030000`40003:000000@00@412@001040004400030@0002d000<10000f00000<000<10000
20020@D000<10000;@000`40003H00005@000`40003o00T0000E00030@0003H00P7@00005@000`40
000b00@1dP0001D00P7o00X0000E00030@000?l02@0001D000<10000o`0900005@000`40003o00T0
003o0240003o0240003o0240003o02400000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0825959, 0.303946, 
  0.00385924, 0.00558344}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stepResponsePZ2\  = \ 
      Plot[\((stepResponse[r\ , i\ , c\ , d\ , n\ , m\ , \ t]\  /. \ 
            polesZeroes2)\), {t, 0, 1}, PlotRange -> All]; \)\)], "Input",
  InitializationCell->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0442106 0.583859 [
[.21429 .52715 -9 -9 ]
[.21429 .52715 9 0 ]
[.40476 .52715 -9 -9 ]
[.40476 .52715 9 0 ]
[.59524 .52715 -9 -9 ]
[.59524 .52715 9 0 ]
[.78571 .52715 -9 -9 ]
[.78571 .52715 9 0 ]
[.97619 .52715 -3 -9 ]
[.97619 .52715 3 0 ]
[.01131 .07256 -18 -4.5 ]
[.01131 .07256 0 4.5 ]
[.01131 .18933 -18 -4.5 ]
[.01131 .18933 0 4.5 ]
[.01131 .30611 -18 -4.5 ]
[.01131 .30611 0 4.5 ]
[.01131 .42288 -18 -4.5 ]
[.01131 .42288 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .53965 m
.21429 .5459 L
s
[(0.2)] .21429 .52715 0 1 Mshowa
.40476 .53965 m
.40476 .5459 L
s
[(0.4)] .40476 .52715 0 1 Mshowa
.59524 .53965 m
.59524 .5459 L
s
[(0.6)] .59524 .52715 0 1 Mshowa
.78571 .53965 m
.78571 .5459 L
s
[(0.8)] .78571 .52715 0 1 Mshowa
.97619 .53965 m
.97619 .5459 L
s
[(1)] .97619 .52715 0 1 Mshowa
.125 Mabswid
.07143 .53965 m
.07143 .5434 L
s
.11905 .53965 m
.11905 .5434 L
s
.16667 .53965 m
.16667 .5434 L
s
.2619 .53965 m
.2619 .5434 L
s
.30952 .53965 m
.30952 .5434 L
s
.35714 .53965 m
.35714 .5434 L
s
.45238 .53965 m
.45238 .5434 L
s
.5 .53965 m
.5 .5434 L
s
.54762 .53965 m
.54762 .5434 L
s
.64286 .53965 m
.64286 .5434 L
s
.69048 .53965 m
.69048 .5434 L
s
.7381 .53965 m
.7381 .5434 L
s
.83333 .53965 m
.83333 .5434 L
s
.88095 .53965 m
.88095 .5434 L
s
.92857 .53965 m
.92857 .5434 L
s
.25 Mabswid
0 .53965 m
1 .53965 L
s
.02381 .07256 m
.03006 .07256 L
s
[(0.2)] .01131 .07256 1 0 Mshowa
.02381 .18933 m
.03006 .18933 L
s
[(0.4)] .01131 .18933 1 0 Mshowa
.02381 .30611 m
.03006 .30611 L
s
[(0.6)] .01131 .30611 1 0 Mshowa
.02381 .42288 m
.03006 .42288 L
s
[(0.8)] .01131 .42288 1 0 Mshowa
.125 Mabswid
.02381 .10175 m
.02756 .10175 L
s
.02381 .13095 m
.02756 .13095 L
s
.02381 .16014 m
.02756 .16014 L
s
.02381 .21853 m
.02756 .21853 L
s
.02381 .24772 m
.02756 .24772 L
s
.02381 .27691 m
.02756 .27691 L
s
.02381 .3353 m
.02756 .3353 L
s
.02381 .36449 m
.02756 .36449 L
s
.02381 .39368 m
.02756 .39368 L
s
.02381 .45207 m
.02756 .45207 L
s
.02381 .48126 m
.02756 .48126 L
s
.02381 .51046 m
.02756 .51046 L
s
.02381 .04337 m
.02756 .04337 L
s
.02381 .01418 m
.02756 .01418 L
s
.02381 .56884 m
.02756 .56884 L
s
.02381 .59803 m
.02756 .59803 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .01947 m
.02499 .01832 L
.02605 .01742 L
.02721 .0166 L
.02846 .01588 L
.02961 .01537 L
.03068 .01503 L
.0317 .01482 L
.03279 .01472 L
.03395 .01474 L
.0352 .01491 L
.03638 .01522 L
.03746 .01562 L
.03873 .01622 L
.04011 .01704 L
.04262 .01898 L
.04759 .02437 L
.0529 .03221 L
.06244 .05113 L
.07382 .0805 L
.08454 .11366 L
.10458 .18608 L
.14313 .34309 L
.16268 .42022 L
.18413 .49433 L
.19399 .523 L
.20456 .54924 L
.21446 .56925 L
.22362 .58364 L
.22846 .58962 L
.23379 .59493 L
.23916 .59893 L
.2421 .60056 L
.24486 .60174 L
.24732 .60251 L
.24856 .6028 L
.24991 .60304 L
.25107 .60319 L
.25231 .60329 L
.25348 .60332 L
.25454 .6033 L
.2552 .60327 L
.25588 .60321 L
.25712 .60307 L
.25781 .60297 L
.25845 .60285 L
.25991 .60253 L
.26236 .60183 L
.26498 .60083 L
.27024 .59814 L
Mistroke
.27511 .59489 L
.28616 .58522 L
.30626 .56222 L
.32509 .53899 L
.34544 .51754 L
.35088 .51305 L
.35662 .50901 L
.36194 .50597 L
.36689 .50377 L
.37154 .50228 L
.37415 .50169 L
.3753 .50149 L
.37652 .50131 L
.37716 .50123 L
.37787 .50116 L
.37912 .50106 L
.37982 .50103 L
.38058 .501 L
.38129 .50099 L
.38194 .50099 L
.38314 .50102 L
.38445 .5011 L
.3851 .50116 L
.38581 .50123 L
.38708 .50139 L
.38967 .50184 L
.39242 .5025 L
.39734 .50413 L
.40264 .50649 L
.40846 .50976 L
.42863 .52537 L
.44974 .54545 L
.46902 .56284 L
.47857 .56998 L
.48361 .57318 L
.48897 .57609 L
.49364 .57818 L
.49612 .57911 L
.4988 .57997 L
.50124 .58063 L
.50349 .58112 L
.50563 .58149 L
.50681 .58165 L
.50789 .58177 L
.50912 .58187 L
.50977 .58192 L
.51046 .58195 L
.51161 .58199 L
.51288 .58199 L
.51401 .58197 L
Mistroke
.51523 .58191 L
.51637 .58183 L
.51742 .58173 L
.51992 .5814 L
.52265 .58089 L
.52522 .58026 L
.52761 .57956 L
.5365 .57597 L
.54597 .57062 L
.5674 .55417 L
.58757 .53624 L
.60596 .52107 L
.6164 .514 L
.6215 .5111 L
.62614 .50883 L
.63076 .50693 L
.63577 .5053 L
.63853 .5046 L
.64108 .50408 L
.64351 .5037 L
.64474 .50355 L
.6461 .50341 L
.64743 .50332 L
.6481 .50328 L
.64883 .50325 L
.65012 .50323 L
.65133 .50323 L
.65206 .50325 L
.65276 .50327 L
.65405 .50334 L
.65478 .5034 L
.65545 .50346 L
.65697 .50362 L
.65933 .50395 L
.66192 .50444 L
.66717 .50579 L
.67239 .50759 L
.67734 .5097 L
.68663 .5146 L
.70753 .52884 L
.72761 .54415 L
.74579 .55666 L
.75528 .56195 L
.76552 .56636 L
.77116 .56813 L
.77363 .56875 L
.77634 .56932 L
.77873 .56972 L
.78129 .57005 L
.7827 .57019 L
Mistroke
.78399 .57028 L
.78528 .57035 L
.78651 .57039 L
.78765 .57041 L
.78889 .5704 L
.79005 .57037 L
.79112 .57033 L
.79236 .57025 L
.79372 .57014 L
.7962 .56986 L
.79878 .56946 L
.80152 .56893 L
.80647 .5677 L
.81614 .5643 L
.82491 .56025 L
.86496 .53556 L
.88333 .52483 L
.89376 .51997 L
.89886 .51803 L
.9035 .51654 L
.90811 .51533 L
.91312 .51434 L
.91587 .51394 L
.91708 .5138 L
.91841 .51366 L
.91958 .51357 L
.92085 .51348 L
.92154 .51345 L
.92218 .51342 L
.92343 .51338 L
.92466 .51337 L
.92597 .51337 L
.92721 .5134 L
.92833 .51345 L
.92965 .51352 L
.93109 .51363 L
.93369 .51389 L
.93642 .51426 L
.93931 .51477 L
.94449 .51593 L
.95239 .5183 L
.96087 .52158 L
.97619 .52894 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`>?U]kOUiBgUFbJo_bI<_bJoC000oooG0;nH]P000000E@00ZP00o`1E001EE@1EZP1Eo`2Z
002ZE@2ZZP2Zo`3o003oE@3oZP3ooeD005D0EED0ZUD0oeEE05EEEEEEZUEEoeFZ05FZEEFZZUFZoeGo
05GoEEGoZUGoojX00:X0EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZZZoj[o0:[oEJ[oZZ[oool0
0?l0EOl0Z_l0oomE0?mEEOmEZ_mEoonZ0?nZEOnZZ_nZoooo0?ooEOooZ_ooo`0001lO7clo?emOGgmo
OinOWkno_moOgoooonKVi]WIfDa<C;OU`]cU;Nc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a
/JRXZ:2PX=Rof8:2PXj>SWalO7EeMH9cPYVIV@00?mFgi@00O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03loOclo_clo
ocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0
oglo07lo?gloOglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl0
0;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo
?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono
_onooooo?oooOooo_n[ZjWAdM:NWYjj^[WMgMiUVc9UVoiVI09VI<iVIIYVIc9VIoiW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I_l08@000?l08@000?l08@000?l08@0001D0
00<10000o`0900005@000`40003o00T0000E00030@000?l02@0001D000<10000o`0900005@050Ol0
1`0001D00P420081o`0600005@000`40000300030@000?l00`0001D000<100000`000`40003o00<0
000E00030@0000@000<10000o`0200005@000`40000500030@000?l00@0001D000<100001@000`40
003o0040000E00030@0000H000<10000o`0001D00P4700030@000?l0000E00030@0000L000<10000
oP0001D000<100001`000`40003n00005@000`40000800030@000?d0000E00030@0000P000<10000
o@0001D000<100002@000`40003l00000P020@@000<100000P040@@000<100002@000`40003l0000
00D00@000@0800030@0000D000<100002P000`40003k000000D00@000@0900030@0000@00`4:0003
0@000?/000001@01000100X000<100000`000`40000;00030@000?X000001@01000100/000<10000
0P000`40000;00030@000?X000001@01000100P000@1000110000`40000;00030@000?X000020081
2P020@D000<100002`000`40003j00005@000`40000<00030@000?T0000E00030@0000`000<10000
n@0001D000<1000030000`40003i00005@020@d000<10000n@0001D000<100003@000`40003h0000
5@000`40000=00030@000?P0000E00030@0000d000<10000n00001D000<100003@000`40003h0000
5@000`40000>00030@000?L0000E00030@0000h000<10000m`0001D000<100003P000`40003g0000
5@020A0000<10000mP0001D000<100003`000`40003f00005@000`40000?00030@000?H0000E0003
0@0000l000<10000mP0001D000<1000040000`40003e00005@000`40000@00030@000?D0000E0003
0@00010000<10000m@0001D000<100004@000`40003d00005@020A8000<10000m00001D000<10000
4@000`40003d00005@000`40000B00030@000?<0000E00030@00018000<10000l`0001D000<10000
4P000`40003c00005@000`40000B00030@000?<00002008110000`40000400030@0000<000<10000
4`000`40003b000000D00@000@0:00030@0000<00`4C00030@000?8000001@01000100L01@440003
0@0001<000<10000lP000005004000401`001040004500030@0001<000<10000lP00000500400040
20000`400@0500030@0001@000<10000l@000005004000402@020@D000<1000050000`40003a0000
0P020@/000<100000`000`40000D00030@000?40000E00030@0001@000<10000l@0001D000<10000
5@000`40003`00005@020AH000<10000l00001D000<100005@000`40003`00005@000`40000E0003
0@000?00000E00030@0001H000<10000k`0001D000<100005P000`40003_00005@000`40000F0003
0@000>l0000E00030@0001H000<10000k`0001D000<100005`000`40003^00005@020AP000<10000
kP0001D000<100005`000`40003^00005@000`40000G00030@000>h0000E00030@0001P000<10000
k@0001D000<1000060000`40003]00005@000`40000H00030@000>d0000E00030@0001P000<10000
k@0001D000<1000060000`40003]00005@020AX000<10000k00001D000<100006@000`40003/0000
5@000`40000I00030@000>`0000E00030@0001T000<10000k00001D000<100006P000`40003[0000
5@000`40000J00030@000>/0000E00030@0001X000<10000j`0000800P4400030@0000<00P450003
0@0001X000<10000j`0000050040004020001040004400<16`000`40003Z000000D00@000@080004
0@000@@000<100006`000`40003Z000000D00@000@0800<11@000`40000K00030@000>X000001@01
000100P000<100001@000`40000K00030@000>X000001@01000100P000<100001@000`40000L0003
0@000>T0000200812P030@@000<1000070000`40003Y00005@000`40000L00030@000>T0000E0003
0@0001`000<10000j@0001D00P4N00030@000>P0000E00030@0001d000<10000j00001D000<10000
7@000`40003X00005@000`40000M00030@000>P0000E00030@0001h000<10000i`0001D000<10000
7P000`40003W00005@000`40000N00030@000>L0000E00030@0001h000<10000i`0001D00P4P0003
0@000>H0000E00030@0001l000<10000iP0001D000<100007`000`40003V00005@000`40000P0003
0@000>D0000E00030@00020000<10000i@0001D000<1000080000`40003U00005@000`40000P0003
0@000>D0000E00030@00024000<10000i00001D00P4R00030@000>@0000E00030@00024000<10000
i00001D000<100008P000`40003S00005@000`40000R00030@000><0000E00030@00028000<10000
h`0001D000<100008P000`40003S00005@000`40000S00030@000>800002008110000`4000030081
1@000`40000S00030@000>8000001@01000100P000@1000110030B<000<10000hP00000500400040
20001040004400030@0002@000<10000h@000005004000402@020@D000<1000090000`40003Q0000
00D00@000@0800040@000@@000<1000090000`40003Q000000D00@000@0800040@000@@000<10000
9@000`40003P00000P020@X00P4500030@0002D000<10000h00001D000<100009@000`40003P0000
5@000`40000U00030@000>00000E00819`000`40003O00005@000`40000V00030@000=l0000E0003
0@0002H000<10000g`0001D000<100009`000`40003N00005@000`40000W00030@000=h0000E0003
0@0002L000<10000gP0001D000<10000:0000`40003M00005@000`40000X00030@000=d0000E0081
:@000`40003M00005@000`40000X00030@000=d0000E00030@0002T000<10000g00001D000<10000
:@000`40003L00005@000`40000Y00030@000=`0000E00030@0002X000<10000;`050JL0000E0003
0@0002X000<10000;@030@@00`4o00T1G00001D000<10000:P020@@000<100000P040Ah00`440081
10020@D000<100008`020@@000<100000`020@800P4900<15P020@@000<100000`020B/010460000
5@020BX00P400`01000700030@0001l000<100000`001040004500030@00008000<100008P001040
004800030@0000813P020A<000@1000120001040004/00030@0000D0000E00030@0002T000@10041
2@000`40000L00811P001040004600H18`001040004800040@010A4000<100004000104000480004
0@000AP03@4700030@0000D0000E00030@0002T000@100412P000`40000J00030@0000H000@10001
1`020@03004002<000@1000120030A<00P4@00040@000@T00P4G00813@030@@000<100001@0001D0
00<10000:@0010400@4;00030@0001P000<100001`001040004800<190001040004700815`000`40
000=00040@000@P000@1000150020A800P4200030@0000D0000E00030@0002T000@1004120001040
004I00030@0000P000@100012@020B@000@100011P000`400@0H00813@001040004800040@000A<0
00<1000050030@L0000E00030@0002X00`4900816P000`40000900812`020B@00P4500810`030AL0
00<100002`020@X00P4B00816@000`40000500005@000`40000/00030@00028000<100006@020BP0
00<100007P000`40000X00818`0001D000<10000;@000`40000P00030@0001`000<1000090000`40
000P00819`000`40000S00003P3o0A<1000E00030@0000X000<100002P000`40000:00030@0000L0
00@1000130000`40000:00040@000@T000<100002P000`40000900812`000`40000:00030@0000H0
00D100000@0<00030@0000X000<100001`001040004<00030@0000X000<100000P020@H000<10000
2P000`40000:00030@0000D0000E00030@0002h000<1000070000`40000R00030@0001h000<10000
9`020Ad00P4Z00005@000`40000_00030@0001/000<100008`000`40000L00030@0002X00P4I0081
;00001D000<10000;`000`40000J00030@0002D000<100006P000`40000]00030@0001@00P4^0000
5@000`40000`00030@0001P000<100009`000`40000G0081<@020A800P4`00005@000`40000`0003
0@0001L000<10000:@000`40000E00030@0003<00P4=00<1<P0001D000<10000<@000`40000E0003
0@0002/00P4C0081>0020@T00P4e00005@020C8000<1000050000`40000^00030@0000l000<10000
>P090CL0000E00030@00038000<100004P000`40000`00030@0000`00P5m00005@000`40000b0003
0@00014000<10000<P030@T00P5o00005@000`40000c00030@0000l000<10000=@0:0H40000E0003
0@0003<00P4?00030@000<40000E00030@0003D000<100002`000`40003200005@000`40000f0003
0@0000T000<10000``0001D000<10000=P000`40000800030@000<@0000E0081>0020@H00P770000
5@000`40000i00H1b@0001D000<10000o`0900005@000`40003o00T0000E00030@000?l02@0001D0
00<10000o`090000o`0Q0000o`0Q0000o`0Q0000o`0Q0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0825959, 0.0480628, 
  0.00385924, 0.00629512}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stepResponsesPZ\  = \ 
      Show[stepResponsePZ1, \ stepResponsePZ2, 
        AxesLabel -> {"\<t\>", "\<\>"}, PlotLabel -> "\<Step Response\>"]; 
    \)\)], "Input",
  InitializationCell->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0372091 0.514486 [
[.21429 .46478 -9 -9 ]
[.21429 .46478 9 0 ]
[.40476 .46478 -9 -9 ]
[.40476 .46478 9 0 ]
[.59524 .46478 -9 -9 ]
[.59524 .46478 9 0 ]
[.78571 .46478 -9 -9 ]
[.78571 .46478 9 0 ]
[.97619 .46478 -3 -9 ]
[.97619 .46478 3 0 ]
[1.025 .47728 0 -7.5 ]
[1.025 .47728 10 7.5 ]
[.01131 .06569 -18 -4.5 ]
[.01131 .06569 0 4.5 ]
[.01131 .16859 -18 -4.5 ]
[.01131 .16859 0 4.5 ]
[.01131 .27148 -18 -4.5 ]
[.01131 .27148 0 4.5 ]
[.01131 .37438 -18 -4.5 ]
[.01131 .37438 0 4.5 ]
[.01131 .58017 -18 -4.5 ]
[.01131 .58017 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 15 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .47728 m
.21429 .48353 L
s
[(0.2)] .21429 .46478 0 1 Mshowa
.40476 .47728 m
.40476 .48353 L
s
[(0.4)] .40476 .46478 0 1 Mshowa
.59524 .47728 m
.59524 .48353 L
s
[(0.6)] .59524 .46478 0 1 Mshowa
.78571 .47728 m
.78571 .48353 L
s
[(0.8)] .78571 .46478 0 1 Mshowa
.97619 .47728 m
.97619 .48353 L
s
[(1)] .97619 .46478 0 1 Mshowa
.125 Mabswid
.07143 .47728 m
.07143 .48103 L
s
.11905 .47728 m
.11905 .48103 L
s
.16667 .47728 m
.16667 .48103 L
s
.2619 .47728 m
.2619 .48103 L
s
.30952 .47728 m
.30952 .48103 L
s
.35714 .47728 m
.35714 .48103 L
s
.45238 .47728 m
.45238 .48103 L
s
.5 .47728 m
.5 .48103 L
s
.54762 .47728 m
.54762 .48103 L
s
.64286 .47728 m
.64286 .48103 L
s
.69048 .47728 m
.69048 .48103 L
s
.7381 .47728 m
.7381 .48103 L
s
.83333 .47728 m
.83333 .48103 L
s
.88095 .47728 m
.88095 .48103 L
s
.92857 .47728 m
.92857 .48103 L
s
.25 Mabswid
0 .47728 m
1 .47728 L
s
gsave
1.025 .47728 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(t) show
69.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .06569 m
.03006 .06569 L
s
[(0.2)] .01131 .06569 1 0 Mshowa
.02381 .16859 m
.03006 .16859 L
s
[(0.4)] .01131 .16859 1 0 Mshowa
.02381 .27148 m
.03006 .27148 L
s
[(0.6)] .01131 .27148 1 0 Mshowa
.02381 .37438 m
.03006 .37438 L
s
[(0.8)] .01131 .37438 1 0 Mshowa
.02381 .58017 m
.03006 .58017 L
s
[(1.2)] .01131 .58017 1 0 Mshowa
.125 Mabswid
.02381 .09141 m
.02756 .09141 L
s
.02381 .11714 m
.02756 .11714 L
s
.02381 .14286 m
.02756 .14286 L
s
.02381 .19431 m
.02756 .19431 L
s
.02381 .22003 m
.02756 .22003 L
s
.02381 .24576 m
.02756 .24576 L
s
.02381 .29721 m
.02756 .29721 L
s
.02381 .32293 m
.02756 .32293 L
s
.02381 .34866 m
.02756 .34866 L
s
.02381 .4001 m
.02756 .4001 L
s
.02381 .42583 m
.02756 .42583 L
s
.02381 .45155 m
.02756 .45155 L
s
.02381 .503 m
.02756 .503 L
s
.02381 .52873 m
.02756 .52873 L
s
.02381 .55445 m
.02756 .55445 L
s
.02381 .03996 m
.02756 .03996 L
s
.02381 .01424 m
.02756 .01424 L
s
.02381 .6059 m
.02756 .6059 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Step) show
93.000000 15.000000 moveto
(Response) show
141.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 Mabswid
[ .02 .02 ] 0 setdash
.02381 .16475 m
.02846 .15529 L
.03279 .149 L
.03527 .14645 L
.03754 .1448 L
.03879 .14414 L
.0395 .14386 L
.04015 .14364 L
.04135 .14338 L
.04262 .14329 L
.04384 .14337 L
.04496 .1436 L
.04626 .14403 L
.04749 .14461 L
.04967 .14603 L
.05205 .14815 L
.05466 .15113 L
.05744 .15503 L
.06244 .16382 L
.07382 .19136 L
.08454 .22511 L
.10458 .30116 L
.14313 .45495 L
.16307 .51991 L
.17324 .54643 L
.18413 .5693 L
.18941 .57824 L
.19441 .58541 L
.19927 .5912 L
.20377 .59552 L
.20803 .59871 L
.21255 .60116 L
.2149 .60206 L
.21709 .60269 L
.21835 .60295 L
.21951 .60313 L
.22077 .60326 L
.22141 .6033 L
.22211 .60332 L
.22342 .60331 L
.22464 .60323 L
.22528 .60317 L
.22598 .60309 L
.22739 .60285 L
.22863 .60258 L
.22997 .60222 L
.23238 .60139 L
.23726 .59908 L
.24172 .59626 L
.25246 .58694 L
Mistroke
.26267 .57535 L
.30091 .51895 L
.32227 .48663 L
.34161 .46141 L
.35131 .45091 L
.3618 .44146 L
.3717 .43446 L
.38079 .4297 L
.38551 .42788 L
.3881 .42705 L
.39055 .42639 L
.39284 .42588 L
.39532 .42543 L
.39757 .42512 L
.39866 .425 L
.39965 .42491 L
.40084 .42483 L
.40212 .42477 L
.40324 .42474 L
.40443 .42474 L
.40573 .42476 L
.40694 .4248 L
.40764 .42484 L
.40827 .42488 L
.40969 .42499 L
.41232 .42529 L
.41517 .42574 L
.42033 .42687 L
.42524 .4283 L
.42982 .42992 L
.44025 .43456 L
.4613 .44693 L
.50018 .47381 L
.51997 .48605 L
.53041 .49147 L
.54151 .49623 L
.55133 .49949 L
.55692 .50094 L
.56218 .50201 L
.56452 .5024 L
.56698 .50275 L
.56911 .503 L
.57139 .50322 L
.57267 .50333 L
.57384 .50341 L
.57503 .50347 L
.57613 .50353 L
.57741 .50357 L
.57808 .50359 L
.5788 .5036 L
Mistroke
.58 .50361 L
.58132 .50361 L
.58261 .50359 L
.58381 .50356 L
.58512 .50351 L
.58652 .50344 L
.58912 .50326 L
.59147 .50305 L
.59624 .50247 L
.60074 .50176 L
.61078 .49961 L
.62163 .49655 L
.66265 .48107 L
.68309 .47326 L
.69307 .46992 L
.70216 .46728 L
.71095 .46514 L
.7205 .46334 L
.72574 .4626 L
.73059 .46208 L
.73298 .46188 L
.73523 .46172 L
.73757 .46159 L
.73881 .46154 L
.74015 .4615 L
.74141 .46147 L
.74255 .46145 L
.74387 .46143 L
.74511 .46143 L
.74627 .46144 L
.74733 .46145 L
.7485 .46148 L
.74973 .46151 L
.75231 .46162 L
.75472 .46175 L
.75736 .46194 L
.76021 .46219 L
.76587 .46282 L
.77124 .46357 L
.78131 .46537 L
.81957 .47499 L
.84095 .48066 L
.86029 .48487 L
.87001 .48645 L
.87511 .48711 L
.8805 .48768 L
.88522 .48805 L
.8879 .48822 L
.8904 .48834 L
.89158 .48839 L
Mistroke
.8927 .48842 L
.89372 .48845 L
.89479 .48848 L
.89596 .4885 L
.89705 .48851 L
.89821 .48851 L
.89949 .48851 L
.90078 .4885 L
.90198 .48849 L
.90329 .48846 L
.90469 .48843 L
.90728 .48834 L
.90962 .48822 L
.9144 .48792 L
.91889 .48753 L
.92892 .48637 L
.93977 .4847 L
.97619 .47729 L
Mfstroke
[ ] 0 setdash
.02381 .0189 m
.02499 .01789 L
.02605 .0171 L
.02721 .01637 L
.02846 .01574 L
.02961 .01529 L
.03068 .01499 L
.0317 .01481 L
.03279 .01472 L
.03395 .01473 L
.0352 .01489 L
.03638 .01516 L
.03746 .01551 L
.03873 .01604 L
.04011 .01677 L
.04262 .01847 L
.04759 .02322 L
.0529 .03013 L
.06244 .0468 L
.07382 .07268 L
.08454 .1019 L
.10458 .16572 L
.14313 .30407 L
.16268 .37204 L
.18413 .43734 L
.19399 .46261 L
.20456 .48573 L
.21446 .50336 L
.22362 .51604 L
.22846 .52131 L
.23379 .52599 L
.23916 .52951 L
.2421 .53095 L
.24486 .53199 L
.24732 .53267 L
.24856 .53293 L
.24991 .53314 L
.25107 .53327 L
.25231 .53335 L
.25348 .53338 L
.25454 .53337 L
.2552 .53334 L
.25588 .53329 L
.25712 .53316 L
.25781 .53307 L
.25845 .53297 L
.25991 .53269 L
.26236 .53207 L
.26498 .53119 L
.27024 .52882 L
Mistroke
.27511 .52595 L
.28616 .51743 L
.30626 .49717 L
.32509 .4767 L
.34544 .4578 L
.35088 .45384 L
.35662 .45028 L
.36194 .4476 L
.36689 .44566 L
.37154 .44435 L
.37415 .44383 L
.3753 .44365 L
.37652 .4435 L
.37716 .44343 L
.37787 .44336 L
.37912 .44328 L
.37982 .44324 L
.38058 .44322 L
.38129 .44321 L
.38194 .44321 L
.38314 .44324 L
.38445 .44331 L
.3851 .44336 L
.38581 .44342 L
.38708 .44356 L
.38967 .44396 L
.39242 .44454 L
.39734 .44598 L
.40264 .44806 L
.40846 .45094 L
.42863 .4647 L
.44974 .48238 L
.46902 .49771 L
.47857 .50401 L
.48361 .50683 L
.48897 .50939 L
.49364 .51123 L
.49612 .51205 L
.4988 .51281 L
.50124 .51339 L
.50349 .51382 L
.50563 .51414 L
.50681 .51428 L
.50789 .51439 L
.50912 .51448 L
.50977 .51452 L
.51046 .51455 L
.51161 .51459 L
.51288 .51459 L
.51401 .51457 L
Mistroke
.51523 .51452 L
.51637 .51445 L
.51742 .51436 L
.51992 .51407 L
.52265 .51361 L
.52522 .51306 L
.52761 .51244 L
.5365 .50928 L
.54597 .50457 L
.5674 .49007 L
.58757 .47427 L
.60596 .46091 L
.6164 .45467 L
.6215 .45212 L
.62614 .45012 L
.63076 .44844 L
.63577 .44701 L
.63853 .44639 L
.64108 .44593 L
.64351 .4456 L
.64474 .44546 L
.6461 .44535 L
.64743 .44526 L
.6481 .44523 L
.64883 .44521 L
.65012 .44518 L
.65133 .44519 L
.65206 .4452 L
.65276 .44522 L
.65405 .44529 L
.65478 .44533 L
.65545 .44538 L
.65697 .44553 L
.65933 .44582 L
.66192 .44625 L
.66717 .44744 L
.67239 .44903 L
.67734 .45089 L
.68663 .4552 L
.70753 .46775 L
.72761 .48124 L
.74579 .49227 L
.75528 .49693 L
.76552 .50081 L
.77116 .50237 L
.77363 .50292 L
.77634 .50342 L
.77873 .50378 L
.78129 .50407 L
.7827 .50419 L
Mistroke
.78399 .50427 L
.78528 .50433 L
.78651 .50437 L
.78765 .50438 L
.78889 .50437 L
.79005 .50435 L
.79112 .50431 L
.79236 .50424 L
.79372 .50414 L
.7962 .5039 L
.79878 .50355 L
.80152 .50308 L
.80647 .50199 L
.81614 .499 L
.82491 .49543 L
.86496 .47367 L
.88333 .46422 L
.89376 .45994 L
.89886 .45823 L
.9035 .45691 L
.90811 .45585 L
.91312 .45497 L
.91587 .45462 L
.91708 .4545 L
.91841 .45438 L
.91958 .45429 L
.92085 .45422 L
.92154 .45419 L
.92218 .45417 L
.92343 .45413 L
.92466 .45412 L
.92597 .45412 L
.92721 .45415 L
.92833 .45419 L
.92965 .45425 L
.93109 .45435 L
.93369 .45458 L
.93642 .45491 L
.93931 .45535 L
.94449 .45637 L
.95239 .45847 L
.96087 .46135 L
.97619 .46784 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`>?U]kOUiBgUFbJo_bI<_bJoC000oooG0;nH]P000000E@00ZP00o`1E001EE@1EZP1Eo`2Z
002ZE@2ZZP2Zo`3o003oE@3oZP3ooeD005D0EED0ZUD0oeEE05EEEEEEZUEEoeFZ05FZEEFZZUFZoeGo
05GoEEGoZUGoojX00:X0EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZZZoj[o0:[oEJ[oZZ[oool0
0?l0EOl0Z_l0oomE0?mEEOmEZ_mEoonZ0?nZEOnZZ_nZoooo0?ooEOooZ_ooo`0001lO7clo?emOGgmo
OinOWkno_moOgoooonKVi]WIfDa<C;OU`]cU;Nc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a
/JRXZ:2PX=Rof8:2PXj>SWalO7EeMH9cPYVIV@00?mFgi@00O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03loOclo_clo
ocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0
oglo07lo?gloOglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl0
0;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo
?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono
_onooooo?oooOooo_n[ZjWAdM:NWYjj^[WMgMiUVc9UVoiVI09VI<iVIIYVIc9VIoiW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0IQD000<10000o`0900005@000`40003o00T0
000E00030@000?l02@0001D000<10000o`0900005@050Ol01`0001D000<100000P000`40003o00@0
000E00030@0000<000<10000o`0300005@000`40000400030@000?l00P0001D000<1000010000`40
003o0080000E00030@0000D000<10000o`0100005@020@L000<10000o`0001D000<100001P000`40
003o00005@000`40000700030@000?h0000E00030@0000L000<10000oP0001D000<1000020000`40
003m00000P020@@000<100000P040@@000<1000020000`40003m000000D00@000@0800030@0000D0
00<1000020000`40003m000000D00@000@0900030@0000@00P4900030@000?d000001@01000100X0
00<100000`000`40000900030@000?`000001@01000100/000<100000P000`40000900030@000?`0
00001@01000100P000@1000110000`40000900030@000?`0000200812P020@D000<100002P000`40
003k00005@000`40000:00030@000?/0000E008130000`40003j00005@000`40000;00030@000?X0
000E00030@0000`000<10000n@0001D000<1000030000`40003i00005@000`40000<00030@000?T0
000E00030@0000d000<10000n00001D000<100003@000`40003h00005@020@h000<10000n00001D0
00<100003P000`40003g00005@000`40000>00030@000?L0000E00030@0000h000<10000m`0001D0
00<100003`000`40003f00005@000`40000?00030@000?H0000E008140000`40003f00005@001040
00030@/000<10000mP0001D000<1000010000`40000900030@000?D0000E00030@0000D000<10000
20000`40003e00005@020A4000<10000m@0001D00P4B00030@000?@00002008110000`4000040003
0@0000<000<100004@000`40003d000000D00@000@0:00030@0000<00P4B00030@000?@000001@01
000100L01@4400030@0000L000<1000020000`40003c000000D00@000@0700040@000@D000<10000
20000`40000700030@000?<000001@01000100P000<100401@000`40000800030@0000L000<10000
l`000005004000402@020@D000<100002@000`40000600030@000?<0000200812`000`4000030003
0@0000T000<100001`000`40003b00005@000`40000C00030@000?80000E008150000`40003b0000
5@000`40000D00030@000?40000E00030@0001@000<10000l@0001D000<100002`000`4000060003
0@000?40000E00030@0000/000<100001P000`40003a00005@000`40000<00030@0000H000<10000
l00001D00P4=00030@0000H000<10000l00001D000<1000030000`40000600030@000?00000E0003
0@0000`000<100001P000`40003`00005@000`40000F00030@000>l0000E00030@0001H000<10000
k`0001D000<100005P000`40003_00005@000`40000G00030@000>h0000E00813`000`4000060003
0@000>h0000E00030@0000h000<100001P000`40003^00005@000`40000>00030@0000H000<10000
kP0001D000<100003`000`40000600030@000>d0000E00030@0000l000<100001P000`40003]0000
0P020@@000<100000`020@D000<100003`000`40000600030@000>d000001@01000100P000@10001
10020AX000<10000k00000050040004020001040004400030@0001T000<10000k000000500400040
20030@D000<100006@000`40003/000000D00@000@0800030@0000D000<100006@000`40003/0000
00D00@000@0800030@0000D000<1000040000`40000700030@000>/0000200812P030@@000<10000
40000`40000700030@000>/0000E00030@00014000<100001P000`40003[00005@020A8000<10000
1P000`40003[00005@000`40000A00030@0000L000<10000jP0001D000<100004P000`4000060003
0@000>X0000E00030@0001/000<10000jP0001D000<1000070000`40003Y00005@000`40000L0003
0@000>T0000E00817@000`40003Y00005@000`40000C00030@0000H000<10000j@0001D000<10000
4`000`40000700030@000>P0000E00030@0001<000<100001`000`40003X00005@000`40000D0003
0@0000H000<10000j00001D000<1000050000`40000700030@000>L0000E00030@0001@000<10000
1`000`40003W00005@020Al000<10000i`0001D000<100007`000`40003V00005@000`40000O0003
0@000>H0000E00030@0001l000<10000iP0001D000<100005@000`40000700030@000>H000020081
10000`40000300811@000`40000E00030@0000P000<10000i@000005004000402000104000440003
0@0001H000<100001`000`40003U000000D00@000@0800040@000@@00P4G00030@0000L000<10000
i@000005004000402@020@D000<100005`000`40000700030@000>@000001@01000100P000@10001
10000`40000G00030@0000L000<10000i00000050040004020001040004400030@00024000<10000
i00000800P4:00811@000`40000R00030@000><0000E00030@00028000<10000h`0001D00P4S0003
0@000><0000E00030@0001P000<1000020000`40003R00005@000`40000H00030@0000P000<10000
hP0001D000<1000060000`40000900030@000>40000E00030@0001T000<1000020000`40003Q0000
5@000`40000I00030@0000P000<10000h@0001D000<100006@000`40000900030@000>00000E0081
9P000`40000a00@11@020J@0000E00030@0002D000<10000<0000`4000090081XP0001D000<10000
9P000`40000m00030@0009l0000E00030@0002H000<10000g`0001D000<100006P000`4000090081
10000`40000200@17P000`4000050@8000<1000010000`40000400030@0001X00P4400030@0000<0
0P4R008110000`4000030081:0040AH0000E00030@0001X000<10000200010400@4800030@0001d0
1P4200030@0100<11@000`40000500030@0001P000@1000120001040004200T15@00104000480004
0@000BT000<100005@0001D00P4L00030@0000L000@100412@000`40000K00<10`00104000450003
0@0100@11`020AP000@1000120000`400@030@T0104A00040@000@P000@10001:@000`40000E0000
5@000`40000K00030@0000L000@100412P000`40000I00811@001040004600810P000`4000080003
0@0001D000@1000120030A0000<100003P00104000490081600:0@P000<100005@0001D000<10000
70000`40000600040@000@/000<1000060000`40000400040@000@L00P400`01000Q00040@000@L0
0P4C00813P001040004800040@000A@00`4:00@110000`40000E00005@000`40000L00030@0000H0
00@1000120001040004I00030@0000D000@100012@020B8000@100011P000`400@0E00811`060@80
00<100001P001040004B00814@050AL0000E00030@0002H00P400`01000700816@000`4000070081
2`000`40000<00030@0001800P4500810`030A801@4:00810P040@@00P4A00815@030A400P440000
5@000`40000Y00030@00020000<100005P020@d00P4H00030@0001L000@100000P4B00814`020AT0
00<100003P001040004300005@000`40000Z00030@0001h000<100006@000`40000<00815@000`40
000N00030@0001D0104:00030@0002X000<10000100000l0o`410@X000<10000100001D000<10000
2@000`40000900030@0000D000D100000@0900030@0100`000<100002@000`4000020@L000<10000
2@000`40000900030@0000T000<100002P000`40000400810`000`40000900030@0000@11@000`40
000700030@0100/000<100002P00104000020@H000<100002@000`40000200811@000`40000=00@1
100001D000<100007P000`40000:00030@0101X00P4D00030@0000X000<100003P000`40000:0003
0@0000<000<1000080020@/000<1000030020@80104?00@11`000`40000>00030@0000@0000E0003
0@0001h000<100002P000`40000I00030@00028000<100003P000`40000800030@0000h00P4I0003
0@0001D00P4<00L180000`40000400005@000`40000O00030@0000X000<100005`000`40000T0003
0@0000h00P4600813`020A`00P4C0081?00001D000<100007`000`40000:00030@0001H000<10000
9P000`40000?00030@00008000<100003@020B000`4<00@1?P0001D00P4^00030@0001@000<10040
:0020A801P460081:@030@L00P5200005@000`40000]00030@0001<000<10040:`030@d00P4600H1
;P070D@0000E00030@0002h000<100004@001040004^00030@0000P00P6700005@000`40000_0003
0@0000l000@10001<00:0HT0000E00030@00020000<100003@000`40000=00050@000040``0001D0
00<1000080000`40000>00030@0000X00P4300030@000<80000E00030@00024000<100003P020@T0
00<10000b00001D00P4R00030@00010000<1000010020L/0000E00030@00028000<100003`070Ld0
000E00030@00028000<1000070000`40003400005@000`40001000030@000<D0000E00030@000400
00<10000a@0001D000<10000?`000`40003600005@000`40000n00030@000<L0000E00819@000`40
003Q00005@000`40000U00030@000>00000E00030@0002D000<10000h00001D000<100009P000`40
000B00030@000<X0000E00030@0002H000<100004P000`40003:000000<00@400P4300030@000080
104400030@0003X000<10000b`0000<000<100001`000`4000050081>P000`40003<00000`000`40
000800030@0000@000<10000>0000`40003=00000`000`40000900030@0000<000<10000:@000`40
003L00000`000`40000:00030@00008000<10000:P000`4000080081d@00000400410@T000@10001
10000`40000[00030@0000H000<10000d@0000<000<1000020020@D000<10000;0000`4000040003
0@000=80000E00030@0002d000<100000P000`40003C00005@020Ol02P0001D000<10000o`090000
5@000`40003o00T0000E00030@000?l02@000?l08@000?l08@000?l08@000?l08@000?l08@0007T0
0`4K00<1QP0007X000<100006`000`4000250000J0030@D00P4300<10P030@P00`4200030@0000<1
0P030@<00`4400810P030@04004100<110030F`0001X00040@000@<000H10001004500040@000@P0
00@100010P000`40000600040@000@8000@100010P001040004200030@0000<000@10001K`0006/0
00D100000@0400<10`001040004800<10`030@@00P4300040@000@8000@100010P00104000430081
0`030Fd0001Y008110000`40000200040@000@8000@1000120001040004200040@000@8000<10000
0`001040004200040@000@8000@100010P000`40000300040@000F`0001X00030@0000<010430081
0P0010400@4900040@000@<00P4400<100<00@000P4400810P0010400@4400<10`020Fd0001Y00<1
0`000`40000C00@1U`0006l000<10000[P000?l08@000?l08@000?l08@000?l08@000001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0871025, 0.0691379, 
  0.00410959, 0.0076074}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Phase response", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(phaseResponsePZ1\  = \ 
      Plot[\((phase[r\ , i\ , c\ , d\ , n\ , m\ , \ w]\  /. \ polesZeroes1)
          \), {w, 0, 20}, PlotRange -> \ All, 
        PlotStyle -> {Dashing[{.02, .02}]}]; \)\)], "Input",
  InitializationCell->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0476191 0.603319 0.164769 [
[.2619 .59082 -3 -9 ]
[.2619 .59082 3 0 ]
[.5 .59082 -6 -9 ]
[.5 .59082 6 0 ]
[.7381 .59082 -6 -9 ]
[.7381 .59082 6 0 ]
[.97619 .59082 -6 -9 ]
[.97619 .59082 6 0 ]
[.01131 .02663 -24 -4.5 ]
[.01131 .02663 0 4.5 ]
[.01131 .10901 -12 -4.5 ]
[.01131 .10901 0 4.5 ]
[.01131 .1914 -24 -4.5 ]
[.01131 .1914 0 4.5 ]
[.01131 .27378 -12 -4.5 ]
[.01131 .27378 0 4.5 ]
[.01131 .35616 -24 -4.5 ]
[.01131 .35616 0 4.5 ]
[.01131 .43855 -12 -4.5 ]
[.01131 .43855 0 4.5 ]
[.01131 .52093 -24 -4.5 ]
[.01131 .52093 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60332 m
.2619 .60957 L
s
[(5)] .2619 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(10)] .5 .59082 0 1 Mshowa
.7381 .60332 m
.7381 .60957 L
s
[(15)] .7381 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(20)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .02663 m
.03006 .02663 L
s
[(-3.5)] .01131 .02663 1 0 Mshowa
.02381 .10901 m
.03006 .10901 L
s
[(-3)] .01131 .10901 1 0 Mshowa
.02381 .1914 m
.03006 .1914 L
s
[(-2.5)] .01131 .1914 1 0 Mshowa
.02381 .27378 m
.03006 .27378 L
s
[(-2)] .01131 .27378 1 0 Mshowa
.02381 .35616 m
.03006 .35616 L
s
[(-1.5)] .01131 .35616 1 0 Mshowa
.02381 .43855 m
.03006 .43855 L
s
[(-1)] .01131 .43855 1 0 Mshowa
.02381 .52093 m
.03006 .52093 L
s
[(-0.5)] .01131 .52093 1 0 Mshowa
.125 Mabswid
.02381 .0431 m
.02756 .0431 L
s
.02381 .05958 m
.02756 .05958 L
s
.02381 .07606 m
.02756 .07606 L
s
.02381 .09253 m
.02756 .09253 L
s
.02381 .12549 m
.02756 .12549 L
s
.02381 .14196 m
.02756 .14196 L
s
.02381 .15844 m
.02756 .15844 L
s
.02381 .17492 m
.02756 .17492 L
s
.02381 .20787 m
.02756 .20787 L
s
.02381 .22435 m
.02756 .22435 L
s
.02381 .24083 m
.02756 .24083 L
s
.02381 .2573 m
.02756 .2573 L
s
.02381 .29026 m
.02756 .29026 L
s
.02381 .30673 m
.02756 .30673 L
s
.02381 .32321 m
.02756 .32321 L
s
.02381 .33969 m
.02756 .33969 L
s
.02381 .37264 m
.02756 .37264 L
s
.02381 .38912 m
.02756 .38912 L
s
.02381 .4056 m
.02756 .4056 L
s
.02381 .42207 m
.02756 .42207 L
s
.02381 .45503 m
.02756 .45503 L
s
.02381 .4715 m
.02756 .4715 L
s
.02381 .48798 m
.02756 .48798 L
s
.02381 .50446 m
.02756 .50446 L
s
.02381 .53741 m
.02756 .53741 L
s
.02381 .55389 m
.02756 .55389 L
s
.02381 .57037 m
.02756 .57037 L
s
.02381 .58684 m
.02756 .58684 L
s
.02381 .01015 m
.02756 .01015 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
[ .02 .02 ] 0 setdash
.02381 .60332 m
.06244 .59867 L
.10458 .59354 L
.14415 .58861 L
.18221 .5837 L
.22272 .57823 L
.26171 .57266 L
.30316 .5663 L
.34309 .55965 L
.3815 .55264 L
.42237 .54439 L
.46172 .53548 L
.49955 .52584 L
.53984 .51414 L
.57861 .50123 L
.61984 .48536 L
.65954 .46768 L
.69774 .4482 L
.73838 .42472 L
.77751 .39963 L
.81909 .37085 L
.85916 .34159 L
.89771 .31155 L
.91726 .29425 L
.92761 .28354 L
.93871 .26946 L
.94392 .26115 L
.94885 .25151 L
.95328 .24054 L
.95557 .23358 L
.9581 .22443 L
.96265 .202 L
.96515 .1846 L
.96749 .16308 L
.96968 .13673 L
.97168 .10582 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`>?U]kOUiBgUFbJo_bI<_bJoC000oooG0;nH]P000000E@00ZP00o`1E001EE@1EZP1Eo`2Z
002ZE@2ZZP2Zo`3o003oE@3oZP3ooeD005D0EED0ZUD0oeEE05EEEEEEZUEEoeFZ05FZEEFZZUFZoeGo
05GoEEGoZUGoojX00:X0EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZZZoj[o0:[oEJ[oZZ[oool0
0?l0EOl0Z_l0oomE0?mEEOmEZ_mEoonZ0?nZEOnZZ_nZoooo0?ooEOooZ_ooo`0001lO7clo?emOGgmo
OinOWkno_moOgoooonKVi]WIfDa<C;OU`]cU;Nc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a
/JRXZ:2PX=Rof8:2PXj>SWalO7EeMH9cPYVIV@00?mFgi@00O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03loOclo_clo
ocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0
oglo07lo?gloOglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl0
0;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo
?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono
_onooooo?oooOooo_n[ZjWAdM:NWYjj^[WMgMiUVc9UVoiVI09VI<iVIIYVIc9VIoiW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I_l08@000?l08@000?l08@000?l08@000?l0
8@000?l08@0001/000<10000o`0300006`000`40003o00<0000K00030@000?l00`0001/00P7o00@0
000K00030@000?X000<100001@0001/000<10000nP000`400005000020020@@000<100000P030@D0
00<10000nP000`40000500001`001040004;00030@0000800P7k00030@0000D0000:00030@0000T0
00<100000P000`40003j00030@0000D000000`010@020@<00P4900<11@000`40003o00<0000:0003
0@0000H000<100001@000`40003o00<0000700040@000@P000<100001@020Ol0100000P00P4900@1
10000`40003o00<0000K00030@000?l00`0001/000<10000nP000`40000500006`000`40003j0003
0@0000D0000K0081n`000`40000500006`000`40003i00030@0000H0000K00030@000?T000<10000
1P0001/000<10000n@000`40000600006`020Ol0100001/000<10000o`0300006`000`40003o00<0
000K00030@000?l00`0001/00P7j00030@0000H0000K00030@000?T000<100001P0001/000<10000
n@000`40000600006`000`40003i00030@0000H0000D00811@000`40003i00030@0000H0000C0004
0@000@@00P7j00030@0000H0000F00030@00008000<10000n@000`40000600003@040@<00P450003
0@000?l00`0001H000<100000P000`40003o00<0000C00040@000@@00P7o00@0000D00811@000`40
003o00<0000K00030@000?P000<100001`0001/000<10000n0000`40000700006`000`40003h0003
0@0000L0000K0081n@000`40000700006`000`40003h00030@0000L0000K00030@000?P000<10000
1`0001/000<10000o`0300006`020Ol0100001/000<10000o`0300006`000`40003o00<0000K0003
0@000?P000<100001`0001/00P7i00030@0000L0000K00030@000?P000<100001`0001/000<10000
m`000`40000800001`040@<000<100000P030@D000<10000m`000`40000800001`000`40000<0003
0@00008000<10000m`000`400008000020000`40000;00030@0000800P7h00030@0000P000000`01
0@020@@000<100001`030@D000<10000o`0300002P000`40000600030@0000D000<10000o`030000
1`001040004800030@0000D000<10000o`03000020020@T010440081o`0400006`000`40003f0003
0@0000T0000K00030@000?H000<100002@0001/000<10000mP000`40000900006`000`40003e0003
0@0000X0000K0081mP000`40000:00006`000`40003e00030@0000X0000K00030@000?l00`0001/0
00<10000o`0300006`020Ol0100001/000<10000o`0300006`000`40003c00030@0000`0000K0003
0@000?<000<10000300001/00P7d00030@0000`0000K00030@000?8000<100003@0001/000<10000
lP000`40000=00004`040@@000<10000l@000`40000>00004`000`40000500030@000?l00`0001@0
00<1000010020Ol0100000d0104400030@0000<000<10000o`0300005P000`40000200030@000>d0
00<100004P0001<000@1000110000`40003/00030@0001<0000D00811@020N`000<10000500001/0
00<10000jP000`40000E00006`000`40003Z00030@0001D0000K00030@000?l00`0001/00P7o00@0
000K00030@000>H000<100006@0001/000<10000i@000`40000J00006`000`40003S00817@0001/0
00<10000hP000`40000M00006`020N8000<100007P0001/000<10000o`0300006`000`40003o00<0
000K00030@000=d000<100008P0001/00P7M00030@0002<0000K00030@000=X00P4V00006`000`40
003I00030@0002H0000700@10`000`40000200<11@000`40003o00<0000900030@0000X000<10000
0P000`40003o00<0000900030@0000X000<100000P020MH000<10000:P0000030041008110000`40
000700<11@000`40003C0081;@0000T000<100001`000`40000500030@000=400P4_00001`030@T0
00<100001@000`40003@00030@0002l0000900030@0000L010440081o`0400006`000`40003o00<0
000K00030@000?l00`0001/000<10000c0000`40000c00006`020L/00P4f00006`000`4000390003
0@0003H0000K00030@000<P000<10000=`0001/000<10000o`0300006`000`40003300030@0003`0
000K0081`P020Cl0000K00030@000<0000<10000?`0001/000<10000_`000`40001000006`000`40
003o00<0000K0081o`0400006`000`40002j00030@0004D0000K00030@000;P00P5800004`040@@0
00<10000]`000`40001800005@000`4000030081]`000`40001900005@000`40000300030@000?l0
0`0000d0104400030@0000<000<10000/@000`40001>00005@000`40000300030@000:l00P5A0000
4`030@D000<10000[@020E<0000E00030@0000<00P6]00030@0005<0000K00030@000?l00`0001/0
00<10000Y`020ET0000K00030@000:H000<10000F@0001/00P6U0081G00001/000<10000X`000`40
001L00006`000`40003o00<0000K00030@0009d00P5S00006`000`40002J00<1I@0001/00P6J0003
0@0006H0000K00030@000?l00`0001/000<10000TP030Fd0000K00030@0009000P5`00006`020I00
00<10000L00001/000<10000R@020GL0000K00030@0008L00P5i000020020@@000<100000P030@D0
00<10000Q@020G/0000700040@000@/000<100000P020H000P6100001`001040004;00030@000080
00<10000O@020H<000000`010@020@8000@1000120030@D000<10000N`020HD0000700040@000@P0
00<100001@000`40001d00<1R`0000L000@1000120000`40000500030@0007400`6>000020020@T0
10440081L@000`40002?00006`000`40001Y00<1UP0001/000<10000IP030IT0000K00030@0005l0
0`6P00006`020Ed00`6S00006`000`40001D00<1Z`0001/000<10000D@030Jh0000K00030@0004L0
1P6e00006`000`40000o00<11@000`40002h00006`020C/01@4g00@10`020CL0104200<1=P040@<0
0P4400006`000`40000e00<11@000`40000h00050@0000400P000`40000f00030@0000@000<10000
<`000`40000300040@000@<0000K00030@0002X00`4500<120000`40000h00050@0000400P000`40
000f00030@0000@000<10000=0000`40000200040@000@<0000K00030@0002L00`4@00<1>`001@40
0001008000<10000=P00104000030CP000D100000@0200030@000040000K00817@070AL000<10000
>`001@400001008000<10000=P001@40000103/000@100010P000`40000100006`000`40000E00<1
8P000`40000i00<10`001040004f00<10`000`40000f00040@000@8000@100010`0001/000<10000
2P040@@00`4U00@1>P000`4000020081>@00104000040CH00P440081100001/000<100001`030OP0
000D0?l13@4001/000<100002@000`40000:00030@0000X000<100002@000`40000:00030@0000X0
00<100002@000`40000:00030@0000X000<100002@000`40000:00030@0000X000<100002@000`40
000:00030@0000X000<100002@000`40000:00030@0000X000<100002@000`40000:00030@0000D0
000K00030@0003`000<10000?0000`40000m00030@0003`000<100001@0001/000<10000o`030000
6`000`40003o00<0003o0240003o0240003o0240003o0240003o0240003o02400000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.15729, -3.80464, 
  0.0789455, 0.0228157}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(phaseResponsePZ2\  = \ 
      Plot[\((phase[r\ , i\ , c\ , d\ , n\ , m\ , \ w]\  /. \ polesZeroes2)
          \), {w, 0, 20}, PlotRange -> All]; \)\)], "Input",
  InitializationCell->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0476191 0.603319 0.286486 [
[.2619 .59082 -3 -9 ]
[.2619 .59082 3 0 ]
[.5 .59082 -6 -9 ]
[.5 .59082 6 0 ]
[.7381 .59082 -6 -9 ]
[.7381 .59082 6 0 ]
[.97619 .59082 -6 -9 ]
[.97619 .59082 6 0 ]
[.01131 .03035 -12 -4.5 ]
[.01131 .03035 0 4.5 ]
[.01131 .17359 -24 -4.5 ]
[.01131 .17359 0 4.5 ]
[.01131 .31683 -12 -4.5 ]
[.01131 .31683 0 4.5 ]
[.01131 .46008 -24 -4.5 ]
[.01131 .46008 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60332 m
.2619 .60957 L
s
[(5)] .2619 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(10)] .5 .59082 0 1 Mshowa
.7381 .60332 m
.7381 .60957 L
s
[(15)] .7381 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(20)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .03035 m
.03006 .03035 L
s
[(-2)] .01131 .03035 1 0 Mshowa
.02381 .17359 m
.03006 .17359 L
s
[(-1.5)] .01131 .17359 1 0 Mshowa
.02381 .31683 m
.03006 .31683 L
s
[(-1)] .01131 .31683 1 0 Mshowa
.02381 .46008 m
.03006 .46008 L
s
[(-0.5)] .01131 .46008 1 0 Mshowa
.125 Mabswid
.02381 .05899 m
.02756 .05899 L
s
.02381 .08764 m
.02756 .08764 L
s
.02381 .11629 m
.02756 .11629 L
s
.02381 .14494 m
.02756 .14494 L
s
.02381 .20224 m
.02756 .20224 L
s
.02381 .23089 m
.02756 .23089 L
s
.02381 .25954 m
.02756 .25954 L
s
.02381 .28818 m
.02756 .28818 L
s
.02381 .34548 m
.02756 .34548 L
s
.02381 .37413 m
.02756 .37413 L
s
.02381 .40278 m
.02756 .40278 L
s
.02381 .43143 m
.02756 .43143 L
s
.02381 .48872 m
.02756 .48872 L
s
.02381 .51737 m
.02756 .51737 L
s
.02381 .54602 m
.02756 .54602 L
s
.02381 .57467 m
.02756 .57467 L
s
.02381 .0017 m
.02756 .0017 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .60332 m
.06244 .58257 L
.10458 .55984 L
.14415 .53827 L
.18221 .51725 L
.22272 .4945 L
.26171 .47218 L
.30316 .44799 L
.34309 .42424 L
.3815 .40102 L
.42237 .376 L
.46172 .35173 L
.49955 .32835 L
.53984 .30359 L
.57861 .28004 L
.61984 .25545 L
.65954 .23231 L
.69774 .2106 L
.73838 .188 L
.77751 .16652 L
.81909 .1435 L
.85916 .12014 L
.89771 .09482 L
.91726 .07989 L
.93871 .06074 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`>?U]kOUiBgUFbJo_bI<_bJoC000oooG0;nH]P000000E@00ZP00o`1E001EE@1EZP1Eo`2Z
002ZE@2ZZP2Zo`3o003oE@3oZP3ooeD005D0EED0ZUD0oeEE05EEEEEEZUEEoeFZ05FZEEFZZUFZoeGo
05GoEEGoZUGoojX00:X0EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZZZoj[o0:[oEJ[oZZ[oool0
0?l0EOl0Z_l0oomE0?mEEOmEZ_mEoonZ0?nZEOnZZ_nZoooo0?ooEOooZ_ooo`0001lO7clo?emOGgmo
OinOWkno_moOgoooonKVi]WIfDa<C;OU`]cU;Nc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a
/JRXZ:2PX=Rof8:2PXj>SWalO7EeMH9cPYVIV@00?mFgi@00O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03loOclo_clo
ocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0
oglo07lo?gloOglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl0
0;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo
?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono
_onooooo?oooOooo_n[ZjWAdM:NWYjj^[WMgMiUVc9UVoiVI09VI<iVIIYVIc9VIoiW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I_l08@000?l08@000?l08@000?l08@000?l0
8@000?l08@0001/00P7o00@0000K00030@000?l00`0001/000<10000o`0300006`000`40003o00<0
000K00030@000?X000<100001@0001/000<10000n@000`40000600006`000`40003h00030@0000L0
000C00@110000`40003h00030@0000L0000C00030@0000D00P7h00030@0000P0000D00030@0000@0
00<10000mP000`40000900003@040@@000<100000`000`40003e00030@0000X0000F00030@000080
00<10000m0000`40000;00004`001040004400030@000?<000<10000300001@00P4500030@000?<0
00<10000300001/000<10000lP000`40000=00006`000`40003a00030@0000h0000K0081l@000`40
000?00006`000`40003_00030@000100000K00030@000>d00P4C00006`000`40003/00030@0001<0
000K00030@000>/000<10000500001/000<10000jP000`40000E00006`000`40003Y00030@0001H0
000K0081j0020AT0000K00030@000>H000<100006@0001/000<10000i@000`40000J00006`000`40
003S00817@0001/000<10000hP000`40000M00006`000`40003P0081800001/000<10000g`000`40
000P00006`000`40003N00030@000240000K0081g@020B@0000K00030@000=/000<10000900001/0
00<10000f@020BL0000K00030@000=L00P4Y00006`000`40003E0081:`0001/000<10000d`020Bd0
000K00030@000=400P4_00006`020M4000<10000;`0001/000<10000cP020C80000K00030@000<`0
0P4d00006`000`40003:0081=P0001/000<10000b0020CP0000K00030@000<H00P4j00006`000`40
003500030@0003X0000700@10`000`40000200<11@000`4000330081?@0000T000<100002P000`40
00020081`P020Cl0000900030@0000X000<100000P000`40003000030@0003l000000`010@020@@0
00<100001`030@D000<10000_P020D80000900030@0000L000<100001@000`40002l0081A00000L0
0`4900030@0000D000<10000^`000`40001400002@000`40000700@110000`40002i0081A`0001/0
00<10000]`020DT0000K00030@000;D00P5;00006`020K@00P5=00006`000`40002a0081C`0001/0
00<10000/0000`40001?00006`000`40002^0081DP0001/000<10000[0020E@0000K00030@000:/0
00<10000E00001/000<10000Z@020EL0000K0081Z0020ET0000K00030@000:H000<10000F@0001/0
00<10000Y0020E`0000K00030@000:800P5N00006`000`40002P0081H00001/000<10000WP020F80
000K00030@0009`00P5T00006`000`40002K00030@0006@0000K0081VP020FL0000K00030@0009L0
0P5Y00006`000`40002E0081J`0001/000<10000T`020Fd0000K00030@0009400P5_00006`000`40
002@00030@0006l0000K00030@0008h00P5b00006`020Hh000<10000LP0001/000<10000R`020GD0
000K00030@0008X000<10000M@0001/000<10000R@000`40001f00006`000`4000270081N@0001/0
00<10000QP000`40001i00006`000`4000240081O00001<0104400030@0008800P5n00005@000`40
00030081P@020H00000E00030@0000<000<10000OP020H80000=00@110000`40000300030@0007`0
0P6400005@000`40000300030@0007/000<10000Q00001<00`4500030@0007T00P6700005@000`40
000300030@0007L00P6900006`000`40001f00030@0008T0000K00030@0007@00P6<00006`020G<0
0P6>00006`000`40001a00030@0008h0000K00030@0006l00P6A00006`000`40001^00030@000940
000K00030@0006`00P6D00006`000`40001[00030@0009@0000K00030@0006X000<10000U@0001/0
0P5Y0081V00001/000<10000I`000`40002H00006`000`40001U0081V`0001/000<10000I0000`40
002K00006`000`40001R0081WP0001/000<10000H0020J00000K00030@0005l000<10000X00001/0
00<10000G@020J<0000K0081G@000`40002S00006`000`40001J0081YP0001/000<10000F0020JP0
000K00030@0005L000<10000Z00001/000<10000E@020J/0000K00030@0005<00P6]00006`000`40
001B00030@000:d0000K00030@0005000P6`00006`020Dl00P6b00006`000`40001<0081]00001/0
00<10000BP020KH0000K00030@0004P00P6h00006`000`40001700030@000;P0000K00030@0004D0
0P6k000020020@@000<100000P030@D000<10000@`020Kd0000700040@000@/000<100000P020D80
0P6o00001`001040004;00030@00008000<10000?`020L4000000`010@020@8000@1000120030@D0
00<10000?@020L<0000700040@000@P000<100001@000`40000l00030@000<<0000700040@000@P0
00<100001@000`40000j0081aP0000P00P4900@110000`40000h0081b00001/000<10000=`000`40
003800006`000`40000e0081b`0001/00P4d0081c@0001/000<10000<P000`40003=00006`000`40
000`0081d00001/000<10000;P020M80000K00030@0002`00P7D00006`000`40000Z0081eP0001/0
00<10000:0020MP0000K0081:0000`40003H00006`000`40000U0081f`0001/000<100008`020Md0
000K00030@00028000<10000g@0001/000<1000080020N00000K00030@0001h00P7R00006`000`40
000M00030@000>80000K00030@0001/00P7U00006`020AX00P7W00006`000`40000G0081j@0001/0
00<100005@020N/0000K00030@0001<00P7]00006`000`40000B00030@000>d0000K00030@000100
0P7`00006`000`40000>0081lP0001/000<1000030020B`00`4i00@10`020CL0104200<1=P040@<0
0P4400006`020@/00P4a00030@0003P000D100000@0200030@0003H000<1000010000`40000c0003
0@0000<000@100010`0001/000<1000020020C<000<10000>0001@400001008000<10000=P000`40
000400030@0003@000<100000P001040004300006`000`4000060081<P030C/000D100000@020003
0@0003H000@100000`4h00050@0000400P000`40000100006`000`4000040081=0000`40000k0005
0@0000400P000`40000f00050@000040>`001040004200030@000040000K00030@0000800P4f0003
0@0003T00`4300040@000CH00`4300030@0003H000@100010P001040004300006`000`4000020CP0
104j00030@0000800P4i00040@0000@1=P020@@00P4400006`030Ol00`0001@0o`4=0@006`000`40
000900030@0000X000<100002P000`40000900030@0000X000<100002P000`40000900030@0000X0
00<100002P000`40000900030@0000X000<100002P000`40000900030@0000X000<100002P000`40
000900030@0000X000<100002P000`40000900030@0000X000<100001@0001/000<10000?0000`40
000l00030@0003d000<10000?0000`40000500006`000`40003o00<0000K00030@000?l00`000?l0
8@000?l08@000?l08@000?l08@000?l08@000?l08@000001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.15729, -2.18819, 
  0.0789455, 0.0131222}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(phaseResponsesPZ\  = \ 
      Show[phaseResponsePZ1, \ phaseResponsePZ2, 
        AxesLabel -> {"\<\[Omega]\>", "\<\>"}, 
        PlotLabel -> "\<Phase Response\>"]; \)\)], "Input",
  InitializationCell->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0476191 0.603319 0.164769 [
[.2619 .59082 -3 -9 ]
[.2619 .59082 3 0 ]
[.5 .59082 -6 -9 ]
[.5 .59082 6 0 ]
[.7381 .59082 -6 -9 ]
[.7381 .59082 6 0 ]
[.97619 .59082 -6 -9 ]
[.97619 .59082 6 0 ]
[1.025 .60332 0 -7.5 ]
[1.025 .60332 10 7.5 ]
[.01131 .02663 -24 -4.5 ]
[.01131 .02663 0 4.5 ]
[.01131 .10901 -12 -4.5 ]
[.01131 .10901 0 4.5 ]
[.01131 .1914 -24 -4.5 ]
[.01131 .1914 0 4.5 ]
[.01131 .27378 -12 -4.5 ]
[.01131 .27378 0 4.5 ]
[.01131 .35616 -24 -4.5 ]
[.01131 .35616 0 4.5 ]
[.01131 .43855 -12 -4.5 ]
[.01131 .43855 0 4.5 ]
[.01131 .52093 -24 -4.5 ]
[.01131 .52093 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 15 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .60332 m
.2619 .60957 L
s
[(5)] .2619 .59082 0 1 Mshowa
.5 .60332 m
.5 .60957 L
s
[(10)] .5 .59082 0 1 Mshowa
.7381 .60332 m
.7381 .60957 L
s
[(15)] .7381 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(20)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.21429 .60332 m
.21429 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.40476 .60332 m
.40476 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.59524 .60332 m
.59524 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.78571 .60332 m
.78571 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
gsave
1.025 .60332 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(w) show
69.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.02381 .02663 m
.03006 .02663 L
s
[(-3.5)] .01131 .02663 1 0 Mshowa
.02381 .10901 m
.03006 .10901 L
s
[(-3)] .01131 .10901 1 0 Mshowa
.02381 .1914 m
.03006 .1914 L
s
[(-2.5)] .01131 .1914 1 0 Mshowa
.02381 .27378 m
.03006 .27378 L
s
[(-2)] .01131 .27378 1 0 Mshowa
.02381 .35616 m
.03006 .35616 L
s
[(-1.5)] .01131 .35616 1 0 Mshowa
.02381 .43855 m
.03006 .43855 L
s
[(-1)] .01131 .43855 1 0 Mshowa
.02381 .52093 m
.03006 .52093 L
s
[(-0.5)] .01131 .52093 1 0 Mshowa
.125 Mabswid
.02381 .0431 m
.02756 .0431 L
s
.02381 .05958 m
.02756 .05958 L
s
.02381 .07606 m
.02756 .07606 L
s
.02381 .09253 m
.02756 .09253 L
s
.02381 .12549 m
.02756 .12549 L
s
.02381 .14196 m
.02756 .14196 L
s
.02381 .15844 m
.02756 .15844 L
s
.02381 .17492 m
.02756 .17492 L
s
.02381 .20787 m
.02756 .20787 L
s
.02381 .22435 m
.02756 .22435 L
s
.02381 .24083 m
.02756 .24083 L
s
.02381 .2573 m
.02756 .2573 L
s
.02381 .29026 m
.02756 .29026 L
s
.02381 .30673 m
.02756 .30673 L
s
.02381 .32321 m
.02756 .32321 L
s
.02381 .33969 m
.02756 .33969 L
s
.02381 .37264 m
.02756 .37264 L
s
.02381 .38912 m
.02756 .38912 L
s
.02381 .4056 m
.02756 .4056 L
s
.02381 .42207 m
.02756 .42207 L
s
.02381 .45503 m
.02756 .45503 L
s
.02381 .4715 m
.02756 .4715 L
s
.02381 .48798 m
.02756 .48798 L
s
.02381 .50446 m
.02756 .50446 L
s
.02381 .53741 m
.02756 .53741 L
s
.02381 .55389 m
.02756 .55389 L
s
.02381 .57037 m
.02756 .57037 L
s
.02381 .58684 m
.02756 .58684 L
s
.02381 .01015 m
.02756 .01015 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Phase) show
99.000000 15.000000 moveto
(Response) show
147.000000 15.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.5 Mabswid
[ .02 .02 ] 0 setdash
.02381 .60332 m
.06244 .59867 L
.10458 .59354 L
.14415 .58861 L
.18221 .5837 L
.22272 .57823 L
.26171 .57266 L
.30316 .5663 L
.34309 .55965 L
.3815 .55264 L
.42237 .54439 L
.46172 .53548 L
.49955 .52584 L
.53984 .51414 L
.57861 .50123 L
.61984 .48536 L
.65954 .46768 L
.69774 .4482 L
.73838 .42472 L
.77751 .39963 L
.81909 .37085 L
.85916 .34159 L
.89771 .31155 L
.91726 .29425 L
.92761 .28354 L
.93871 .26946 L
.94392 .26115 L
.94885 .25151 L
.95328 .24054 L
.95557 .23358 L
.9581 .22443 L
.96265 .202 L
.96515 .1846 L
.96749 .16308 L
.96968 .13673 L
.97168 .10582 L
.97619 .01472 L
s
[ ] 0 setdash
.02381 .60332 m
.06244 .59139 L
.10458 .57831 L
.14415 .56591 L
.18221 .55382 L
.22272 .54073 L
.26171 .5279 L
.30316 .51399 L
.34309 .50032 L
.3815 .48697 L
.42237 .47258 L
.46172 .45862 L
.49955 .44518 L
.53984 .43094 L
.57861 .41739 L
.61984 .40325 L
.65954 .38994 L
.69774 .37745 L
.73838 .36445 L
.77751 .3521 L
.81909 .33886 L
.85916 .32543 L
.89771 .31086 L
.91726 .30228 L
.93871 .29126 L
.97619 .26479 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`000<c<c;Ng]fIV
I_Cdm42P`>?U]kOUiBgUFbJo_bI<_bJoC000oooG0;nH]P000000E@00ZP00o`1E001EE@1EZP1Eo`2Z
002ZE@2ZZP2Zo`3o003oE@3oZP3ooeD005D0EED0ZUD0oeEE05EEEEEEZUEEoeFZ05FZEEFZZUFZoeGo
05GoEEGoZUGoojX00:X0EJX0ZZX0ojYE0:YEEJYEZZYEojZZ0:ZZEJZZZZZZoj[o0:[oEJ[oZZ[oool0
0?l0EOl0Z_l0oomE0?mEEOmEZ_mEoonZ0?nZEOnZZ_nZoooo0?ooEOooZ_ooo`0001lO7clo?emOGgmo
OinOWkno_moOgoooonKVi]WIfDa<C;OU`]cU;Nc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a
/JRXZ:2PX=Rof8:2PXj>SWalO7EeMH9cPYVIV@00?mFgi@00O`00_`0o000o?`0oO`0o_`0oo`1o001o
?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03loOclo_clo
ocmo03mo?cmoOcmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0
oglo07lo?gloOglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl0
0;l0?kl0Okl0_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo
?kooOkoo_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono
_onooooo?oooOooo_n[ZjWAdM:NWYjj^[WMgMiUVc9UVoiVI09VI<iVIIYVIc9VIoiW<09W<<iW<IYW<
VIW<c9W<oiWo09Wo<iWoIYWoVIWoc9Wool`00<`0<l`0I_l08@000?l08@0001/000<10000o`030000
6`000`40003o00<0000K0081o`0400006`000`40003o00<0000K00030@000>X000<100005@0000P0
0P4400030@0000800`4500030@000>X000<100005@0000L000@100012`000`4000020081j`000`40
000E00002P000`40000900030@00008000<10000jP000`40000E000000<00@400P4300812@030@D0
00<10000jP000`40000E00002P000`40000600030@0000D000<10000o`0300001`00104000480003
0@0000D000<10000o`03000020020@T010440081o`0400006`000`40003o00<0000K00030@000>X0
00<100005@0001/000<10000jP000`40000E00006`020N/000<100005@0001/000<10000jP000`40
000E00006`000`40003Z00030@0001D0000K00030@000>X000<100005@0001/00P7o00@0000K0003
0@000?l00`0001/000<10000o`0300006`000`40003o00<0000K0081jP000`40000F00006`000`40
003Y00030@0001H0000K00030@000>T000<100005P0001@00P4500030@000>T000<100005P0001<0
00@1000110020NX000<100005P0001H000<100000P000`40003Y00030@0001H0000=00@10`020@D0
00<10000o`0300005P000`40000200030@000?l00`0001<000@1000110020Ol0100001@00P450003
0@000?l00`0001/000<10000j@000`40000F00006`000`40003Y00030@0001H0000K0081jP000`40
000F00006`000`40003Y00030@0001H0000K00030@000>P000<100005`0001/000<10000j0000`40
000G00006`020Ol0100001/000<10000o`0300006`000`40003o00<0000K00030@000?l00`0001/0
00<10000j0000`40000G00006`020NT000<100005`0001/000<10000j0000`40000G00001`040@<0
00<100000P030@D000<10000j0000`40000G00001`000`40000<00030@00008000<10000j0000`40
000G000020000`40000;00030@0000800P7X00030@0001P000000`010@020@@000<100001`030@D0
00<10000o`0300002P000`40000600030@0000D000<10000o`0300001`001040004800030@0000D0
00<10000o`03000020020@T010440081o`0400006`000`40003V00030@0001T0000K00030@000>H0
00<100006@0001/000<10000iP000`40000I00006`020NL000<100006@0001/000<10000i@000`40
000J00006`000`40003o00<0000K00030@000?l00`0001/00P7o00@0000K00030@000?l00`0001/0
00<10000i0000`40000K00006`000`40003S00030@0001`0000K0081i0000`40000L00006`000`40
003R00030@0001d0000K00030@000>8000<100001@000`40000E00004`040@@000<10000h@000`40
000500030@0001H0000C00030@0000D00P7X00816@0001@000<1000010000`40003V00030@0001T0
000=00@110000`40000300030@000>D000<100006P0001H000<100000P000`40003N00030@000080
0P4M00004`00104000440081gP000`40000200030@0001d0000D00811@000`40003L00040@000081
800001/000<10000f`000`4000020B80000K00030@000=/00`4T00006`020MX00P4W00006`000`40
003F00<1:@0001/000<10000e0040BX0000K00030@000=401@4/00006`000`40003?00810P000`40
000/00006`020Ld00`4c00006`000`40003800@1=P0001/000<10000a@030CX0000K00030@000<80
0`490081<P0001/00P7100812`000`40000b00006`000`40002m00<130000`40000c00001`040@<0
00<100000P030@D000<10000^`020@h000<10000=00000T000<100002P000`40000200030@000;P0
0`5700002@000`40000:00030@0000800P6e00@13`000`40000h000000<00@400P4400030@0000L0
0`4500030@000;400`4A0081>`0000T000<100001`000`40000500030@000:h00`4C00030@0003/0
000700<12@000`40000500030@000:X0104E00030@0003`0000900030@0000L010440081Z0030EP0
000K00030@000:@00`5K00006`000`40002P00@16`000`40001000006`000`40002M00<17@020D<0
000K0081V`030Al000<10000@`0001/000<10000UP040B4000<10000A00001/000<10000T`030F`0
000K00030@0009000`5_00006`020Hl00P4W00030@0004P0000K00030@0008/00`4W0081B`0001/0
00<10000R@020BT000<10000B`0001/000<10000QP030BX000<10000C00001/00P6300@1O00001/0
00<10000O`030B`000<10000D@0001/000<10000O0030Bd00P5D00004`040@@000<10000NP020Bl0
00<10000E00001D000<100000`020GP00`4`00030@0005D0000E00030@0000<000<10000M@020H/0
000=00@110000`40000300030@0007800`4a00030@0005T0000E00030@0000<000<10000K`030C80
0P5L00004`030@D00P5]00<1<`020Eh0000E00030@0000<000<10000J@030CD000<10000GP0001/0
00<10000I`020IT0000K00030@0006@00`4e0081I00001/000<10000HP020CH00P5V00006`020F00
0`4f0081J00001/000<10000F`040J<0000K00030@0005P00`4h0081K@0001/000<10000E@030CP0
0`5_00006`020E@00P4j00030@000700000K00030@0005000`6_00006`000`40001>0081>@020GL0
000K00030@0004/00`4h00<1N@0001/00P5800@1]`0001/000<10000A0030CP00`6000006`000`40
001100<1>0030H<00008008110000`40000200<11@000`40000o0081`@0000L000@100012`000`40
00020081?@030CL00`6900001`001040004;00030@00008000<10000>P020CL00`6<000000<00@40
0P4200040@000@P00`4500030@0003L00`4b00<1T`0000L000@1000120000`40000500030@0003<0
104c0081UP0000L000@1000120000`4000050081<@030CH000<10000UP0000P00P4900@110000`40
000]00<1<P030Id0000K00030@0002T0104b00<1X00001/000<100009P030Bl00`6W00006`020B@0
0`4`0081ZP0001/000<1000080030B`00`6`00006`000`40000M00<19@030@@00`6c00006`000`40
000J00<19@030Kd0000K00815`040A`00`4200<1<0040@<00P4c00@10P030C8010430081500001/0
00<100004`030B800`4e00050@0000400P000`40000b00030@0000@000<10000;`000`4000030004
0@000A<0000K00030@0001000`4K00H11@000`40000d00050@0000400P000`40000b00030@0000@0
00<10000<0000`40000200040@000A<0000K00030@0000`0104G00<130030CL000D100000@020003
0@00038000@100000`4d00050@0000400P000`40000A00006`020@T0104A00<110030@l000<10000
=`001@400001008000<10000<P001@40000103L000@100010P000`40000A00006`000`40000500<1
2`030@@00`4I00030@0003D00`4300040@000C800`4300030@00038000@100010P001040004C0000
6`000`40000200<12`030B<0104f00030@0000800P4e00040@0000@1<P020@@00P4<00@1100001/0
00<100400P4400H1k@001P4000400@<0000E0?X120001P4000400@<0000K00030@0000T000<10000
20000`40000900030@0000T000<100002@000`40000900030@0000T000<100002@000`4000090003
0@0000P000<100002@000`40000900030@0000T000<100002@000`40000900030@0000T000<10000
2@000`40000900030@0000P000<100002@000`40000<00030@00008000<100000@0001/000<10000
>0000`40000h00030@0003T000<10000>0000`40000=00050@0000400`0001/000<10000o`030000
6`000`40003o00<0003o0240003o0240003o0240003o0240003o0240002M00<1P00009h000<10000
O`0006L00`4300<100<00@400P020@03004000<110030@L00`4200030@0000<10P030@<00`440081
0P030@04004100<110030FH0001X00030@0000<000@100010P001040004500040@000@/000@10001
0P000`40000600040@000@8000@100010P001040004200030@0000<000@10001J@0006P00`430004
0@000@<00`4300810`030@T00`4300<110020@<000@100010P001040004200040@000@<00P4300<1
I`0006P000@100010P001040004500040@000@D000@1000120001040004200040@000@8000<10000
0`001040004200040@000@8000@100010P000`40000300040@000FH0001X00040@000@800`440081
10030@<00P4900040@000@<00P4400<100<00@000P4400810P0010400@4400<10`020FL0001W00@1
0`000`40000J00@1T@0006d00P6a0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000o`0Q0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.28198, -3.71716, 0.084141,
   0.0243172}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Writing results to files", "Subsection"],

Cell[BoxData[
    \(\(Display["\<magpz_44.eps\>", magnitudeResponsesPZ, "\<EPS\>"]; \)\)], 
  "Input"],

Cell[BoxData[
    \(\(Display["\<phasepz_44.eps\>", phaseResponsesPZ, "\<EPS\>"]; \)\)], 
  "Input"],

Cell[BoxData[
    \(\(Display["\<steppz_44.eps\>", stepResponsesPZ, "\<EPS\>"]; \)\)], 
  "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1280}, {0, 1024}},
AutoGeneratedPackage->None,
WindowSize->{520, 600},
WindowMargins->{{243, Automatic}, {159, Automatic}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"Magnification"->1}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 69, 0, 201, "Title"],
Cell[1803, 53, 70, 3, 83, "Subtitle"],
Cell[1876, 58, 177, 5, 118, "Subsubtitle"],
Cell[2056, 65, 52, 0, 52, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2133, 69, 33, 0, 54, "Section"],
Cell[2169, 71, 65, 0, 32, "Text"],
Cell[2237, 73, 103, 2, 27, "Input",
  InitializationCell->True],
Cell[2343, 77, 60, 0, 32, "Text"],
Cell[2406, 79, 110, 2, 27, "Input",
  InitializationCell->True],
Cell[2519, 83, 103, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[2647, 90, 181, 3, 43, "Input",
  InitializationCell->True],
Cell[2831, 95, 174, 3, 39, "Message"],
Cell[3008, 100, 174, 3, 39, "Message"]
}, Open  ]],
Cell[3197, 106, 117, 2, 27, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3351, 113, 26, 0, 34, "Section"],
Cell[3380, 115, 347, 6, 86, "Text"],
Cell[3730, 123, 422, 8, 86, "Text"],

Cell[CellGroupData[{
Cell[4177, 135, 96, 3, 45, "Subsection"],
Cell[4276, 140, 138, 3, 50, "Text"],
Cell[4417, 145, 85, 2, 43, "Input",
  InitializationCell->True],
Cell[4505, 149, 136, 3, 50, "Text"],

Cell[CellGroupData[{
Cell[4666, 156, 280, 5, 59, "Input",
  InitializationCell->True],
Cell[4949, 163, 1563, 42, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6549, 210, 276, 5, 59, "Input",
  InitializationCell->True],
Cell[6828, 217, 1588, 42, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[8465, 265, 40, 0, 29, "Subsection"],

Cell[CellGroupData[{
Cell[8530, 269, 261, 5, 75, "Input",
  InitializationCell->True],
Cell[8794, 276, 13493, 495, 70, 5622, 393, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22324, 776, 216, 4, 75, "Input",
  InitializationCell->True],
Cell[22543, 782, 12554, 419, 70, 4578, 316, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35134, 1206, 254, 5, 59, "Input",
  InitializationCell->True],
Cell[35391, 1213, 19550, 693, 70, 9654, 566, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[54990, 1912, 35, 0, 29, "Subsection"],

Cell[CellGroupData[{
Cell[55050, 1916, 262, 5, 75, "Input",
  InitializationCell->True],
Cell[55315, 1923, 12615, 456, 70, 5366, 362, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67967, 2384, 217, 4, 59, "Input",
  InitializationCell->True],
Cell[68187, 2390, 13554, 492, 70, 5806, 392, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81778, 2887, 216, 5, 43, "Input",
  InitializationCell->True],
Cell[81997, 2894, 19862, 767, 70, 10714, 650, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[101908, 3667, 36, 0, 29, "Subsection"],

Cell[CellGroupData[{
Cell[101969, 3671, 257, 5, 59, "Input",
  InitializationCell->True],
Cell[102229, 3678, 10582, 373, 70, 4034, 288, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[112848, 4056, 210, 4, 59, "Input",
  InitializationCell->True],
Cell[113061, 4062, 9375, 304, 70, 3090, 222, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[122473, 4371, 231, 5, 43, "Input",
  InitializationCell->True],
Cell[122707, 4378, 13870, 487, 70, 6500, 391, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[136626, 4871, 46, 0, 29, "Subsection"],
Cell[136675, 4873, 102, 2, 27, "Input"],
Cell[136780, 4877, 100, 2, 27, "Input"],
Cell[136883, 4881, 98, 2, 27, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

